@@ -10,7 +10,4 @@
 int predR(void);
 int predCS(void);
 
-int coordinator(int argc, char *argv[]);
-int client(int argc, char *argv[]);
-
 #endif 
