@@ -8,14 +8,12 @@
 #define JEDULE_EVENTS_H_
 
 #include "simgrid_config.h"
-
 #include "xbt/dynar.h"
 #include "xbt/dict.h"
+#include "simgrid/jedule/jedule_platform.h"
 
-#include "instr/jedule/jedule_platform.h"
-
-
-#ifdef HAVE_JEDULE
+#if HAVE_JEDULE
+SG_BEGIN_DECL()
 
 struct jed_event {
   int event_id;
@@ -30,18 +28,13 @@ struct jed_event {
 
 typedef struct jed_event s_jed_event_t, *jed_event_t;
 
-/************************************************************/
-
 void create_jed_event(jed_event_t *event, char *name, double start_time, double end_time, const char *type);
-
 void jed_event_free(jed_event_t event);
-
 void jed_event_add_resources(jed_event_t event, xbt_dynar_t host_selection);
-
 void jed_event_add_characteristic(jed_event_t event, char *characteristic);
-
 void jed_event_add_info(jed_event_t event, char *key, char *value);
 
+SG_END_DECL()
 #endif
 
 #endif /* JEDULE_EVENTS_H_ */
