@@ -10,21 +10,15 @@
 #include "simgrid_config.h"
 #include "simgrid/simdag.h"
 
-#ifdef HAVE_JEDULE
-
-void jedule_log_sd_event(SD_task_t task);
-
-void jedule_setup_platform(void);
-
-void jedule_sd_init(void);
-
-void jedule_sd_cleanup(void);
-
-void jedule_sd_exit(void);
-
-void jedule_sd_dump(void);
-
+#if HAVE_JEDULE
+SG_BEGIN_DECL()
+XBT_PUBLIC(void) jedule_log_sd_event(SD_task_t task);
+XBT_PUBLIC(void) jedule_setup_platform(void);
+XBT_PUBLIC(void) jedule_sd_init(void);
+XBT_PUBLIC(void) jedule_sd_cleanup(void);
+XBT_PUBLIC(void) jedule_sd_exit(void);
+XBT_PUBLIC(void) jedule_sd_dump(const char* filename);
+SG_END_DECL()
 #endif /* JEDULE_SD_BINDING_H_ */
 
-
 #endif
