@@ -9,8 +9,8 @@
 
 #include "xbt.h"
 #include "xbt/lib.h"
+#include "simgrid/forward.h"
 #include "simgrid/simix.h"
-#include "simgrid/platf.h"
 
 SG_BEGIN_DECL()
 
@@ -26,10 +26,10 @@ SG_BEGIN_DECL()
  * #MSG_task_send and friends) hide this object behind a string
  * alias. That mean that you don't provide the mailbox on which you
  * want to send your task, but only the name of this mailbox. */
-typedef struct s_smx_rvpoint *msg_mailbox_t;
+typedef struct s_smx_mailbox *msg_mailbox_t;
 
 /* ******************************** Environment ************************************ */
-typedef struct As *msg_as_t;
+typedef simgrid_As *msg_as_t;
 
 /* ******************************** Host ************************************ */
 
@@ -53,10 +53,6 @@ typedef struct s_msg_host_priv {
 
   xbt_dict_t affinity_mask_db;
   xbt_dynar_t file_descriptor_table;
-
-#ifdef MSG_USE_DEPRECATED
-  msg_mailbox_t *mailboxes;     /**< the channels  */
-#endif
 } s_msg_host_priv_t;
 
 /* ******************************** Task ************************************ */
@@ -134,26 +130,6 @@ static inline msg_storage_priv_t MSG_storage_priv(msg_storage_t storage){
   return (msg_storage_priv_t )xbt_lib_get_level(storage, MSG_STORAGE_LEVEL);
 }
 
-/*************** Begin GPU ***************/
-typedef struct simdata_gpu_task *simdata_gpu_task_t;
-
-typedef struct msg_gpu_task {
-  char *name;                   /**< @brief task name if any */
-  simdata_gpu_task_t simdata;       /**< @brief simulator data */
-  long long int counter;        /* task unique identifier for instrumentation */
-  char *category;               /* task category for instrumentation */
-} s_msg_gpu_task_t;
-
-/** @brief GPU task datatype.
-    @ingroup m_task_management
-
-    A <em>task</em> may then be defined by a <em>computing
-    amount</em>, a <em>dispatch latency</em> and a <em>collect latency</em>.
-    \see m_task_management
-*/
-typedef struct msg_gpu_task *msg_gpu_task_t;
-/*************** End GPU ***************/
-
 /**
  * \brief @brief Communication action.
  * \ingroup msg_task_usage
@@ -181,19 +157,6 @@ typedef struct msg_comm *msg_comm_t;
  */
 typedef struct s_smx_process *msg_process_t;
 
-#ifdef MSG_USE_DEPRECATED
-
-/* Compatibility typedefs */
-typedef int                     m_channel_t;
-typedef msg_gpu_task_t          m_gpu_task_t;
-typedef msg_host_t              m_host_t;
-typedef msg_process_t           m_process_t;
-typedef msg_task_t              m_task_t;
-typedef s_msg_gpu_task_t        s_m_gpu_task_t;
-typedef s_msg_host_t            s_m_host_t;
-typedef s_msg_task_t            s_m_task_t;
-#endif
-
 /** @brief Return code of most MSG functions
     @ingroup msg_simulation
     @{ */
@@ -224,7 +187,7 @@ XBT_PUBLIC(void) MSG_config(const char *key, const char *value);
  *  We allow to link against compiled versions that differ in the patch level.
  */
 #define MSG_init(argc,argv)  do {                                                          \
-	sg_version_check(SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH);\
+  sg_version_check(SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH);\
     MSG_init_nocheck(argc,argv);                                                        \
   } while (0)
 
@@ -249,7 +212,6 @@ XBT_PUBLIC(const char *) MSG_environment_as_get_name(msg_as_t as);
 XBT_PUBLIC(msg_as_t) MSG_environment_as_get_by_name(const char * name);
 XBT_PUBLIC(xbt_dict_t) MSG_environment_as_get_routing_sons(msg_as_t as);
 XBT_PUBLIC(const char *) MSG_environment_as_get_property_value(msg_as_t as, const char *name);
-XBT_PUBLIC(const char *) MSG_environment_as_get_model(msg_as_t as);
 XBT_PUBLIC(xbt_dynar_t) MSG_environment_as_get_hosts(msg_as_t as);
 
 /************************** File handling ***********************************/
@@ -266,7 +228,7 @@ XBT_PUBLIC(msg_error_t) MSG_file_seek(msg_file_t fd, sg_offset_t offset, int ori
 XBT_PUBLIC(sg_size_t) MSG_file_tell (msg_file_t fd);
 XBT_PUBLIC(void) __MSG_file_get_info(msg_file_t fd);
 XBT_PUBLIC(void) __MSG_file_priv_free(msg_file_priv_t priv);
-XBT_PUBLIC(const char *) MSG_file_get_name(msg_file_t storage);
+XBT_PUBLIC(const char *) MSG_file_get_name(msg_file_t file);
 XBT_PUBLIC(msg_error_t) MSG_file_move(msg_file_t fd, const char* fullpath);
 XBT_PUBLIC(msg_error_t) MSG_file_rcopy(msg_file_t fd, msg_host_t host, const char* fullpath);
 XBT_PUBLIC(msg_error_t) MSG_file_rmove(msg_file_t fd, msg_host_t host, const char* fullpath);
@@ -295,26 +257,28 @@ XBT_PUBLIC(msg_host_t) MSG_host_by_name(const char *name);
 #define MSG_get_host_by_name(n) MSG_host_by_name(n) /* Rewrite the old name into the new one transparently */
 XBT_PUBLIC(msg_error_t) MSG_host_set_data(msg_host_t host, void *data);
 XBT_PUBLIC(void *) MSG_host_get_data(msg_host_t host);
-XBT_PUBLIC(const char *) MSG_host_get_name(msg_host_t host);
+/** \ingroup m_host_management
+ *
+ * \brief Return the name of the #msg_host_t. */
+#define MSG_host_get_name(host) sg_host_get_name(host)
 XBT_PUBLIC(void) MSG_host_on(msg_host_t host);
 XBT_PUBLIC(void) MSG_host_off(msg_host_t host);
 XBT_PUBLIC(msg_host_t) MSG_host_self(void);
-XBT_PUBLIC(int) MSG_get_host_msgload(msg_host_t host);
-XBT_PUBLIC(double) MSG_get_host_speed(msg_host_t h);
+XBT_PUBLIC(double) MSG_host_get_speed(msg_host_t h);
 XBT_PUBLIC(int) MSG_host_get_core_number(msg_host_t h);
 XBT_PUBLIC(xbt_swag_t) MSG_host_get_process_list(msg_host_t h);
 XBT_PUBLIC(int) MSG_host_is_on(msg_host_t h);
 XBT_PUBLIC(int) MSG_host_is_off(msg_host_t h);
-XBT_PUBLIC(double) MSG_host_get_wattmin_at(msg_host_t host, int pstate);
-XBT_PUBLIC(double) MSG_host_get_wattmax_at(msg_host_t host, int pstate);
 
-XBT_PUBLIC(void) __MSG_host_destroy(msg_host_t host);
+// deprecated
+XBT_PUBLIC(double) MSG_get_host_speed(msg_host_t h);
+
 
 XBT_PUBLIC(double) MSG_host_get_power_peak_at(msg_host_t h, int pstate);
 XBT_PUBLIC(double) MSG_host_get_current_power_peak(msg_host_t h);
 XBT_PUBLIC(int)    MSG_host_get_nb_pstates(msg_host_t h);
-XBT_PUBLIC(void)   MSG_host_set_pstate(msg_host_t h, int pstate);
-XBT_PUBLIC(int)    MSG_host_get_pstate(msg_host_t host);
+#define MSG_host_get_pstate(h)         sg_host_get_pstate(h)
+#define MSG_host_set_pstate(h, pstate) sg_host_set_pstate(h, pstate)
 XBT_PUBLIC(xbt_dynar_t) MSG_hosts_as_dynar(void);
 XBT_PUBLIC(int) MSG_get_host_number(void);
 XBT_PUBLIC(void) MSG_host_get_params(msg_host_t ind_pm, vm_params_t params);
@@ -323,8 +287,6 @@ XBT_PUBLIC(xbt_dict_t) MSG_host_get_mounted_storage_list(msg_host_t host);
 XBT_PUBLIC(xbt_dynar_t) MSG_host_get_attached_storage_list(msg_host_t host);
 XBT_PUBLIC(xbt_dict_t) MSG_host_get_storage_content(msg_host_t host);
 
-XBT_PUBLIC(double) MSG_host_get_consumed_energy(msg_host_t h);
-
 /*property handlers*/
 XBT_PUBLIC(xbt_dict_t) MSG_host_get_properties(msg_host_t host);
 XBT_PUBLIC(const char *) MSG_host_get_property_value(msg_host_t host,
@@ -356,6 +318,11 @@ XBT_PUBLIC(msg_process_t) MSG_process_create_with_environment(const char
                                                             char **argv,
                                                             xbt_dict_t
                                                             properties);
+XBT_PUBLIC(msg_process_t) MSG_process_attach(
+  const char *name, void *data,
+  msg_host_t host, xbt_dict_t properties);
+XBT_PUBLIC(void) MSG_process_detach(void);
+
 XBT_PUBLIC(void) MSG_process_kill(msg_process_t process);
 XBT_PUBLIC(int) MSG_process_killall(int reset_PIDs);
 XBT_PUBLIC(msg_error_t) MSG_process_migrate(msg_process_t process, msg_host_t host);
@@ -395,10 +362,6 @@ XBT_PUBLIC(msg_process_t) MSG_process_restart(msg_process_t process);
 XBT_PUBLIC(msg_task_t) MSG_task_create(const char *name,
                                      double flops_amount,
                                      double bytes_amount, void *data);
-XBT_PUBLIC(msg_gpu_task_t) MSG_gpu_task_create(const char *name,
-                                     double flops_amount,
-                                     double dispatch_latency,
-                                     double collect_latency);
 XBT_PUBLIC(msg_task_t) MSG_parallel_task_create(const char *name,
                                               int host_nb,
                                               const msg_host_t * host_list,
@@ -416,11 +379,6 @@ XBT_PUBLIC(void) MSG_task_set_name(msg_task_t task, const char *name);
 XBT_PUBLIC(msg_error_t) MSG_task_cancel(msg_task_t task);
 XBT_PUBLIC(msg_error_t) MSG_task_destroy(msg_task_t task);
 
-XBT_PUBLIC(msg_error_t) MSG_task_receive_from_host(msg_task_t * task, const char *alias,
-                                       msg_host_t host);
-XBT_PUBLIC(msg_error_t) MSG_task_receive_from_host_bounded(msg_task_t * task, const char *alias,
-                                       msg_host_t host, double rate);
-
 XBT_PUBLIC(msg_error_t) MSG_task_execute(msg_task_t task);
 XBT_PUBLIC(msg_error_t) MSG_parallel_task_execute(msg_task_t task);
 XBT_PUBLIC(void) MSG_task_set_priority(msg_task_t task, double priority);
@@ -459,20 +417,14 @@ XBT_PUBLIC(msg_error_t)
     MSG_task_receive_ext_bounded(msg_task_t * task, const char *alias, double timeout,
                      msg_host_t host, double rate);
 
-XBT_PUBLIC(msg_error_t)
-    MSG_task_receive_with_timeout_bounded(msg_task_t * task, const char *alias,
-                              double timeout, double rate);
-
-XBT_PUBLIC(msg_error_t)
-    MSG_task_receive_bounded(msg_task_t * task, const char *alias,double rate);
+XBT_PUBLIC(msg_error_t) MSG_task_receive_with_timeout_bounded(msg_task_t * task, const char *alias,  double timeout, double rate);
+XBT_PUBLIC(msg_error_t) MSG_task_receive_bounded(msg_task_t * task, const char *alias,double rate);
 #define MSG_task_recv_bounded(t,a,r) MSG_task_receive_bounded(t,a,r)
 
 XBT_PUBLIC(msg_comm_t) MSG_task_isend(msg_task_t task, const char *alias);
 XBT_PUBLIC(msg_comm_t) MSG_task_isend_bounded(msg_task_t task, const char *alias, double maxrate);
-XBT_PUBLIC(msg_comm_t) MSG_task_isend_with_matching(msg_task_t task,
-                                                    const char *alias,
-                                                    int (*match_fun)(void*,void*, smx_synchro_t),
-                                                    void *match_data);
+XBT_PUBLIC(msg_comm_t) MSG_task_isend_with_matching(msg_task_t task, const char *alias,
+    int (*match_fun)(void*,void*, smx_synchro_t), void *match_data);
 
 XBT_PUBLIC(void) MSG_task_dsend(msg_task_t task, const char *alias, void_f_pvoid_t cleanup);
 XBT_PUBLIC(void) MSG_task_dsend_bounded(msg_task_t task, const char *alias, void_f_pvoid_t cleanup, double maxrate);
@@ -482,106 +434,68 @@ XBT_PUBLIC(int) MSG_comm_test(msg_comm_t comm);
 XBT_PUBLIC(int) MSG_comm_testany(xbt_dynar_t comms);
 XBT_PUBLIC(void) MSG_comm_destroy(msg_comm_t comm);
 XBT_PUBLIC(msg_error_t) MSG_comm_wait(msg_comm_t comm, double timeout);
-XBT_PUBLIC(void) MSG_comm_waitall(msg_comm_t * comm, int nb_elem,
-                                  double timeout);
+XBT_PUBLIC(void) MSG_comm_waitall(msg_comm_t * comm, int nb_elem, double timeout);
 XBT_PUBLIC(int) MSG_comm_waitany(xbt_dynar_t comms);
 XBT_PUBLIC(msg_task_t) MSG_comm_get_task(msg_comm_t comm);
 XBT_PUBLIC(msg_error_t) MSG_comm_get_status(msg_comm_t comm);
 
 XBT_PUBLIC(int) MSG_task_listen(const char *alias);
-
-XBT_PUBLIC(int) MSG_task_listen_from_host(const char *alias,
-                                          msg_host_t host);
-
-XBT_PUBLIC(msg_error_t)
-    MSG_task_send_with_timeout(msg_task_t task, const char *alias,
-                           double timeout);
-
-XBT_PUBLIC(msg_error_t)
-    MSG_task_send_with_timeout_bounded(msg_task_t task, const char *alias,
-                           double timeout, double maxrate);
-
-XBT_PUBLIC(msg_error_t)
-    MSG_task_send(msg_task_t task, const char *alias);
-
-XBT_PUBLIC(msg_error_t)
-    MSG_task_send_bounded(msg_task_t task, const char *alias, double rate);
-
+XBT_PUBLIC(msg_error_t) MSG_task_send_with_timeout(msg_task_t task, const char *alias, double timeout);
+XBT_PUBLIC(msg_error_t) MSG_task_send_with_timeout_bounded(msg_task_t task, const char *alias, double timeout, double maxrate);
+XBT_PUBLIC(msg_error_t) MSG_task_send(msg_task_t task, const char *alias);
+XBT_PUBLIC(msg_error_t) MSG_task_send_bounded(msg_task_t task, const char *alias, double rate);
 XBT_PUBLIC(int) MSG_task_listen_from(const char *alias);
-
 XBT_PUBLIC(void) MSG_task_set_category (msg_task_t task, const char *category);
 XBT_PUBLIC(const char *) MSG_task_get_category (msg_task_t task);
 
-/************************** Task handling ************************************/
-XBT_PUBLIC(msg_error_t)
-    MSG_mailbox_get_task_ext(msg_mailbox_t mailbox, msg_task_t * task,
-                         msg_host_t host, double timeout);
+/************************** Mailbox handling ************************************/
+/* @brief MSG_mailbox_new - create a new mailbox.
+ * Creates a new mailbox identified by the key specified by the parameter alias and add it in the global dictionary.
+ * @param  alias  The alias of the mailbox to create.
+ * @return        The newly created mailbox.
+ */
+XBT_PUBLIC(msg_mailbox_t) MSG_mailbox_new(const char *alias);
 
-XBT_PUBLIC(msg_error_t)
-    MSG_mailbox_get_task_ext_bounded(msg_mailbox_t mailbox, msg_task_t *task,
-                                     msg_host_t host, double timeout, double rate);
+/* @brief MSG_mailbox_get_by_alias - get a mailbox from its alias.
+ * Returns the mailbox associated with the key specified by the parameter alias. If the mailbox does not exists,
+ * the function creates it.
+ * @param   alias    The alias of the mailbox to return.
+ * @return           The mailbox associated with the alias specified as parameter or a new one if the key doesn't match.
+ */
+XBT_PUBLIC(msg_mailbox_t) MSG_mailbox_get_by_alias(const char *alias);
 
-XBT_PUBLIC(msg_error_t)
-    MSG_mailbox_put_with_timeout(msg_mailbox_t mailbox, msg_task_t task,
-                             double timeout);
+/* @brief MSG_mailbox_is_empty - test if a mailbox is empty.
+ * Tests if a mailbox is empty (contains no msg task).
+ * @param   mailbox  The mailbox to get test.
+ * @return           1 if the mailbox is empty, 0 otherwise.
+ */
+XBT_PUBLIC(int) MSG_mailbox_is_empty(msg_mailbox_t mailbox);
 
+/* @brief MSG_mailbox_set_async - set a mailbox as eager
+ * Sets the mailbox to a permanent receiver mode. Messages sent to this mailbox will then be sent just after the send
+ * is issued, without waiting for the corresponding receive.
+ * This call should be done before issuing any receive, and on the receiver's side only
+ * @param alias    The alias of the mailbox to modify.
+ */
 XBT_PUBLIC(void) MSG_mailbox_set_async(const char *alias);
 
+/* @brief MSG_mailbox_get_head - get the task at the head of a mailbox.
+ * Returns the task at the head of the mailbox. This function does not remove the task from the mailbox.
+ * @param   mailbox  The mailbox concerned by the operation.
+ * @return           The task at the head of the mailbox.
+ */
+XBT_PUBLIC(msg_task_t) MSG_mailbox_get_head(msg_mailbox_t mailbox);
+
+XBT_PUBLIC(msg_error_t) MSG_mailbox_get_task_ext(msg_mailbox_t mailbox, msg_task_t * task, msg_host_t host,
+                                                 double timeout);
+XBT_PUBLIC(msg_error_t) MSG_mailbox_get_task_ext_bounded(msg_mailbox_t mailbox, msg_task_t *task, msg_host_t host,
+                                                         double timeout, double rate);
 
 /************************** Action handling **********************************/
 XBT_PUBLIC(msg_error_t) MSG_action_trace_run(char *path);
 XBT_PUBLIC(void) MSG_action_init(void);
 XBT_PUBLIC(void) MSG_action_exit(void);
 
-#ifdef MSG_USE_DEPRECATED
-
-typedef msg_error_t MSG_error_t;
-
-#define MSG_global_init(argc, argv)      MSG_init(argc,argv)
-#define MSG_global_init_args(argc, argv) MSG_init(argc,argv)
-
-/* these are the functions which are deprecated. Do not use them, they may get removed in future releases */
-XBT_PUBLIC(msg_host_t *) MSG_get_host_table(void);
-
-#define MSG_host_is_avail(h) MSG_host_is_on(h)
-
-#define MSG_TIMEOUT_FAILURE MSG_TIMEOUT
-#define MSG_TASK_CANCELLED MSG_TASK_CANCELED
-#define MSG_mailbox_put_with_time_out(mailbox, task, timeout) \
-        MSG_mailbox_put_with_timeout(mailbox, task, timeout)
-
-#define MSG_process_change_host(h) MSG_process_migrate(MSG_process_self(),h);
-XBT_PUBLIC(msg_error_t) MSG_get_errno(void);
-
-XBT_PUBLIC(msg_error_t) MSG_clean(void);
-
-XBT_PUBLIC(msg_error_t) MSG_task_get(msg_task_t * task, m_channel_t channel);
-XBT_PUBLIC(msg_error_t) MSG_task_get_with_timeout(msg_task_t * task,
-                                                  m_channel_t channel,
-                                                  double max_duration);
-XBT_PUBLIC(msg_error_t) MSG_task_get_from_host(msg_task_t * task,
-                                               int channel, msg_host_t host);
-XBT_PUBLIC(msg_error_t) MSG_task_get_ext(msg_task_t * task, int channel,
-                                         double max_duration,
-                                         msg_host_t host);
-XBT_PUBLIC(msg_error_t) MSG_task_put(msg_task_t task, msg_host_t dest,
-                                     m_channel_t channel);
-XBT_PUBLIC(msg_error_t) MSG_task_put_bounded(msg_task_t task,
-                                             msg_host_t dest,
-                                             m_channel_t channel,
-                                             double max_rate);
-XBT_PUBLIC(msg_error_t) MSG_task_put_with_timeout(msg_task_t task,
-                                                  msg_host_t dest,
-                                                  m_channel_t channel,
-                                                  double max_duration);
-XBT_PUBLIC(int) MSG_task_Iprobe(m_channel_t channel);
-XBT_PUBLIC(int) MSG_task_probe_from(m_channel_t channel);
-XBT_PUBLIC(int) MSG_task_probe_from_host(int channel, msg_host_t host);
-
-XBT_PUBLIC(msg_error_t) MSG_set_channel_number(int number);
-XBT_PUBLIC(int) MSG_get_channel_number(void);
-#endif
-
 /** @brief Opaque type representing a semaphore
  *  @ingroup msg_synchro
  *  @hideinitializer
