@@ -8,16 +8,12 @@
 #define _SURF_SURF_ROUTING_H
 
 #include "xbt/lib.h"
-#include "simgrid/platf.h"
 
 SG_BEGIN_DECL()
 
-XBT_PUBLIC_DATA(xbt_lib_t) host_lib;
-XBT_PUBLIC_DATA(int) SURF_HOST_LEVEL;     //Surf workstation level
+XBT_PUBLIC_DATA(xbt_dict_t) host_list;
 XBT_PUBLIC_DATA(int) SIMIX_STORAGE_LEVEL; //Simix storage level
-XBT_PUBLIC_DATA(int) SD_STORAGE_LEVEL;    //Simdag storage level
 XBT_PUBLIC_DATA(int) COORD_HOST_LEVEL;    //Coordinates level
-XBT_PUBLIC_DATA(int) NS3_HOST_LEVEL;      //host node for ns3
 
 XBT_PUBLIC_DATA(xbt_lib_t) as_router_lib;
 XBT_PUBLIC_DATA(int) ROUTING_ASR_LEVEL;  //Routing level
@@ -33,12 +29,6 @@ XBT_PUBLIC_DATA(xbt_lib_t) file_lib;
 XBT_PUBLIC_DATA(xbt_lib_t) storage_type_lib;
 XBT_PUBLIC_DATA(int) ROUTING_STORAGE_TYPE_LEVEL;   //Routing storage_type level
 
-/* The callbacks to register for the routing to work */
-void routing_AS_begin(sg_platf_AS_cbarg_t AS);
-void routing_AS_end(sg_platf_AS_cbarg_t AS);
-
-void routing_cluster_add_backbone(void* bb);
-
 SG_END_DECL()
 
 #endif                          /* _SURF_SURF_H */
