@@ -18,9 +18,8 @@ SG_BEGIN_DECL()
 /** @addtogroup XBT_dict
  *  @brief The dictionary data structure (comparable to hash tables)
  *
- *  This section describes the API to a dictionary structure that
- *  associates as string to a void* key. It provides the same
- *  functionality than an hash table.
+ *  This section describes the API to a dictionary structure that  associates as string to a void* key. It provides the
+ *  same functionality than an hash table.
  *
  *  Here is a little example of use:
 
@@ -44,7 +43,6 @@ SG_BEGIN_DECL()
  */
 
   /** \brief Dictionary data type (opaque structure) */
-
 typedef struct s_xbt_dict *xbt_dict_t;
 typedef struct s_xbt_dictelm *xbt_dictelm_t;
 typedef struct s_xbt_dictelm {
@@ -71,8 +69,7 @@ XBT_PUBLIC(unsigned int) xbt_dict_size(xbt_dict_t dict);
  *  @{
  */
 
-XBT_PUBLIC(void) xbt_dict_set(xbt_dict_t dict, const char *key, void *data,
-                              void_f_pvoid_t free_ctn);
+XBT_PUBLIC(void) xbt_dict_set(xbt_dict_t dict, const char *key, void *data, void_f_pvoid_t free_ctn);
 XBT_PUBLIC(void *) xbt_dict_get(xbt_dict_t dict, const char *key);
 XBT_PUBLIC(void *) xbt_dict_get_or_null(xbt_dict_t dict, const char *key);
 XBT_PUBLIC(char *) xbt_dict_get_key(xbt_dict_t dict, const void *data);
@@ -97,22 +94,10 @@ XBT_PUBLIC(int) xbt_dict_is_empty(xbt_dict_t dict);
  *
  *  @{
  */
-XBT_PUBLIC(void) xbt_dict_set_ext(xbt_dict_t dict,
-                                  const char *key, int key_len,
-                                  void *data, void_f_pvoid_t free_ctn);
-XBT_PUBLIC(void *) xbt_dict_get_ext(xbt_dict_t dict, const char *key,
-                                    int key_len);
-XBT_PUBLIC(void *) xbt_dict_get_or_null_ext(xbt_dict_t dict,
-                                            const char *key, int key_len);
-XBT_PUBLIC(void) xbt_dict_remove_ext(xbt_dict_t dict, const char *key,
-                                     int key_len);
-
-#ifdef XBT_USE_DEPRECATED
-XBT_PUBLIC(void) xbt_dicti_set(xbt_dict_t dict, uintptr_t key,
-                               uintptr_t data);
-XBT_PUBLIC(uintptr_t) xbt_dicti_get(xbt_dict_t dict, uintptr_t key);
-XBT_PUBLIC(void) xbt_dicti_remove(xbt_dict_t dict, uintptr_t key);
-#endif
+XBT_PUBLIC(void) xbt_dict_set_ext(xbt_dict_t dict, const char *key, int key_len, void *data, void_f_pvoid_t free_ctn);
+XBT_PUBLIC(void *) xbt_dict_get_ext(xbt_dict_t dict, const char *key, int key_len);
+XBT_PUBLIC(void *) xbt_dict_get_or_null_ext(xbt_dict_t dict, const char *key, int key_len);
+XBT_PUBLIC(void) xbt_dict_remove_ext(xbt_dict_t dict, const char *key, int key_len);
 
 struct s_xbt_dict_cursor {
   xbt_dictelm_t current;
@@ -124,12 +109,12 @@ struct s_xbt_dict_cursor {
 /** @defgroup XBT_dict_curs Cursors on dictionaries
  *  @ingroup XBT_dict
  *
- *  Don't get impressed, there is a lot of functions here, but traversing a
- *  dictionary is immediate with the xbt_dict_foreach macro.
+ *  Don't get impressed, there is a lot of functions here, but traversing a dictionary is immediate with the
+ *  xbt_dict_foreach macro.
  *  You only need the other functions in rare cases (they are not used directly in SG itself).
  *
- *  Here is an example (assuming that the dictionary contains strings, ie
- *  that the <tt>data</tt> argument of xbt_dict_set was always a null-terminated char*):
+ *  Here is an example (assuming that the dictionary contains strings, i.e., that the <tt>data</tt> argument of
+ *  xbt_dict_set was always a null-terminated char*):
 \verbatim xbt_dict_cursor_t cursor=NULL;
  char *key,*data;
 
@@ -142,7 +127,7 @@ struct s_xbt_dict_cursor {
  *
  *  @{ */
 
-  /** @brief Cursor on dictionaries (opaque type) */
+/** @brief Cursor on dictionaries (opaque type) */
 typedef struct s_xbt_dict_cursor *xbt_dict_cursor_t;
 
 static inline xbt_dictelm_t xbt_dict_cursor_get_elm(xbt_dict_cursor_t cursor) {
@@ -157,15 +142,11 @@ XBT_PUBLIC(void) xbt_dict_cursor_rewind(xbt_dict_cursor_t cursor);
 xbt_dictelm_t xbt_dict_cursor_get_elm(xbt_dict_cursor_t cursor);
 XBT_PUBLIC(char *) xbt_dict_cursor_get_key(xbt_dict_cursor_t cursor);
 XBT_PUBLIC(void *) xbt_dict_cursor_get_data(xbt_dict_cursor_t cursor);
-XBT_PUBLIC(void) xbt_dict_cursor_set_data(xbt_dict_cursor_t cursor,
-                                          void *data,
-                                          void_f_pvoid_t free_ctn);
+XBT_PUBLIC(void) xbt_dict_cursor_set_data(xbt_dict_cursor_t cursor, void *data, void_f_pvoid_t free_ctn);
 
-XBT_PUBLIC(void) xbt_dict_cursor_first(const xbt_dict_t dict,
-                                       xbt_dict_cursor_t * cursor);
+XBT_PUBLIC(void) xbt_dict_cursor_first(const xbt_dict_t dict, xbt_dict_cursor_t * cursor);
 XBT_PUBLIC(void) xbt_dict_cursor_step(xbt_dict_cursor_t cursor);
-XBT_PUBLIC(int) xbt_dict_cursor_get_or_free(xbt_dict_cursor_t * cursor,
-                                            char **key, void **data);
+XBT_PUBLIC(int) xbt_dict_cursor_get_or_free(xbt_dict_cursor_t * cursor, char **key, void **data);
 /** @def xbt_dict_foreach
  *  @param dict a \ref xbt_dict_t iterator
  *  @param cursor an \ref xbt_dict_cursor_t used as cursor
@@ -191,44 +172,17 @@ xbt_dict_foreach(head, cursor, key, data) {
 
 /** @} */
 
-#ifdef XBT_USE_DEPRECATED
-/** @defgroup XBT_dict_multi Multi-level dictionaries
- *  @ingroup XBT_dict
- *
- * They can be seen as dictionary of multiple keys or as dictionary of
- * dictionary of ... of data. Most of the functions here work the same way
- * than their simple dictionary counterpart.
- *
- * Note that there is no xbt_multidict_free neither xbt_multi_dict_new functions.
- * Use xbt_dict_free() and xbt_dict_new() instead.
- *
- * @{
- */
+SG_END_DECL()
 
-/*----[ xbt_multidict_set ]--------------------------------------------------*/
-XBT_PUBLIC(void)
-xbt_multidict_set(xbt_dict_t mdict,
-                  xbt_dynar_t keys, void *data, void (*free_ctn) (void *));
-XBT_PUBLIC(void)
-xbt_multidict_set_ext(xbt_dict_t mdict,
-                      xbt_dynar_t keys, xbt_dynar_t lens,
-                      void *data, void_f_pvoid_t free_ctn);
-
-/*----[ xbt_multidict_get ]--------------------------------------------------*/
-XBT_PUBLIC(void *) xbt_multidict_get(xbt_dict_t mdict, xbt_dynar_t keys);
-XBT_PUBLIC(void *) xbt_multidict_get_ext(xbt_dict_t mdict,
-                                         xbt_dynar_t keys,
-                                         xbt_dynar_t lens);
-
-/*----[ xbt_multidict_remove ]-----------------------------------------------*/
-/*---------------------------------------------------------------------------*/
-XBT_PUBLIC(void) xbt_multidict_remove(xbt_dict_t mdict, xbt_dynar_t keys);
-XBT_PUBLIC(void) xbt_multidict_remove_ext(xbt_dict_t mdict,
-                                          xbt_dynar_t keys,
-                                          xbt_dynar_t lens);
-
-/** @} */
+#ifdef __cplusplus
+namespace simgrid {
+namespace xbt {
+  inline void destroy(xbt_dict_t d)
+  {
+    xbt_dict_free(&d);
+  }
+}
+}
 #endif
 
-SG_END_DECL()
 #endif                          /* _XBT_DICT_H */
