@@ -15,15 +15,14 @@
 #include "xbt/str.h"
 #include "xbt/dict.h"
 
-/**
- ** Buffer code
- **/
+SG_BEGIN_DECL()
+
+/** Buffer code **/
 typedef struct {
   char *data;
   int used, size;
 } s_xbt_strbuff_t, *xbt_strbuff_t;
 
-
 XBT_PUBLIC(void) xbt_strbuff_empty(xbt_strbuff_t b);
 XBT_PUBLIC(xbt_strbuff_t) xbt_strbuff_new(void);
 XBT_PUBLIC(xbt_strbuff_t) xbt_strbuff_new_from(const char *s);
@@ -32,7 +31,7 @@ XBT_PUBLIC(void) xbt_strbuff_free_container(xbt_strbuff_t b);
 XBT_PUBLIC(void) xbt_strbuff_append(xbt_strbuff_t b, const char *toadd);
 XBT_PUBLIC(void) xbt_strbuff_chomp(xbt_strbuff_t b);
 XBT_PUBLIC(void) xbt_strbuff_trim(xbt_strbuff_t b);
-XBT_PUBLIC(void) xbt_strbuff_varsubst(xbt_strbuff_t b,
-                                      xbt_dict_t patterns);
+XBT_PUBLIC(void) xbt_strbuff_varsubst(xbt_strbuff_t b, xbt_dict_t patterns);
 
+SG_END_DECL()
 #endif
