@@ -11,10 +11,6 @@
 #ifndef _XBT_SYSDEP_H
 #define _XBT_SYSDEP_H
 
-#ifdef __cplusplus
-#include <type_traits>
-#endif
-
 #include "xbt/log.h"
 #include "xbt/misc.h"
 #include "xbt/asserts.h"
@@ -41,11 +37,9 @@ XBT_PUBLIC(void) XBT_ATTRIB_NORETURN xbt_abort(void);
  * @brief Kill the program with an error message
  * \param ... a format string and its arguments
  *
- * Things are so messed up that the only thing to do now, is to stop the
- * program.
+ * Things are so messed up that the only thing to do now, is to stop the program.
  *
- * The message is handled by a CRITICAL logging request, and may consist of a
- * format string with arguments.
+ * The message is handled by a CRITICAL logging request, and may consist of a format string with arguments.
  */
 #define xbt_die(...)                            \
   do {                                          \
@@ -60,25 +54,12 @@ XBT_LOG_NEW_CATEGORY(xbt, "All XBT categories (simgrid toolbox)");
 XBT_LOG_EXTERNAL_CATEGORY(xbt);
 #endif
 
-/* these ones live in str.h, but redeclare them here so that we do
-   not need to load the whole str.h and its heavy dependencies */
-#ifndef __USE_GNU               /* do not redeclare existing headers */
-XBT_PUBLIC(int) asprintf(char **ptr, const char *fmt,   /*args */
-                         ...) XBT_ATTRIB_PRINTF(2, 3);
-XBT_PUBLIC(int) vasprintf(char **ptr, const char *fmt, va_list ap);
-#endif
-XBT_PUBLIC(char *) bprintf(const char *fmt, ...) XBT_ATTRIB_PRINTF(1, 2);
-
 /** @addtogroup XBT_syscall
  *  @brief Malloc and associated functions, killing the program on error (with \ref XBT_ex)
  *
  *  @{
  */
 
-#if defined(_MSC_VER) && !defined(strdup)
-#  define strdup _strdup /* POSIX name is not ANSI complient blabla */
-#endif
-
 /** @brief Like strdup, but xbt_die() on error */
 static XBT_ALWAYS_INLINE char *xbt_strdup(const char *s) {
   char *res = NULL;
@@ -148,42 +129,11 @@ XBT_PUBLIC(void) xbt_free_ref(void *d);
 
 SG_END_DECL()
 
-/** @brief like calloc, but xbt_die() on error and don't memset to 0
-    @hideinitializer */
-#ifndef __cplusplus
-
 #define xbt_new(type, count)  ((type*)xbt_malloc (sizeof (type) * (count)))
 /** @brief like calloc, but xbt_die() on error
     @hideinitializer */
 #define xbt_new0(type, count) ((type*)xbt_malloc0 (sizeof (type) * (count)))
 
-#else
-
-/** C++ wrapper for xtb_new
- *
- *  This ensures that we do not xbt_new things that need a constructor.
- */
-template<typename T> inline
-T* xbt_new_(size_t count)
-{
-  static_assert(std::is_trivial<T>(),
-    "Cannot xbt_new this type");
-  return (T*) xbt_malloc(sizeof(T) * count);
-}
-
-template<typename T> inline
-T* xbt_new0_(size_t count)
-{
-  static_assert(std::is_trivial<T>(),
-    "Cannot xbt_new0 this type");
-  return (T*) xbt_malloc0(sizeof(T) * count);
-}
-
-#define xbt_new(type, count)  ::xbt_new_<type>(count)
-#define xbt_new0(type, count) ::xbt_new0_<type>(count)
-
-#endif
-
 /** @} */
 
 #endif                          /* _XBT_SYSDEP_H */
