@@ -13,6 +13,7 @@ public class As {
 	protected As() {
 	};
 
+	@Override
 	public String toString (){
 		return this.getName(); 
 	}
@@ -22,8 +23,6 @@ public class As {
 
 	public native String getProperty(String name);
 
-	public native String getModel();
-
 	public native Host[] getHosts();
 
 	/**
