@@ -7,6 +7,7 @@
 #ifndef SIMGRID_LUA_H
 #define SIMGRID_LUA_H
 
+extern "C" {
 #include <lua.h>
 
 /* ********************************************************************************* */
@@ -16,13 +17,16 @@
 int console_open(lua_State *L);
 int console_close(lua_State *L);
 
+int console_add_backbone(lua_State*);
+int console_add_host___link(lua_State*);
 int console_add_host(lua_State*);
 int console_add_link(lua_State*);
 int console_add_router(lua_State* L);
 int console_add_route(lua_State*);
+int console_add_ASroute(lua_State*);
 int console_AS_open(lua_State*);
-int console_AS_close(lua_State *L);
+int console_AS_seal(lua_State *L);
 int console_set_function(lua_State*);
 int console_host_set_property(lua_State*);
-
+}
 #endif  /* SIMGRID_LUA_H */
