@@ -7,39 +7,25 @@
 #ifndef MC_DATATYPE_H
 #define MC_DATATYPE_H
 
-#include "xbt/misc.h"
-#include "xbt/swag.h"
-#include "xbt/fifo.h"
+#include <src/internal_config.h>
+#include <xbt/base.h>
 
-#if HAVE_MC
-#include <libunwind.h>
-#include <dwarf.h>
-#endif 
+#if HAVE_UCONTEXT_H
+#include <ucontext.h>           /* context relative declarations */
+#endif
 
 SG_BEGIN_DECL()
 
-/******************************* Transitions **********************************/
-
-typedef struct s_mc_transition *mc_transition_t;
-
-/*********** Structures for snapshot comparison **************************/
-
-typedef struct s_mc_heap_ignore_region{
-  int block;
-  int fragment;
-  void *address;
-  size_t size;
-}s_mc_heap_ignore_region_t, *mc_heap_ignore_region_t;
-
 typedef struct s_stack_region{
   void *address;
-  void *context;
+#if HAVE_UCONTEXT_H
+  ucontext_t* context;
+#endif
   size_t size;
   int block;
   int process_index;
 }s_stack_region_t, *stack_region_t;
 
-/************ DWARF structures *************/
-
 SG_END_DECL()
+
 #endif                          /* _MC_MC_H */
