@@ -11,7 +11,7 @@
 
 #include "simgrid/instr.h"
 #include "instr/instr_interface.h"
-#include "internal_config.h"
+#include "src/internal_config.h"
 #include "simgrid_config.h"
 
 SG_BEGIN_DECL()
@@ -26,7 +26,6 @@ SG_BEGIN_DECL()
 
 #include "xbt/graph.h"
 #include "xbt/dict.h"
-#include "simgrid/platf.h"
 
 typedef enum {
   PAJE_DefineContainerType,
@@ -89,7 +88,7 @@ typedef enum {
 
 typedef struct s_container *container_t;
 typedef struct s_container {
-  sg_routing_edge_t net_elm;
+  sg_netcard_t netcard;
   char *name;     /* Unique name of this container */
   char *id;       /* Unique id of this container */
   type_t type;    /* Type of this container */
@@ -256,12 +255,16 @@ XBT_PUBLIC(void) new_pajeAddVariable (double timestamp, container_t container, t
 XBT_PUBLIC(void) new_pajeSubVariable (double timestamp, container_t container, type_t type, double value);
 XBT_PUBLIC(void) new_pajeSetState (double timestamp, container_t container, type_t type, val_t value);
 XBT_PUBLIC(void) new_pajePushState (double timestamp, container_t container, type_t type, val_t value);
-XBT_PUBLIC(void) new_pajePushStateWithExtra (double timestamp, container_t container, type_t type, val_t value, void* extra);
+XBT_PUBLIC(void) new_pajePushStateWithExtra (double timestamp, container_t container, type_t type, val_t value,
+                                             void* extra);
 XBT_PUBLIC(void) new_pajePopState (double timestamp, container_t container, type_t type);
 XBT_PUBLIC(void) new_pajeResetState (double timestamp, container_t container, type_t type);
-XBT_PUBLIC(void) new_pajeStartLink (double timestamp, container_t container, type_t type, container_t sourceContainer, const char *value, const char *key);
-XBT_PUBLIC(void) new_pajeStartLinkWithSize (double timestamp, container_t container, type_t type, container_t sourceContainer, const char *value, const char *key, int size);
-XBT_PUBLIC(void) new_pajeEndLink (double timestamp, container_t container, type_t type, container_t destContainer, const char *value, const char *key);
+XBT_PUBLIC(void) new_pajeStartLink (double timestamp, container_t container, type_t type, container_t sourceContainer,
+                                    const char *value, const char *key);
+XBT_PUBLIC(void) new_pajeStartLinkWithSize (double timestamp, container_t container, type_t type,
+                                            container_t sourceContainer, const char *value, const char *key, int size);
+XBT_PUBLIC(void) new_pajeEndLink (double timestamp, container_t container, type_t type, container_t destContainer,
+                                  const char *value, const char *key);
 XBT_PUBLIC(void) new_pajeNewEvent (double timestamp, container_t container, type_t type, val_t value);
 
 /* from instr_config.c */
@@ -276,7 +279,7 @@ XBT_PRIVATE int TRACE_msg_process_is_enabled(void);
 XBT_PRIVATE int TRACE_msg_vm_is_enabled(void);
 XBT_PRIVATE int TRACE_buffer (void);
 XBT_PRIVATE int TRACE_disable_link(void);
-XBT_PRIVATE int TRACE_disable_power(void);
+XBT_PRIVATE int TRACE_disable_speed(void);
 XBT_PRIVATE int TRACE_onelink_only (void);
 XBT_PRIVATE int TRACE_disable_destroy (void);
 XBT_PRIVATE int TRACE_basic (void);
@@ -300,15 +303,9 @@ XBT_PUBLIC(int) TRACE_smpi_is_sleeping(void);
 XBT_PUBLIC(int) TRACE_smpi_view_internals(void);
 
 /* from resource_utilization.c */
-XBT_PRIVATE void TRACE_surf_host_set_utilization(const char *resource,
-                                     const char *category,
-                                     double value,
-                                     double now,
+XBT_PRIVATE void TRACE_surf_host_set_utilization(const char *resource, const char *category, double value, double now,
                                      double delta);
-XBT_PRIVATE void TRACE_surf_link_set_utilization(const char *resource,
-                                     const char *category,
-                                     double value,
-                                     double now,
+XBT_PRIVATE void TRACE_surf_link_set_utilization(const char *resource,const char *category, double value, double now,
                                      double delta);
 XBT_PUBLIC(void) TRACE_surf_resource_utilization_alloc(void);
 
@@ -378,9 +375,6 @@ XBT_PRIVATE void TRACE_paje_dump_buffer (int force);
 XBT_PRIVATE void dump_comment_file (const char *filename);
 XBT_PRIVATE void dump_comment (const char *comment);
 
-
-
-
 typedef struct instr_trace_writer {
   void (*print_DefineContainerType) (paje_event_t event);
   void (*print_DefineVariableType)(paje_event_t event);
@@ -402,12 +396,9 @@ typedef struct instr_trace_writer {
   void (*print_NewEvent) (paje_event_t event);
 } s_instr_trace_writer_t;
 
-
-
 struct s_instr_extra_data;
 typedef struct s_instr_extra_data *instr_extra_data;
 
-
 typedef enum{
   TRACING_INIT,
   TRACING_FINALIZE,
@@ -444,8 +435,6 @@ typedef enum{
   TRACING_EXSCAN
 } e_caller_type ;
 
-
-
 typedef struct s_instr_extra_data {
   e_caller_type type;
   int send_size;
@@ -464,8 +453,8 @@ typedef struct s_instr_extra_data {
 
 SG_END_DECL()
 
-#ifdef HAVE_JEDULE
-#include "instr/jedule/jedule_sd_binding.h"
+#if HAVE_JEDULE
+#include "simgrid/jedule/jedule_sd_binding.h"
 #endif
 
 #endif /* INSTR_PRIVATE_H_ */
