@@ -9,15 +9,13 @@
 
 #include <sys/mman.h>
 
-#include <boost/foreach.hpp>
+#include <xbt/base.h>
+#include <xbt/log.h>
+#include <xbt/sysdep.h>
 
-#include <xbt.h>
+#include "src/mc/PageStore.hpp"
 
-#include "PageStore.hpp"
-
-#include "mc_mmu.h"
-
-extern "C" {
+#include "src/mc/mc_mmu.h"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_page_snapshot, mc,
                                 "Logging specific to mc_page_snapshot");
@@ -41,24 +39,22 @@ PageStore::hash_type mc_hash_page(const void* data)
 
   // This djb2:
   std::uint64_t hash = 5381;
-  for (std::size_t i = 0; i != n; ++i) {
+  for (std::size_t i = 0; i != n; ++i)
     hash = ((hash << 5) + hash) + values[i];
-  }
   return hash;
 }
 
 // ***** snapshot_page_manager
 
 PageStore::PageStore(size_t size) :
-  memory_(NULL), capacity_(0), top_index_(0)
+  memory_(nullptr), capacity_(0), top_index_(0)
 {
   // Using mmap in order to be able to expand the region
   // by relocating it somewhere else in the virtual memory
   // space:
-  void* memory = ::mmap(NULL, size << xbt_pagebits, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS|MAP_POPULATE, -1, 0);
-  if (memory == MAP_FAILED) {
+  void* memory = ::mmap(nullptr, size << xbt_pagebits, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS|MAP_POPULATE, -1, 0);
+  if (memory == MAP_FAILED)
     xbt_die("Could not mmap initial snapshot pages.");
-  }
 
   this->top_index_ = 0;
   this->capacity_ = size;
@@ -79,9 +75,8 @@ void PageStore::resize(std::size_t size)
   // Expand the memory region by moving it into another
   // virtual memory address if necessary:
   void* new_memory = mremap(this->memory_, old_bytesize, new_bytesize, MREMAP_MAYMOVE);
-  if (new_memory == MAP_FAILED) {
+  if (new_memory == MAP_FAILED)
     xbt_die("Could not mremap snapshot pages.");
-  }
 
   this->capacity_ = size;
   this->memory_ = new_memory;
@@ -97,10 +92,9 @@ std::size_t PageStore::alloc_page()
   if (this->free_pages_.empty()) {
 
     // Expand the region:
-    if (this->top_index_ == this->capacity_) {
+    if (this->top_index_ == this->capacity_)
       // All the pages are allocated, we need add more pages:
       this->resize(2 * this->capacity_);
-    }
 
     // Use a page from the top:
     return this->top_index_++;
@@ -137,7 +131,7 @@ std::size_t PageStore::store_page(void* page)
 
   // Try to find a duplicate in set of pages with the same hash:
   page_set_type& page_set = this->hash_index_[hash];
-  BOOST_FOREACH (size_t pageno, page_set) {
+  for (size_t pageno : page_set) {
     const void* snapshot_page = this->get_page(pageno);
     if (memcmp(page, snapshot_page, xbt_pagesize) == 0) {
 
@@ -173,7 +167,7 @@ std::size_t PageStore::store_page(void* page)
 
 #include <memory>
 
-#include "mc/PageStore.hpp"
+#include "src/mc/PageStore.hpp"
 
 static int value = 0;
 
@@ -184,11 +178,9 @@ static void new_content(void* data, std::size_t size)
 
 static void* getpage()
 {
-  return mmap(NULL, getpagesize(), PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS, -1, 0);
+  return mmap(nullptr, getpagesize(), PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS, -1, 0);
 }
 
-extern "C" {
-
 XBT_TEST_SUITE("mc_page_store", "Page store");
 
 XBT_TEST_UNIT("base", test_mc_page_store, "Test adding/removing pages in the store")
@@ -237,8 +229,4 @@ XBT_TEST_UNIT("base", test_mc_page_store, "Test adding/removing pages in the sto
   xbt_test_assert(store->size()==2, "Bad size");
 }
 
-}
-
 #endif /* SIMGRID_TEST */
-
-}
