@@ -8,10 +8,13 @@
 
 #include <assert.h>
 #include <stddef.h>
-#include <stdbool.h>
 #include <stdint.h>
 #include <errno.h>
 
+#include <sys/ptrace.h>
+
+#include <cstdio>
+
 #include <sys/types.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -25,33 +28,35 @@
 #include <libunwind.h>
 #include <libunwind-ptrace.h>
 
+#include <xbt/log.h>
+#include <xbt/base.h>
 #include <xbt/mmalloc.h>
 
-#include "mc_object_info.h"
-#include "mc_unw.h"
-#include "mc_snapshot.h"
-#include "mc_ignore.h"
-#include "mc_smx.h"
-#include "mc_server.h"
+#include "src/mc/mc_unw.h"
+#include "src/mc/mc_snapshot.h"
+#include "src/mc/mc_ignore.h"
+#include "src/mc/mc_smx.h"
 
-#include "mc/Process.hpp"
-#include "mc/AddressSpace.hpp"
-#include "mc/ObjectInformation.hpp"
-#include "mc/Variable.hpp"
+#include "src/mc/Process.hpp"
+#include "src/mc/AddressSpace.hpp"
+#include "src/mc/ObjectInformation.hpp"
+#include "src/mc/Variable.hpp"
 
 using simgrid::mc::remote;
 
-extern "C" {
-
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_process, mc,
                                 "MC process information");
 
 // ***** Helper stuff
 
+namespace simgrid {
+namespace mc {
+
 #define SO_RE "\\.so[\\.0-9]*$"
 #define VERSION_RE "-[\\.0-9-]*$"
 
-static const char *const FILTERED_LIBS[] = {
+// In lexicographic order (but this is currently not used in the code):
+static const char *const filtered_libraries[] = {
   "ld",
   "libbz2",
   "libboost_chrono",
@@ -67,11 +72,11 @@ static const char *const FILTERED_LIBS[] = {
   "libelf",
   "libgcc_s",
   "liblua5.1",
+  "liblua5.3",
   "liblzma",
   "libm",
   "libpthread",
   "librt",
-  "libsigc",
   "libstdc++",
   "libunwind",
   "libunwind-x86_64",
@@ -80,14 +85,14 @@ static const char *const FILTERED_LIBS[] = {
   "libz"
 };
 
-static bool MC_is_simgrid_lib(const char* libname)
+static bool is_simgrid_lib(const char* libname)
 {
   return !strcmp(libname, "libsimgrid");
 }
 
-static bool MC_is_filtered_lib(const char* libname)
+static bool is_filtered_lib(const char* libname)
 {
-  for (const char* filtered_lib : FILTERED_LIBS)
+  for (const char* filtered_lib : filtered_libraries)
     if (strcmp(libname, filtered_lib)==0)
       return true;
   return false;
@@ -98,15 +103,19 @@ struct s_mc_memory_map_re {
   regex_t version_re;
 };
 
-static char* MC_get_lib_name(const char* pathname, struct s_mc_memory_map_re* res)
+static char* get_lib_name(const char* pathname, struct s_mc_memory_map_re* res)
 {
-  const char* map_basename = basename((char*) pathname);
+  char* map_basename = xbt_basename(pathname);
 
   regmatch_t match;
-  if(regexec(&res->so_re, map_basename, 1, &match, 0))
-    return NULL;
+  if(regexec(&res->so_re, map_basename, 1, &match, 0)) {
+    free(map_basename);
+    return nullptr;
+  }
 
   char* libname = strndup(map_basename, match.rm_so);
+  free(map_basename);
+  map_basename = nullptr;
 
   // Strip the version suffix:
   if(libname && !regexec(&res->version_re, libname, 1, &match, 0)) {
@@ -128,9 +137,9 @@ static ssize_t pread_whole(int fd, void *buf, size_t count, std::uint64_t offset
       count  -= res;
       buffer += res;
       offset += res;
-    } else if (res==0) {
+    } else if (res==0)
       return -1;
-    } else if (errno != EINTR) {
+    else if (errno != EINTR) {
       perror("pread_whole");
       return -1;
     }
@@ -148,11 +157,10 @@ static ssize_t pwrite_whole(int fd, const void *buf, size_t count, off_t offset)
       count  -= res;
       buffer += res;
       offset += res;
-    } else if (res==0) {
+    } else if (res==0)
       return -1;
-    } else if (errno != EINTR) {
+    else if (errno != EINTR)
       return -1;
-    }
   }
   return real_count;
 }
@@ -161,30 +169,17 @@ static pthread_once_t zero_buffer_flag = PTHREAD_ONCE_INIT;
 static const void* zero_buffer;
 static const size_t zero_buffer_size = 10 * 4096;
 
-static void MC_zero_buffer_init(void)
+static void zero_buffer_init(void)
 {
   int fd = open("/dev/zero", O_RDONLY);
   if (fd<0)
     xbt_die("Could not open /dev/zero");
-  zero_buffer = mmap(NULL, zero_buffer_size, PROT_READ, MAP_SHARED, fd, 0);
+  zero_buffer = mmap(nullptr, zero_buffer_size, PROT_READ, MAP_SHARED, fd, 0);
   if (zero_buffer == MAP_FAILED)
     xbt_die("Could not map the zero buffer");
   close(fd);
 }
 
-static
-int open_process_file(pid_t pid, const char* file, int flags)
-{
-  char buff[50];
-  snprintf(buff, sizeof(buff), "/proc/%li/%s", (long) pid, file);
-  return open(buff, flags);
-}
-
-}
-
-namespace simgrid {
-namespace mc {
-
 int open_vm(pid_t pid, int flags)
 {
   const size_t buffer_size = 30;
@@ -197,93 +192,51 @@ int open_vm(pid_t pid, int flags)
   return open(buffer, flags);
 }
 
-  
-}
-}
-
 // ***** Process
 
-namespace simgrid {
-namespace mc {
+Process::Process(pid_t pid, int sockfd) :
+   AddressSpace(this), pid_(pid), channel_(sockfd), running_(true)
+{}
 
-Process::Process(pid_t pid, int sockfd) : AddressSpace(this)
+void Process::init()
 {
-  Process* process = this;
-  process->socket_ = sockfd;
-  process->pid_ = pid;
-  process->running_ = true;
-  process->status_ = 0;
-  process->memory_map_ = get_memory_map(pid);
-  process->cache_flags = MC_PROCESS_CACHE_FLAG_NONE;
-  process->heap = NULL;
-  process->heap_info = NULL;
-  process->init_memory_map_info();
-  process->clear_refs_fd_ = -1;
-  process->pagemap_fd_ = -1;
+  this->memory_map_ = simgrid::xbt::get_memory_map(this->pid_);
+  this->init_memory_map_info();
 
-  int fd = open_vm(process->pid_, O_RDWR);
+  int fd = open_vm(this->pid_, O_RDWR);
   if (fd<0)
     xbt_die("Could not open file for process virtual address space");
-  process->memory_file = fd;
+  this->memory_file = fd;
 
   // Read std_heap (is a struct mdesc*):
-  simgrid::mc::Variable* std_heap_var = process->find_variable("__mmalloc_default_mdp");
+  simgrid::mc::Variable* std_heap_var = this->find_variable("__mmalloc_default_mdp");
   if (!std_heap_var)
     xbt_die("No heap information in the target process");
   if(!std_heap_var->address)
     xbt_die("No constant address for this variable");
-  process->read_bytes(&process->heap_address, sizeof(struct mdesc*),
+  this->read_bytes(&this->heap_address, sizeof(struct mdesc*),
     remote(std_heap_var->address),
     simgrid::mc::ProcessIndexDisabled);
 
-  process->smx_process_infos = MC_smx_process_info_list_new();
-  process->smx_old_process_infos = MC_smx_process_info_list_new();
-  process->unw_addr_space = unw_create_addr_space(&mc_unw_accessors  , __BYTE_ORDER);
-  process->unw_underlying_addr_space = unw_create_addr_space(&mc_unw_vmread_accessors, __BYTE_ORDER);
-  process->unw_underlying_context = _UPT_create(pid);
+  this->smx_process_infos.clear();
+  this->smx_old_process_infos.clear();
+  this->unw_addr_space = simgrid::mc::UnwindContext::createUnwindAddressSpace();
+  this->unw_underlying_addr_space = simgrid::unw::create_addr_space();
+  this->unw_underlying_context = simgrid::unw::create_context(
+    this->unw_underlying_addr_space, this->pid_);
 }
 
 Process::~Process()
 {
-  Process* process = this;
+  if (this->memory_file >= 0)
+    close(this->memory_file);
 
-  if (this->socket_ >= 0 && close(this->socket_) < 0)
-    xbt_die("Could not close communication socket");
-
-  process->pid_ = 0;
-
-  process->maestro_stack_start_ = nullptr;
-  process->maestro_stack_end_ = nullptr;
-
-  xbt_dynar_free(&process->smx_process_infos);
-  xbt_dynar_free(&process->smx_old_process_infos);
-
-  if (process->memory_file >= 0) {
-    close(process->memory_file);
+  if (this->unw_underlying_addr_space != unw_local_addr_space) {
+    unw_destroy_addr_space(this->unw_underlying_addr_space);
+    _UPT_destroy(this->unw_underlying_context);
   }
 
-  if (process->unw_underlying_addr_space != unw_local_addr_space) {
-    unw_destroy_addr_space(process->unw_underlying_addr_space);
-    _UPT_destroy(process->unw_underlying_context);
-  }
-  process->unw_underlying_context = NULL;
-  process->unw_underlying_addr_space = NULL;
-
-  unw_destroy_addr_space(process->unw_addr_space);
-  process->unw_addr_space = NULL;
-
-  process->cache_flags = MC_PROCESS_CACHE_FLAG_NONE;
-
-  free(process->heap);
-  process->heap = NULL;
-
-  free(process->heap_info);
-  process->heap_info = NULL;
-
-  if (process->clear_refs_fd_ >= 0)
-    close(process->clear_refs_fd_);
-  if (process->pagemap_fd_ >= 0)
-    close(process->pagemap_fd_);
+  unw_destroy_addr_space(this->unw_addr_space);
 }
 
 /** Refresh the information about the process
@@ -293,14 +246,12 @@ Process::~Process()
  */
 void Process::refresh_heap()
 {
-  xbt_assert(mc_mode == MC_MODE_SERVER);
   // Read/dereference/refresh the std_heap pointer:
-  if (!this->heap) {
-    this->heap = (struct mdesc*) malloc(sizeof(struct mdesc));
-  }
-  this->read_bytes(this->heap, sizeof(struct mdesc), remote(this->heap_address),
-    simgrid::mc::ProcessIndexDisabled);
-  this->cache_flags |= MC_PROCESS_CACHE_FLAG_HEAP;
+  if (!this->heap)
+    this->heap = std::unique_ptr<s_xbt_mheap_t>(new s_xbt_mheap_t());
+  this->read_bytes(this->heap.get(), sizeof(struct mdesc),
+    remote(this->heap_address), simgrid::mc::ProcessIndexDisabled);
+  this->cache_flags_ |= Process::cache_heap;
 }
 
 /** Refresh the information about the process
@@ -310,16 +261,15 @@ void Process::refresh_heap()
  * */
 void Process::refresh_malloc_info()
 {
-  xbt_assert(mc_mode == MC_MODE_SERVER);
-  if (!(this->cache_flags & MC_PROCESS_CACHE_FLAG_HEAP))
-    this->refresh_heap();
   // Refresh process->heapinfo:
-  size_t malloc_info_bytesize =
-    (this->heap->heaplimit + 1) * sizeof(malloc_info);
-  this->heap_info = (malloc_info*) realloc(this->heap_info, malloc_info_bytesize);
-  this->read_bytes(this->heap_info, malloc_info_bytesize,
+  if (this->cache_flags_ & Process::cache_malloc)
+    return;
+  size_t count = this->heap->heaplimit + 1;
+  if (this->heap_info.size() < count)
+    this->heap_info.resize(count);
+  this->read_bytes(this->heap_info.data(), count * sizeof(malloc_info),
     remote(this->heap->heapinfo), simgrid::mc::ProcessIndexDisabled);
-  this->cache_flags |= MC_PROCESS_CACHE_FLAG_MALLOC_INFO;
+  this->cache_flags_ |= Process::cache_malloc;
 }
 
 /** @brief Finds the range of the different memory segments and binary paths */
@@ -329,27 +279,27 @@ void Process::init_memory_map_info()
   this->maestro_stack_start_ = nullptr;
   this->maestro_stack_end_ = nullptr;
   this->object_infos.resize(0);
-  this->binary_info = NULL;
-  this->libsimgrid_info = NULL;
+  this->binary_info = nullptr;
+  this->libsimgrid_info = nullptr;
 
   struct s_mc_memory_map_re res;
 
   if(regcomp(&res.so_re, SO_RE, 0) || regcomp(&res.version_re, VERSION_RE, 0))
     xbt_die(".so regexp did not compile");
 
-  std::vector<simgrid::mc::VmMap> const& maps = this->memory_map_;
+  std::vector<simgrid::xbt::VmMap> const& maps = this->memory_map_;
 
-  const char* current_name = NULL;
+  const char* current_name = nullptr;
 
-  this->object_infos.resize(0);
+  this->object_infos.clear();
 
   for (size_t i=0; i < maps.size(); i++) {
-    simgrid::mc::VmMap const& reg = maps[i];
+    simgrid::xbt::VmMap const& reg = maps[i];
     const char* pathname = maps[i].pathname.c_str();
 
     // Nothing to do
     if (maps[i].pathname.empty()) {
-      current_name = NULL;
+      current_name = nullptr;
       continue;
     }
 
@@ -359,7 +309,7 @@ void Process::init_memory_map_info()
         this->maestro_stack_start_ = remote(reg.start_addr);
         this->maestro_stack_end_ = remote(reg.end_addr);
       }
-      current_name = NULL;
+      current_name = nullptr;
       continue;
     }
 
@@ -371,23 +321,23 @@ void Process::init_memory_map_info()
       continue;
 
     const bool is_executable = !i;
-    char* libname = NULL;
+    char* libname = nullptr;
     if (!is_executable) {
-      libname = MC_get_lib_name(pathname, &res);
+      libname = get_lib_name(pathname, &res);
       if(!libname)
         continue;
-      if (MC_is_filtered_lib(libname)) {
+      if (is_filtered_lib(libname)) {
         free(libname);
         continue;
       }
     }
 
     std::shared_ptr<simgrid::mc::ObjectInformation> info =
-      MC_find_object_info(this->memory_map_, pathname, is_executable);
+      simgrid::mc::createObjectInformation(this->memory_map_, pathname);
     this->object_infos.push_back(info);
     if (is_executable)
       this->binary_info = info;
-    else if (libname && MC_is_simgrid_lib(libname))
+    else if (libname && is_simgrid_lib(libname))
       this->libsimgrid_info = info;
     free(libname);
   }
@@ -397,7 +347,7 @@ void Process::init_memory_map_info()
 
   // Resolve time (including accross differents objects):
   for (auto const& object_info : this->object_infos)
-    MC_post_process_object_info(this, object_info.get());
+    postProcessObjectInformation(this, object_info.get());
 
   xbt_assert(this->maestro_stack_start_, "Did not find maestro_stack_start");
   xbt_assert(this->maestro_stack_end_, "Did not find maestro_stack_end");
@@ -405,40 +355,34 @@ void Process::init_memory_map_info()
   XBT_DEBUG("Get debug information done !");
 }
 
-std::shared_ptr<simgrid::mc::ObjectInformation> Process::find_object_info(remote_ptr<void> addr) const
+std::shared_ptr<simgrid::mc::ObjectInformation> Process::find_object_info(RemotePtr<void> addr) const
 {
-  for (auto const& object_info : this->object_infos) {
+  for (auto const& object_info : this->object_infos)
     if (addr.address() >= (std::uint64_t)object_info->start
-        && addr.address() <= (std::uint64_t)object_info->end) {
+        && addr.address() <= (std::uint64_t)object_info->end)
       return object_info;
-    }
-  }
-  return NULL;
+  return nullptr;
 }
 
-std::shared_ptr<ObjectInformation> Process::find_object_info_exec(remote_ptr<void> addr) const
+std::shared_ptr<ObjectInformation> Process::find_object_info_exec(RemotePtr<void> addr) const
 {
-  for (std::shared_ptr<ObjectInformation> const& info : this->object_infos) {
+  for (std::shared_ptr<ObjectInformation> const& info : this->object_infos)
     if (addr.address() >= (std::uint64_t) info->start_exec
-        && addr.address() <= (std::uint64_t) info->end_exec) {
+        && addr.address() <= (std::uint64_t) info->end_exec)
       return info;
-    }
-  }
   return nullptr;
 }
 
-std::shared_ptr<ObjectInformation> Process::find_object_info_rw(remote_ptr<void> addr) const
+std::shared_ptr<ObjectInformation> Process::find_object_info_rw(RemotePtr<void> addr) const
 {
-  for (std::shared_ptr<ObjectInformation> const& info : this->object_infos) {
+  for (std::shared_ptr<ObjectInformation> const& info : this->object_infos)
     if (addr.address() >= (std::uint64_t)info->start_rw
-        && addr.address() <= (std::uint64_t)info->end_rw) {
+        && addr.address() <= (std::uint64_t)info->end_rw)
       return info;
-    }
-  }
   return nullptr;
 }
 
-simgrid::mc::Frame* Process::find_function(remote_ptr<void> ip) const
+simgrid::mc::Frame* Process::find_function(RemotePtr<void> ip) const
 {
   std::shared_ptr<simgrid::mc::ObjectInformation> info = this->find_object_info_exec(ip);
   return info ? info->find_function((void*) ip.address()) : nullptr;
@@ -465,7 +409,7 @@ simgrid::mc::Variable* Process::find_variable(const char* name) const
       return var;
   }
 
-  return NULL;
+  return nullptr;
 }
 
 void Process::read_variable(const char* name, void* target, size_t size) const
@@ -481,17 +425,16 @@ void Process::read_variable(const char* name, void* target, size_t size) const
   this->read_bytes(target, size, remote(var->address));
 }
 
-char* Process::read_string(remote_ptr<void> address) const
+std::string Process::read_string(RemotePtr<void> address) const
 {
   if (!address)
-    return NULL;
+    return {};
 
-  off_t len = 128;
-  char* res = (char*) malloc(len);
+  std::vector<char> res(128);
   off_t off = 0;
 
   while (1) {
-    ssize_t c = pread(this->memory_file, res + off, len - off, (off_t) address.address() + off);
+    ssize_t c = pread(this->memory_file, res.data() + off, res.size() - off, (off_t) address.address() + off);
     if (c == -1) {
       if (errno == EINTR)
         continue;
@@ -501,28 +444,26 @@ char* Process::read_string(remote_ptr<void> address) const
     if (c==0)
       xbt_die("Could not read string from remote process");
 
-    void* p = memchr(res + off, '\0', c);
+    void* p = memchr(res.data() + off, '\0', c);
     if (p)
-      return res;
+      return std::string(res.data());
 
     off += c;
-    if (off == len) {
-      len *= 2;
-      res = (char*) realloc(res, len);
-    }
+    if (off == (off_t) res.size())
+      res.resize(res.size() * 2);
   }
 }
 
 const void *Process::read_bytes(void* buffer, std::size_t size,
-  remote_ptr<void> address, int process_index,
-  AddressSpace::ReadMode mode) const
+  RemotePtr<void> address, int process_index,
+  ReadOptions options) const
 {
   if (process_index != simgrid::mc::ProcessIndexDisabled) {
     std::shared_ptr<simgrid::mc::ObjectInformation> const& info =
       this->find_object_info_rw((void*)address.address());
     // Segment overlap is not handled.
-#ifdef HAVE_SMPI
-    if (info.get() && info.get()->privatized()) {
+#if HAVE_SMPI
+    if (info.get() && this->privatized(*info)) {
       if (process_index < 0)
         xbt_die("Missing process index");
       if (process_index >= (int) MC_smpi_process_count())
@@ -556,15 +497,15 @@ const void *Process::read_bytes(void* buffer, std::size_t size,
  *  @param remote  target process memory address (target)
  *  @param len     data size
  */
-void Process::write_bytes(const void* buffer, size_t len, remote_ptr<void> address)
+void Process::write_bytes(const void* buffer, size_t len, RemotePtr<void> address)
 {
   if (pwrite_whole(this->memory_file, buffer, len, address.address()) < 0)
     xbt_die("Write to process %lli failed", (long long) this->pid_);
 }
 
-void Process::clear_bytes(remote_ptr<void> address, size_t len)
+void Process::clear_bytes(RemotePtr<void> address, size_t len)
 {
-  pthread_once(&zero_buffer_flag, MC_zero_buffer_init);
+  pthread_once(&zero_buffer_flag, zero_buffer_init);
   while (len) {
     size_t s = len > zero_buffer_size ? zero_buffer_size : len;
     this->write_bytes(zero_buffer, s, address);
@@ -607,42 +548,129 @@ void Process::ignore_region(std::uint64_t addr, std::size_t size)
 
   std::size_t position;
   if (current_region->addr == addr) {
-    if (current_region->size < size) {
+    if (current_region->size < size)
       position = cursor + 1;
-    } else {
+    else
       position = cursor;
-    }
-  } else if (current_region->addr < addr) {
+  } else if (current_region->addr < addr)
     position = cursor + 1;
-  } else {
+  else
     position = cursor;
-  }
   ignored_regions_.insert(
     ignored_regions_.begin() + position, region);
 }
 
-void Process::reset_soft_dirty()
+void Process::ignore_heap(IgnoredHeapRegion const& region)
 {
-  if (this->clear_refs_fd_ < 0) {
-    this->clear_refs_fd_ = open_process_file(pid_, "clear_refs", O_WRONLY|O_CLOEXEC);
-    if (this->clear_refs_fd_ < 0)
-      xbt_die("Could not open clear_refs file for soft-dirty tracking. Run as root?");
+  if (ignored_heap_.empty()) {
+    ignored_heap_.push_back(std::move(region));
+    return;
   }
-  if(::write(this->clear_refs_fd_, "4\n", 2) != 2)
-    xbt_die("Could not reset softdirty bits");
+
+  typedef std::vector<IgnoredHeapRegion>::size_type size_type;
+
+  size_type start = 0;
+  size_type end = ignored_heap_.size() - 1;
+
+  // Binary search the position of insertion:
+  size_type cursor;
+  while (start <= end) {
+    cursor = start + (end - start) / 2;
+    auto& current_region = ignored_heap_[cursor];
+    if (current_region.address == region.address)
+      return;
+    else if (current_region.address < region.address)
+      start = cursor + 1;
+    else if (cursor != 0)
+      end = cursor - 1;
+    // Avoid underflow:
+    else
+      break;
+  }
+
+  // Insert it mc_heap_ignore_region_t:
+  if (ignored_heap_[cursor].address < region.address)
+    ++cursor;
+  ignored_heap_.insert( ignored_heap_.begin() + cursor, region);
 }
 
-void Process::read_pagemap(uint64_t* pagemap, size_t page_start, size_t page_count)
+void Process::unignore_heap(void *address, size_t size)
 {
-  if (pagemap_fd_ < 0) {
-    pagemap_fd_ = open_process_file(pid_, "pagemap", O_RDONLY|O_CLOEXEC);
-    if (pagemap_fd_ < 0)
-      xbt_die("Could not open pagemap file for soft-dirty tracking. Run as root?");
+  typedef std::vector<IgnoredHeapRegion>::size_type size_type;
+
+  size_type start = 0;
+  size_type end = ignored_heap_.size() - 1;
+
+  // Binary search:
+  size_type cursor;
+  while (start <= end) {
+    cursor = (start + end) / 2;
+    auto& region = ignored_heap_[cursor];
+    if (region.address == address) {
+      ignored_heap_.erase(ignored_heap_.begin() + cursor);
+      return;
+    } else if (region.address < address)
+      start = cursor + 1;
+    else if ((char *) region.address <= ((char *) address + size)) {
+      ignored_heap_.erase(ignored_heap_.begin() + cursor);
+      return;
+    } else if (cursor != 0)
+      end = cursor - 1;
+    // Avoid underflow:
+    else
+      break;
   }
-  ssize_t bytesize = sizeof(uint64_t) * page_count;
-  off_t offset = sizeof(uint64_t) * page_start;
-  if (pread_whole(pagemap_fd_, pagemap, bytesize, offset) != bytesize)
-    xbt_die("Could not read pagemap");
+}
+
+void Process::ignore_local_variable(const char *var_name, const char *frame_name)
+{
+  if (frame_name != nullptr && strcmp(frame_name, "*") == 0)
+    frame_name = nullptr;
+  for (std::shared_ptr<simgrid::mc::ObjectInformation> const& info :
+      this->object_infos)
+    info->remove_local_variable(var_name, frame_name);
+}
+
+std::vector<simgrid::mc::SimixProcessInformation>& Process::simix_processes()
+{
+  this->refresh_simix();
+  return smx_process_infos;
+}
+
+std::vector<simgrid::mc::SimixProcessInformation>& Process::old_simix_processes()
+{
+  this->refresh_simix();
+  return smx_old_process_infos;
+}
+
+void Process::dumpStack()
+{
+  unw_addr_space_t as = unw_create_addr_space(&_UPT_accessors, __BYTE_ORDER);
+  if (as == nullptr) {
+    XBT_ERROR("Could not initialize ptrace address space");
+    return;
+  }
+
+  void* context = _UPT_create(this->pid_);
+  if (context == nullptr) {
+    unw_destroy_addr_space(as);
+    XBT_ERROR("Could not initialize ptrace context");
+    return;
+  }
+
+  unw_cursor_t cursor;
+  if (unw_init_remote(&cursor, as, context) != 0) {
+    _UPT_destroy(context);
+    unw_destroy_addr_space(as);
+    XBT_ERROR("Could not initialiez ptrace cursor");
+    return;
+  }
+
+  simgrid::mc::dumpStack(stderr, cursor);
+
+  _UPT_destroy(context);
+  unw_destroy_addr_space(as);
+  return;
 }
 
 }
