@@ -7,25 +7,22 @@
 #ifndef SIMGRID_MC_BASE_H
 #define SIMGRID_MC_BASE_H
 
-#include <xbt/misc.h>
-#include <simgrid/simix.h>
-#include "simgrid_config.h"
-#include "internal_config.h"
-#include "../simix/smx_private.h"
+#include <xbt/base.h>
+#include "src/simix/popping_private.h" // smx_simcall_t
 
-SG_BEGIN_DECL()
+#ifdef __cplusplus
 
-/** Check if the given simcall can be resolved
+namespace simgrid {
+namespace mc {
+
+/** Can this requests can be executed?
  *
- *  \return `TRUE` or `FALSE`
+ *  Most requests are always enabled but WAIT and WAITANY
+ *  are not always enabled: a WAIT where the communication does not
+ *  have both a source and a destination yet is not enabled
+ *  (unless timeout is enabled in the wait and enabeld in SimGridMC).
  */
-XBT_PRIVATE int MC_request_is_enabled(smx_simcall_t req);
-
-/** Check if the given simcall is visible
- *
- *  \return `TRUE` or `FALSE`
- */
-XBT_PRIVATE int MC_request_is_visible(smx_simcall_t req);
+XBT_PRIVATE bool request_is_enabled(smx_simcall_t req);
 
 /** Execute everything which is invisible
  *
@@ -33,10 +30,22 @@ XBT_PRIVATE int MC_request_is_visible(smx_simcall_t req);
  *  iteratively until there doesn't remain any. At this point, the function
  *  returns to the caller which can handle the visible (and ready) simcalls.
  */
-XBT_PRIVATE void MC_wait_for_requests(void);
+XBT_PRIVATE void wait_for_requests(void);
 
-XBT_PRIVATE extern double *mc_time;
+XBT_PRIVATE extern std::vector<double> processes_time;
 
-SG_END_DECL()
+/** Execute a given simcall */
+XBT_PRIVATE void handle_simcall(smx_simcall_t req, int req_num);
+
+/** Check if the given simcall is visible
+ *
+ *  \return `TRUE` or `FALSE`
+ */
+XBT_PRIVATE bool request_is_visible(smx_simcall_t req);
+
+}
+}
+
+#endif
 
 #endif
