@@ -6,109 +6,70 @@
 
 #define __STDC_FORMAT_MACROS
 #include <cinttypes>
-#include <boost/unordered_set.hpp>
+
+#include <utility>
+#include <unordered_set>
 
 #include <xbt/sysdep.h>
 
-#include "internal_config.h"
-#include "mc_object_info.h"
-#include "mc_safety.h"
-#include "mc_liveness.h"
-#include "mc_private.h"
-#include "mc_smx.h"
-#include "mc_dwarf.hpp"
+#include "src/internal_config.h"
+#include "src/mc/mc_forward.hpp"
+#include "src/mc/mc_safety.h"
+#include "src/mc/mc_private.h"
+#include "src/mc/mc_smx.h"
+#include "src/mc/mc_dwarf.hpp"
+#include "src/mc/malloc.hpp"
+#include "src/mc/Frame.hpp"
+#include "src/mc/ObjectInformation.hpp"
+#include "src/mc/Variable.hpp"
 
-#include "mc/Frame.hpp"
-#include "mc/ObjectInformation.hpp"
-#include "mc/Variable.hpp"
-
-#ifdef HAVE_SMPI
-#include "smpi/private.h"
+#if HAVE_SMPI
+#include "src/smpi/private.h"
 #endif
 
 #include "xbt/mmalloc.h"
-#include "xbt/mmalloc/mmprivate.h"
-
-#include <xbt/probes.h>
+#include "src/xbt/mmalloc/mmprivate.h"
 
 using simgrid::mc::remote;
 
-typedef struct s_pointers_pair {
-  void *p1;
-  void *p2;
-  bool operator==(s_pointers_pair const& x) const {
-    return this->p1 == x.p1 && this->p2 == x.p2;
-  }
-  bool operator<(s_pointers_pair const& x) const {
-    return this->p1 < x.p1 || (this->p1 == x.p1 && this->p2 < x.p2);
-  }
-} s_pointers_pair_t, *pointers_pair_t;
-
-namespace boost {
-  template<>
-  struct hash<s_pointers_pair> {
-    typedef uintptr_t result_type;
-    result_type operator()(s_pointers_pair const& x) const {
-      return (result_type) x.p1 ^
-        ((result_type) x.p2 << 8 | (result_type) x.p2 >> (8*sizeof(uintptr_t) - 8));
-    }
-  };
-}
-
-struct mc_compare_state {
-  boost::unordered_set<s_pointers_pair> compared_pointers;
-};
-
-extern "C" {
-
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_compare, xbt,
                                 "Logging specific to mc_compare in mc");
 
-/************************** Free functions ****************************/
-/********************************************************************/
+namespace simgrid {
+namespace mc {
 
-static void stack_region_free(stack_region_t s)
-{
-  if (s) {
-    xbt_free(s);
+/** A hash which works with more stuff
+ *
+ *  It can hash pairs: the standard hash currently doesn't include this.
+ */
+template<class X> struct hash : public std::hash<X> {};
+
+template<class X, class Y>
+struct hash<std::pair<X,Y>> {
+  std::size_t operator()(std::pair<X,Y>const& x) const
+  {
+    struct hash<X> h1;
+    struct hash<X> h2;
+    return h1(x.first) ^ h2(x.second);
   }
+};
+
+struct ComparisonState {
+  std::unordered_set<std::pair<void*, void*>, hash<std::pair<void*, void*>>> compared_pointers;
+};
+
+}
 }
 
-static void stack_region_free_voidp(void *s)
-{
-  stack_region_free((stack_region_t) * (void **) s);
-}
-
-static void pointers_pair_free(pointers_pair_t p)
-{
-  xbt_free(p);
-}
-
-static void pointers_pair_free_voidp(void *p)
-{
-  pointers_pair_free((pointers_pair_t) * (void **) p);
-}
+using simgrid::mc::ComparisonState;
 
 /************************** Snapshot comparison *******************************/
 /******************************************************************************/
 
-/** \brief Try to add a pair a compared pointers to the set of compared pointers
- *
- *  \result !=0 if the pointers were added (they were not in the set),
- *      0 otherwise (they were already in the set)
- */
-static int add_compared_pointers(mc_compare_state& state, void *p1, void *p2)
-{
-  s_pointers_pair_t new_pair;
-  new_pair.p1 = p1;
-  new_pair.p2 = p2;
-  return state.compared_pointers.insert(new_pair).second ? 1 : 0;
-}
-
-static int compare_areas_with_type(struct mc_compare_state& state,
+static int compare_areas_with_type(ComparisonState& state,
                                    int process_index,
-                                   void* real_area1, mc_snapshot_t snapshot1, mc_mem_region_t region1,
-                                   void* real_area2, mc_snapshot_t snapshot2, mc_mem_region_t region2,
+                                   void* real_area1, simgrid::mc::Snapshot* snapshot1, mc_mem_region_t region1,
+                                   void* real_area2, simgrid::mc::Snapshot* snapshot2, mc_mem_region_t region2,
                                    simgrid::mc::Type* type, int pointer_level)
 {
   simgrid::mc::Process* process = &mc_model_checker->process();
@@ -183,18 +144,17 @@ static int compare_areas_with_type(struct mc_compare_state& state,
     void* addr_pointed1 = MC_region_read_pointer(region1, real_area1);
     void* addr_pointed2 = MC_region_read_pointer(region2, real_area2);
 
-    if (type->subtype && type->subtype->type == DW_TAG_subroutine_type) {
+    if (type->subtype && type->subtype->type == DW_TAG_subroutine_type)
       return (addr_pointed1 != addr_pointed2);
-    } else {
+    if (addr_pointed1 == nullptr && addr_pointed2 == nullptr)
+      return 0;
+    if (addr_pointed1 == nullptr || addr_pointed2 == nullptr)
+      return 1;
+    if (!state.compared_pointers.insert(
+        std::make_pair(addr_pointed1, addr_pointed2)).second)
+      return 0;
 
-      if (addr_pointed1 == NULL && addr_pointed2 == NULL)
-        return 0;
-      if (addr_pointed1 == NULL || addr_pointed2 == NULL)
-        return 1;
-      if (!add_compared_pointers(state, addr_pointed1, addr_pointed2))
-        return 0;
-
-      pointer_level++;
+    pointer_level++;
 
       // Some cases are not handled here:
       // * the pointers lead to different areas (one to the heap, the other to the RW segment ...);
@@ -208,8 +168,8 @@ static int compare_areas_with_type(struct mc_compare_state& state,
              && addr_pointed2 < mc_snapshot_get_heap_end(snapshot2)))
           return 1;
         // The pointers are both in the heap:
-        return compare_heap_area(process_index, addr_pointed1, addr_pointed2, snapshot1,
-                                 snapshot2, NULL, type->subtype, pointer_level);
+        return simgrid::mc::compare_heap_area(process_index, addr_pointed1, addr_pointed2, snapshot1,
+                                 snapshot2, nullptr, type->subtype, pointer_level);
       }
 
       // The pointers are both in the current object R/W segment:
@@ -218,30 +178,28 @@ static int compare_areas_with_type(struct mc_compare_state& state,
           return 1;
         if (!type->type_id)
           return (addr_pointed1 != addr_pointed2);
-        else {
+        else
           return compare_areas_with_type(state, process_index,
                                          addr_pointed1, snapshot1, region1,
                                          addr_pointed2, snapshot2, region2,
                                          type->subtype, pointer_level);
-        }
       }
 
       // TODO, We do not handle very well the case where
       // it belongs to a different (non-heap) region from the current one.
 
-      else {
+      else
         return (addr_pointed1 != addr_pointed2);
-      }
-    }
+
     break;
   }
   case DW_TAG_structure_type:
   case DW_TAG_class_type:
     for(simgrid::mc::Member& member : type->members) {
-      void *member1 =
-        mc_member_resolve(real_area1, type, &member, snapshot1, process_index);
-      void *member2 =
-        mc_member_resolve(real_area2, type, &member, snapshot2, process_index);
+      void *member1 = simgrid::dwarf::resolve_member(
+        real_area1, type, &member, snapshot1, process_index);
+      void *member2 = simgrid::dwarf::resolve_member(
+        real_area2, type, &member, snapshot2, process_index);
       mc_mem_region_t subregion1 = mc_get_region_hinted(member1, snapshot1, process_index, region1);
       mc_mem_region_t subregion2 = mc_get_region_hinted(member2, snapshot2, process_index, region2);
       res =
@@ -267,17 +225,16 @@ static int compare_areas_with_type(struct mc_compare_state& state,
 static int compare_global_variables(simgrid::mc::ObjectInformation* object_info,
                                     int process_index,
                                     mc_mem_region_t r1,
-                                    mc_mem_region_t r2, mc_snapshot_t snapshot1,
-                                    mc_snapshot_t snapshot2)
+                                    mc_mem_region_t r2, simgrid::mc::Snapshot* snapshot1,
+                                    simgrid::mc::Snapshot* snapshot2)
 {
   xbt_assert(r1 && r2, "Missing region.");
 
-#ifdef HAVE_SMPI
+#if HAVE_SMPI
   if (r1->storage_type() == simgrid::mc::StorageType::Privatized) {
     xbt_assert(process_index >= 0);
-    if (r2->storage_type() != simgrid::mc::StorageType::Privatized) {
+    if (r2->storage_type() != simgrid::mc::StorageType::Privatized)
       return 1;
-    }
 
     size_t process_count = MC_smpi_process_count();
     xbt_assert(process_count == r1->privatized_data().size()
@@ -298,7 +255,7 @@ static int compare_global_variables(simgrid::mc::ObjectInformation* object_info,
 #endif
   xbt_assert(r2->storage_type() != simgrid::mc::StorageType::Privatized);
 
-  struct mc_compare_state state;
+  ComparisonState state;
 
   std::vector<simgrid::mc::Variable>& variables = object_info->global_variables;
 
@@ -318,7 +275,6 @@ static int compare_global_variables(simgrid::mc::ObjectInformation* object_info,
                                 (char *) current_var.address, snapshot2, r2,
                                 bvariable_type, 0);
     if (res == 1) {
-      XBT_TRACE3(mc, global_diff, -1, -1, current_var->name);
       XBT_VERB("Global variable %s (%p) is different between snapshots",
                current_var.name.c_str(),
                (char *) current_var.address);
@@ -332,17 +288,18 @@ static int compare_global_variables(simgrid::mc::ObjectInformation* object_info,
 }
 
 static int compare_local_variables(int process_index,
-                                   mc_snapshot_t snapshot1,
-                                   mc_snapshot_t snapshot2,
+                                   simgrid::mc::Snapshot* snapshot1,
+                                   simgrid::mc::Snapshot* snapshot2,
                                    mc_snapshot_stack_t stack1,
                                    mc_snapshot_stack_t stack2)
 {
-  struct mc_compare_state state;
+  ComparisonState state;
 
   if (stack1->local_variables.size() != stack2->local_variables.size()) {
     XBT_VERB("Different number of local variables");
     return 1;
-  } else {
+  }
+
     unsigned int cursor = 0;
     local_variable_t current_var1, current_var2;
     int res;
@@ -350,7 +307,7 @@ static int compare_local_variables(int process_index,
       current_var1 = &stack1->local_variables[cursor];
       current_var2 = &stack1->local_variables[cursor];
       if (current_var1->name != current_var2->name
-          || current_var1->subprogram != current_var1->subprogram
+          || current_var1->subprogram != current_var2->subprogram
           || current_var1->ip != current_var2->ip) {
         // TODO, fix current_varX->subprogram->name to include name if DW_TAG_inlined_subprogram
         XBT_VERB
@@ -374,7 +331,6 @@ static int compare_local_variables(int process_index,
 
       if (res == 1) {
         // TODO, fix current_varX->subprogram->name to include name if DW_TAG_inlined_subprogram
-        XBT_TRACE3(mc, local_diff, -1, -1, current_var1->name);
         XBT_VERB
             ("Local variable %s (%p - %p) in frame %s "
              "is different between snapshots",
@@ -387,63 +343,33 @@ static int compare_local_variables(int process_index,
       cursor++;
     }
     return 0;
-  }
 }
 
-int snapshot_compare(void *state1, void *state2)
+namespace simgrid {
+namespace mc {
+
+int snapshot_compare(int num1, simgrid::mc::Snapshot* s1, int num2, simgrid::mc::Snapshot* s2)
 {
   simgrid::mc::Process* process = &mc_model_checker->process();
 
-  mc_snapshot_t s1, s2;
-  int num1, num2;
-
-  if (_sg_mc_liveness) {        /* Liveness MC */
-    s1 = ((mc_visited_pair_t) state1)->graph_state->system_state;
-    s2 = ((mc_visited_pair_t) state2)->graph_state->system_state;
-    num1 = ((mc_visited_pair_t) state1)->num;
-    num2 = ((mc_visited_pair_t) state2)->num;
-  }else if (_sg_mc_termination) { /* Non-progressive cycle MC */
-    s1 = ((mc_state_t) state1)->system_state;
-    s2 = ((mc_state_t) state2)->system_state;
-    num1 = ((mc_state_t) state1)->num;
-    num2 = ((mc_state_t) state2)->num;
-  } else {                      /* Safety or comm determinism MC */
-    s1 = ((mc_visited_state_t) state1)->system_state;
-    s2 = ((mc_visited_state_t) state2)->system_state;
-    num1 = ((mc_visited_state_t) state1)->num;
-    num2 = ((mc_visited_state_t) state2)->num;
-  }
-
   int errors = 0;
   int res_init;
 
-  xbt_os_timer_t global_timer = xbt_os_timer_new();
-  xbt_os_timer_t timer = xbt_os_timer_new();
-
-  xbt_os_walltimer_start(global_timer);
-
-#ifdef MC_DEBUG
-  xbt_os_walltimer_start(timer);
-#endif
-
   int hash_result = 0;
   if (_sg_mc_hash) {
     hash_result = (s1->hash != s2->hash);
     if (hash_result) {
-      XBT_TRACE2(mc, hash_diff, num1, num2);
       XBT_VERB("(%d - %d) Different hash : 0x%" PRIx64 "--0x%" PRIx64, num1,
                num2, s1->hash, s2->hash);
 #ifndef MC_DEBUG
       return 1;
 #endif
-    } else {
+    } else
       XBT_VERB("(%d - %d) Same hash : 0x%" PRIx64, num1, num2, s1->hash);
-    }
   }
 
   /* Compare enabled processes */
   if (s1->enabled_processes != s2->enabled_processes) {
-      //XBT_TRACE3(mc, state_diff, num1, num2, "Different enabled processes");
       XBT_VERB("(%d - %d) Different enabled processes", num1, num2);
       // return 1; ??
   }
@@ -458,11 +384,6 @@ int snapshot_compare(void *state1, void *state2)
     size_used2 = s2->stack_sizes[i];
     if (size_used1 != size_used2) {
 #ifdef MC_DEBUG
-      if (is_diff == 0) {
-        xbt_os_walltimer_stop(timer);
-        mc_comp_times->stacks_sizes_comparison_time =
-            xbt_os_timer_elapsed(timer);
-      }
       XBT_DEBUG("(%d - %d) Different size used in stacks : %zu - %zu", num1,
                 num2, size_used1, size_used2);
       errors++;
@@ -472,56 +393,34 @@ int snapshot_compare(void *state1, void *state2)
       XBT_VERB("(%d - %d) Different size used in stacks : %zu - %zu", num1,
                num2, size_used1, size_used2);
 #endif
-      XBT_TRACE3(mc, state_diff, num1, num2, "Different stack size");
-
-      xbt_os_walltimer_stop(timer);
-      xbt_os_timer_free(timer);
-      xbt_os_walltimer_stop(global_timer);
-      mc_snapshot_comparison_time = xbt_os_timer_elapsed(global_timer);
-      xbt_os_timer_free(global_timer);
-
       return 1;
 #endif
     }
     i++;
   }
 
-#ifdef MC_DEBUG
-  if (is_diff == 0)
-    xbt_os_walltimer_stop(timer);
-  xbt_os_walltimer_start(timer);
-#endif
-
   /* Init heap information used in heap comparison algorithm */
   xbt_mheap_t heap1 = (xbt_mheap_t)s1->read_bytes(
     alloca(sizeof(struct mdesc)), sizeof(struct mdesc),
     remote(process->heap_address),
-    simgrid::mc::ProcessIndexMissing, simgrid::mc::AddressSpace::Lazy);
+    simgrid::mc::ProcessIndexMissing, simgrid::mc::ReadOptions::lazy());
   xbt_mheap_t heap2 = (xbt_mheap_t)s2->read_bytes(
     alloca(sizeof(struct mdesc)), sizeof(struct mdesc),
     remote(process->heap_address),
-    simgrid::mc::ProcessIndexMissing, simgrid::mc::AddressSpace::Lazy);
-  res_init = init_heap_information(heap1, heap2, &s1->to_ignore, &s2->to_ignore);
+    simgrid::mc::ProcessIndexMissing, simgrid::mc::ReadOptions::lazy());
+  res_init = simgrid::mc::init_heap_information(heap1, heap2, &s1->to_ignore, &s2->to_ignore);
   if (res_init == -1) {
 #ifdef MC_DEBUG
     XBT_DEBUG("(%d - %d) Different heap information", num1, num2);
     errors++;
 #else
 #ifdef MC_VERBOSE
-    XBT_TRACE3(mc, state_diff, num1, num2, "Different heap information");
     XBT_VERB("(%d - %d) Different heap information", num1, num2);
 #endif
 
-    xbt_os_walltimer_stop(global_timer);
-    mc_snapshot_comparison_time = xbt_os_timer_elapsed(global_timer);
-    xbt_os_timer_free(global_timer);
-
     return 1;
 #endif
   }
-#ifdef MC_DEBUG
-  xbt_os_walltimer_start(timer);
-#endif
 
   /* Stacks comparison */
   unsigned cursor = 0;
@@ -532,7 +431,7 @@ int snapshot_compare(void *state1, void *state2)
   mc_snapshot_stack_t stack1, stack2;
   while (cursor < s1->stacks.size()) {
     stack1 = &s1->stacks[cursor];
-    stack2 = &s1->stacks[cursor];
+    stack2 = &s2->stacks[cursor];
 
     if (stack1->process_index != stack2->process_index) {
       diff_local = 1;
@@ -542,12 +441,7 @@ int snapshot_compare(void *state1, void *state2)
     else diff_local =
         compare_local_variables(stack1->process_index, s1, s2, stack1, stack2);
     if (diff_local > 0) {
-      XBT_TRACE3(mc, state_diff, num1, num2, "Different local variables");
 #ifdef MC_DEBUG
-      if (is_diff == 0) {
-        xbt_os_walltimer_stop(timer);
-        mc_comp_times->stacks_comparison_time = xbt_os_timer_elapsed(timer);
-      }
       XBT_DEBUG("(%d - %d) Different local variables between stacks %d", num1,
                 num2, cursor + 1);
       errors++;
@@ -559,12 +453,7 @@ int snapshot_compare(void *state1, void *state2)
                num2, cursor + 1);
 #endif
 
-      reset_heap_information();
-      xbt_os_walltimer_stop(timer);
-      xbt_os_timer_free(timer);
-      xbt_os_walltimer_stop(global_timer);
-      mc_snapshot_comparison_time = xbt_os_timer_elapsed(global_timer);
-      xbt_os_timer_free(global_timer);
+      simgrid::mc::reset_heap_information();
 
       return 1;
 #endif
@@ -576,8 +465,6 @@ int snapshot_compare(void *state1, void *state2)
   // TODO, raise a difference instead?
   xbt_assert(regions_count == s2->snapshot_regions.size());
 
-  mc_comp_times->global_variables_comparison_time = 0;
-
   for (size_t k = 0; k != regions_count; ++k) {
     mc_mem_region_t region1 = s1->snapshot_regions[k].get();
     mc_mem_region_t region2 = s2->snapshot_regions[k].get();
@@ -592,24 +479,15 @@ int snapshot_compare(void *state1, void *state2)
 
     std::string const& name = region1->object_info()->file_name;
 
-#ifdef MC_DEBUG
-    if (is_diff == 0)
-      xbt_os_walltimer_stop(timer);
-    xbt_os_walltimer_start(timer);
-#endif
-
     /* Compare global variables */
     is_diff =
-      compare_global_variables(region1->object_info(  ), simgrid::mc::AddressSpace::Normal,
+      compare_global_variables(region1->object_info(),
+        simgrid::mc::ProcessIndexDisabled,
         region1, region2,
         s1, s2);
 
     if (is_diff != 0) {
-      XBT_TRACE3(mc, state_diff, num1, num2, "Different global variables");
 #ifdef MC_DEBUG
-      xbt_os_walltimer_stop(timer);
-      mc_comp_times->global_variables_comparison_time
-        += xbt_os_timer_elapsed(timer);
       XBT_DEBUG("(%d - %d) Different global variables in %s",
         num1, num2, name.c_str());
       errors++;
@@ -619,29 +497,15 @@ int snapshot_compare(void *state1, void *state2)
         num1, num2, name.c_str());
 #endif
 
-      reset_heap_information();
-      xbt_os_walltimer_stop(timer);
-      xbt_os_timer_free(timer);
-      xbt_os_walltimer_stop(global_timer);
-      mc_snapshot_comparison_time = xbt_os_timer_elapsed(global_timer);
-      xbt_os_timer_free(global_timer);
-
       return 1;
 #endif
     }
   }
 
-#ifdef MC_DEBUG
-  xbt_os_walltimer_start(timer);
-#endif
-
   /* Compare heap */
-  if (mmalloc_compare_heap(s1, s2) > 0) {
-    XBT_TRACE3(mc, state_diff, num1, num2, "Different heap");
+  if (simgrid::mc::mmalloc_compare_heap(s1, s2) > 0) {
 
 #ifdef MC_DEBUG
-    xbt_os_walltimer_stop(timer);
-    mc_comp_times->heap_comparison_time = xbt_os_timer_elapsed(timer);
     XBT_DEBUG("(%d - %d) Different heap (mmalloc_compare)", num1, num2);
     errors++;
 #else
@@ -650,36 +514,11 @@ int snapshot_compare(void *state1, void *state2)
     XBT_VERB("(%d - %d) Different heap (mmalloc_compare)", num1, num2);
 #endif
 
-    reset_heap_information();
-    xbt_os_walltimer_stop(timer);
-    xbt_os_timer_free(timer);
-    xbt_os_walltimer_stop(global_timer);
-    mc_snapshot_comparison_time = xbt_os_timer_elapsed(global_timer);
-    xbt_os_timer_free(global_timer);
-
     return 1;
-#endif
-  } else {
-#ifdef MC_DEBUG
-    xbt_os_walltimer_stop(timer);
 #endif
   }
 
-  reset_heap_information();
-
-  xbt_os_walltimer_stop(timer);
-  xbt_os_timer_free(timer);
-
-#ifdef MC_VERBOSE
-  xbt_os_walltimer_stop(global_timer);
-  mc_snapshot_comparison_time = xbt_os_timer_elapsed(global_timer);
-#endif
-
-  xbt_os_timer_free(global_timer);
-
-#ifdef MC_DEBUG
-  print_comparison_times();
-#endif
+  simgrid::mc::reset_heap_information();
 
 #ifdef MC_VERBOSE
   if (errors || hash_result)
@@ -700,21 +539,7 @@ int snapshot_compare(void *state1, void *state2)
 #endif
 
   return errors > 0 || hash_result;
-
-}
-
-/***************************** Statistics *****************************/
-/*******************************************************************/
-
-void print_comparison_times()
-{
-  XBT_DEBUG("*** Comparison times ***");
-  XBT_DEBUG("- Nb processes : %f", mc_comp_times->nb_processes_comparison_time);
-  XBT_DEBUG("- Nb bytes used : %f", mc_comp_times->bytes_used_comparison_time);
-  XBT_DEBUG("- Stacks sizes : %f", mc_comp_times->stacks_sizes_comparison_time);
-  XBT_DEBUG("- GLobal variables : %f", mc_comp_times->global_variables_comparison_time);
-  XBT_DEBUG("- Heap : %f", mc_comp_times->heap_comparison_time);
-  XBT_DEBUG("- Stacks : %f", mc_comp_times->stacks_comparison_time);
 }
 
 }
+}
