@@ -1,48 +1,42 @@
-/* mc_diff - Memory snapshooting and comparison                             */
-
 /* Copyright (c) 2008-2015. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "xbt/ex_interface.h"   /* internals of backtrace setup */
-#include "xbt/str.h"
+/* mc_diff - Memory snapshooting and comparison                             */
+
+#include "src/xbt/ex_interface.h"   /* internals of backtrace setup */
 #include "mc/mc.h"
 #include "xbt/mmalloc.h"
-#include "mc_object_info.h"
 #include "mc/datatypes.h"
-#include "mc/mc_private.h"
-#include "mc/mc_snapshot.h"
-#include "mc/mc_dwarf.hpp"
-#include "mc/Type.hpp"
+#include "src/mc/malloc.hpp"
+#include "src/mc/mc_private.h"
+#include "src/mc/mc_snapshot.h"
+#include "src/mc/mc_dwarf.hpp"
+#include "src/mc/Type.hpp"
+
+#include <xbt/dynar.h>
 
 using simgrid::mc::remote;
 
-extern "C" {
-
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_diff, xbt,
                                 "Logging specific to mc_diff in mc");
 
-xbt_dynar_t mc_heap_comparison_ignore;
-xbt_dynar_t stacks_areas;
-
 /*********************************** Heap comparison ***********************************/
 /***************************************************************************************/
 
-typedef char *type_name;
-
 struct XBT_PRIVATE s_mc_diff {
   s_xbt_mheap_t std_heap_copy;
-  size_t heaplimit;
+  std::size_t heaplimit;
   // Number of blocks in the heaps:
-  size_t heapsize1, heapsize2;
-  std::vector<s_mc_heap_ignore_region_t>* to_ignore1;
-  std::vector<s_mc_heap_ignore_region_t>* to_ignore2;
+  std::size_t heapsize1, heapsize2;
+  std::vector<simgrid::mc::IgnoredHeapRegion>* to_ignore1;
+  std::vector<simgrid::mc::IgnoredHeapRegion>* to_ignore2;
   s_heap_area_t *equals_to1, *equals_to2;
   simgrid::mc::Type **types1;
   simgrid::mc::Type **types2;
-  size_t available;
+  std::size_t available;
 };
 
 #define equals_to1_(i,j) equals_to1[ MAX_FRAGMENT_PER_BLOCK*(i) + (j)]
@@ -50,14 +44,14 @@ struct XBT_PRIVATE s_mc_diff {
 #define types1_(i,j) types1[ MAX_FRAGMENT_PER_BLOCK*(i) + (j)]
 #define types2_(i,j) types2[ MAX_FRAGMENT_PER_BLOCK*(i) + (j)]
 
-__thread struct s_mc_diff *mc_diff_info = NULL;
+static __thread struct s_mc_diff *mc_diff_info = nullptr;
 
 /*********************************** Free functions ************************************/
 
 static void heap_area_pair_free(heap_area_pair_t pair)
 {
   xbt_free(pair);
-  pair = NULL;
+  pair = nullptr;
 }
 
 static void heap_area_pair_free_voidp(void *d)
@@ -68,7 +62,7 @@ static void heap_area_pair_free_voidp(void *d)
 static void heap_area_free(heap_area_t area)
 {
   xbt_free(area);
-  area = NULL;
+  area = nullptr;
 }
 
 /************************************************************************************/
@@ -90,12 +84,11 @@ static int is_new_heap_area_pair(xbt_dynar_t list, int block1, int fragment1,
   unsigned int cursor = 0;
   heap_area_pair_t current_pair;
 
-  xbt_dynar_foreach(list, cursor, current_pair) {
+  xbt_dynar_foreach(list, cursor, current_pair)
     if (current_pair->block1 == block1 && current_pair->block2 == block2
         && current_pair->fragment1 == fragment1
         && current_pair->fragment2 == fragment2)
       return 0;
-  }
 
   return 1;
 }
@@ -105,7 +98,7 @@ static int add_heap_area_pair(xbt_dynar_t list, int block1, int fragment1,
 {
 
   if (is_new_heap_area_pair(list, block1, fragment1, block2, fragment2)) {
-    heap_area_pair_t pair = NULL;
+    heap_area_pair_t pair = nullptr;
     pair = xbt_new0(s_heap_area_pair_t, 1);
     pair->block1 = block1;
     pair->fragment1 = fragment1;
@@ -120,15 +113,16 @@ static int add_heap_area_pair(xbt_dynar_t list, int block1, int fragment1,
   return 0;
 }
 
-static ssize_t heap_comparison_ignore_size(std::vector<s_mc_heap_ignore_region_t>* ignore_list,
-                                           const void *address)
+static ssize_t heap_comparison_ignore_size(
+  std::vector<simgrid::mc::IgnoredHeapRegion>* ignore_list,
+  const void *address)
 {
   int start = 0;
   int end = ignore_list->size() - 1;
 
   while (start <= end) {
     unsigned int cursor = (start + end) / 2;
-    s_mc_heap_ignore_region_t region = (*ignore_list)[cursor];
+    simgrid::mc::IgnoredHeapRegion const& region = (*ignore_list)[cursor];
     if (region.address == address)
       return region.size;
     if (region.address < address)
@@ -140,31 +134,21 @@ static ssize_t heap_comparison_ignore_size(std::vector<s_mc_heap_ignore_region_t
   return -1;
 }
 
-static int is_stack(const void *address)
+static bool is_stack(const void *address)
 {
-  unsigned int cursor = 0;
-  stack_region_t stack;
-
-  xbt_dynar_foreach(stacks_areas, cursor, stack) {
-    if (address == stack->address)
-      return 1;
-  }
-
-  return 0;
+  for (auto const& stack : mc_model_checker->process().stack_areas())
+    if (address == stack.address)
+      return true;
+  return false;
 }
 
 // TODO, this should depend on the snapshot?
-static int is_block_stack(int block)
+static bool is_block_stack(int block)
 {
-  unsigned int cursor = 0;
-  stack_region_t stack;
-
-  xbt_dynar_foreach(stacks_areas, cursor, stack) {
-    if (block == stack->block)
-      return 1;
-  }
-
-  return 0;
+  for (auto const& stack : mc_model_checker->process().stack_areas())
+    if (block == stack.block)
+      return true;
+  return false;
 }
 
 static void match_equals(struct s_mc_diff *state, xbt_dynar_t list)
@@ -173,7 +157,7 @@ static void match_equals(struct s_mc_diff *state, xbt_dynar_t list)
   unsigned int cursor = 0;
   heap_area_pair_t current_pair;
 
-  xbt_dynar_foreach(list, cursor, current_pair) {
+  xbt_dynar_foreach(list, cursor, current_pair)
 
     if (current_pair->fragment1 != -1) {
 
@@ -191,7 +175,6 @@ static void match_equals(struct s_mc_diff *state, xbt_dynar_t list)
 
     }
 
-  }
 }
 
 /** Check whether two blocks are known to be matching
@@ -233,18 +216,19 @@ static int equal_fragments(struct s_mc_diff *state, int b1, int f1, int b2,
   return 0;
 }
 
-}
+namespace simgrid {
+namespace mc {
 
 int init_heap_information(xbt_mheap_t heap1, xbt_mheap_t heap2,
-                          std::vector<s_mc_heap_ignore_region_t>* i1,
-                          std::vector<s_mc_heap_ignore_region_t>* i2)
+                          std::vector<simgrid::mc::IgnoredHeapRegion>* i1,
+                          std::vector<simgrid::mc::IgnoredHeapRegion>* i2)
 {
-  if (mc_diff_info == NULL) {
+  if (mc_diff_info == nullptr) {
     mc_diff_info = xbt_new0(struct s_mc_diff, 1);
-    mc_diff_info->equals_to1 = NULL;
-    mc_diff_info->equals_to2 = NULL;
-    mc_diff_info->types1 = NULL;
-    mc_diff_info->types2 = NULL;
+    mc_diff_info->equals_to1 = nullptr;
+    mc_diff_info->equals_to2 = nullptr;
+    mc_diff_info->types1 = nullptr;
+    mc_diff_info->types2 = nullptr;
   }
   struct s_mc_diff *state = mc_diff_info;
 
@@ -290,16 +274,14 @@ int init_heap_information(xbt_mheap_t heap1, xbt_mheap_t heap2,
   memset(state->equals_to2, 0,
          state->heaplimit * MAX_FRAGMENT_PER_BLOCK * sizeof(s_heap_area_t));
   memset(state->types1, 0,
-         state->heaplimit * MAX_FRAGMENT_PER_BLOCK * sizeof(type_name *));
+         state->heaplimit * MAX_FRAGMENT_PER_BLOCK * sizeof(char**));
   memset(state->types2, 0,
-         state->heaplimit * MAX_FRAGMENT_PER_BLOCK * sizeof(type_name *));
+         state->heaplimit * MAX_FRAGMENT_PER_BLOCK * sizeof(char**));
 
   return 0;
 
 }
 
-extern "C" {
-
 void reset_heap_information()
 {
 
@@ -307,7 +289,7 @@ void reset_heap_information()
 
 // TODO, have a robust way to find it in O(1)
 static inline
-mc_mem_region_t MC_get_heap_region(mc_snapshot_t snapshot)
+mc_mem_region_t MC_get_heap_region(simgrid::mc::Snapshot* snapshot)
 {
   size_t n = snapshot->snapshot_regions.size();
   for (size_t i=0; i!=n; ++i) {
@@ -318,7 +300,7 @@ mc_mem_region_t MC_get_heap_region(mc_snapshot_t snapshot)
   xbt_die("No heap region");
 }
 
-int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
+int mmalloc_compare_heap(simgrid::mc::Snapshot* snapshot1, simgrid::mc::Snapshot* snapshot2)
 {
   simgrid::mc::Process* process = &mc_model_checker->process();
   struct s_mc_diff *state = mc_diff_info;
@@ -398,7 +380,7 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
 
           res_compare =
               compare_heap_area(simgrid::mc::ProcessIndexMissing, addr_block1, addr_block2, snapshot1, snapshot2,
-                                NULL, NULL, 0);
+                                nullptr, nullptr, 0);
 
           if (res_compare != 1) {
             for (k = 1; k < heapinfo2->busy_block.size; k++)
@@ -437,7 +419,7 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
 
         res_compare =
             compare_heap_area(simgrid::mc::ProcessIndexMissing, addr_block1, addr_block2, snapshot1, snapshot2,
-                              NULL, NULL, 0);
+                              nullptr, nullptr, 0);
 
         if (res_compare != 1) {
           for (k = 1; k < heapinfo2b->busy_block.size; k++)
@@ -489,7 +471,7 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
 
             res_compare =
                 compare_heap_area(simgrid::mc::ProcessIndexMissing, addr_frag1, addr_frag2, snapshot1, snapshot2,
-                                  NULL, NULL, 0);
+                                  nullptr, nullptr, 0);
 
             if (res_compare != 1)
               equal = 1;
@@ -537,7 +519,7 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
 
             res_compare =
                 compare_heap_area(simgrid::mc::ProcessIndexMissing, addr_frag1, addr_frag2, snapshot2, snapshot2,
-                                  NULL, NULL, 0);
+                                  nullptr, nullptr, 0);
 
             if (res_compare != 1) {
               equal = 1;
@@ -583,7 +565,6 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
               // TODO, add address
               XBT_DEBUG("Block %zu not found (size used = %zu)", i,
                         heapinfo1->busy_block.busy_size);
-              //mmalloc_backtrace_block_display((void*)heapinfo1, i);
             }
             nb_diff1++;
           }
@@ -601,7 +582,6 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
                     ("Block %zu, Fragment %zu not found (size used = %zd)",
                      i, j,
                      heapinfo1->busy_frag.frag_size[j]);
-                //mmalloc_backtrace_fragment_display((void*)heapinfo1, i, j);
               }
               nb_diff1++;
             }
@@ -625,7 +605,6 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
               // TODO, print address of the block
               XBT_DEBUG("Block %zu not found (size used = %zu)", i,
                         heapinfo2->busy_block.busy_size);
-              //mmalloc_backtrace_block_display((void*)heapinfo2, i);
             }
             nb_diff2++;
           }
@@ -643,7 +622,6 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
                     ("Block %zu, Fragment %zu not found (size used = %zd)",
                      i, j,
                      heapinfo2->busy_frag.frag_size[j]);
-                //mmalloc_backtrace_fragment_display((void*)heapinfo2, i, j);
               }
               nb_diff2++;
             }
@@ -672,8 +650,8 @@ int mmalloc_compare_heap(mc_snapshot_t snapshot1, mc_snapshot_t snapshot2)
  */
 static int compare_heap_area_without_type(struct s_mc_diff *state, int process_index,
                                           const void *real_area1, const void *real_area2,
-                                          mc_snapshot_t snapshot1,
-                                          mc_snapshot_t snapshot2,
+                                          simgrid::mc::Snapshot* snapshot1,
+                                          simgrid::mc::Snapshot* snapshot2,
                                           xbt_dynar_t previous, int size,
                                           int check_ignore)
 {
@@ -727,15 +705,13 @@ static int compare_heap_area_without_type(struct s_mc_diff *state, int process_i
         // Both addreses are in the heap:
         res_compare =
             compare_heap_area(process_index, addr_pointed1, addr_pointed2, snapshot1,
-                              snapshot2, previous, NULL, 0);
-        if (res_compare == 1) {
+                              snapshot2, previous, nullptr, 0);
+        if (res_compare == 1)
           return res_compare;
-        }
         i = pointer_align + sizeof(void *);
         continue;
-      } else {
+      } else
         return 1;
-      }
 
     }
 
@@ -763,25 +739,28 @@ static int compare_heap_area_without_type(struct s_mc_diff *state, int process_i
  */
 static int compare_heap_area_with_type(struct s_mc_diff *state, int process_index,
                                        const void *real_area1, const void *real_area2,
-                                       mc_snapshot_t snapshot1,
-                                       mc_snapshot_t snapshot2,
+                                       simgrid::mc::Snapshot* snapshot1,
+                                       simgrid::mc::Snapshot* snapshot2,
                                        xbt_dynar_t previous, simgrid::mc::Type* type,
                                        int area_size, int check_ignore,
                                        int pointer_level)
 {
 top:
-  if (is_stack(real_area1) && is_stack(real_area2))
+  // HACK: This should not happen but in pratice, there is some
+  // DW_TAG_typedef without DW_AT_type. We should fix this somehow.
+  if (type == nullptr)
     return 0;
 
+  if (is_stack(real_area1) && is_stack(real_area2))
+    return 0;
   ssize_t ignore1, ignore2;
 
   if ((check_ignore > 0)
       && ((ignore1 = heap_comparison_ignore_size(state->to_ignore1, real_area1))
           > 0)
       && ((ignore2 = heap_comparison_ignore_size(state->to_ignore2, real_area2))
-          == ignore1)) {
+          == ignore1))
     return 0;
-  }
 
   simgrid::mc::Type *subtype, *subsubtype;
   int res, elm_size;
@@ -803,9 +782,8 @@ top:
     } else {
       if (area_size != -1 && type->byte_size != area_size)
         return -1;
-      else {
+      else
         return (MC_snapshot_region_memcmp(real_area1, heap_region1, real_area2, heap_region2, type->byte_size) != 0);
-      }
     }
     break;
   case DW_TAG_enumeration_type:
@@ -926,24 +904,22 @@ top:
           if (res == 1)
             return res;
         }
-      } else {
+      } else
         return -1;
-      }
     } else {
       for(simgrid::mc::Member& member : type->members) {
         // TODO, optimize this? (for the offset case)
-        void *real_member1 =
-            mc_member_resolve(real_area1, type, &member, (simgrid::mc::AddressSpace*) snapshot1, process_index);
-        void *real_member2 =
-            mc_member_resolve(real_area2, type, &member, (simgrid::mc::AddressSpace*) snapshot2, process_index);
+        void *real_member1 = simgrid::dwarf::resolve_member(
+          real_area1, type, &member, (simgrid::mc::AddressSpace*) snapshot1, process_index);
+        void *real_member2 = simgrid::dwarf::resolve_member(
+            real_area2, type, &member, (simgrid::mc::AddressSpace*) snapshot2, process_index);
         res =
-            compare_heap_area_with_type(state, process_index, real_member1, real_member2,
+          compare_heap_area_with_type(state, process_index, real_member1, real_member2,
                                         snapshot1, snapshot2,
                                         previous, member.type, -1,
                                         check_ignore, 0);
-        if (res == 1) {
+        if (res == 1)
           return res;
-        }
       }
     }
     break;
@@ -972,7 +948,7 @@ top:
  */
 static simgrid::mc::Type* get_offset_type(void *real_base_address, simgrid::mc::Type* type,
                                  int offset, int area_size,
-                                 mc_snapshot_t snapshot, int process_index)
+                                 simgrid::mc::Snapshot* snapshot, int process_index)
 {
 
   // Beginning of the block, the infered variable type if the type of the block:
@@ -989,7 +965,7 @@ static simgrid::mc::Type* get_offset_type(void *real_base_address, simgrid::mc::
       if (area_size > type->byte_size && area_size % type->byte_size == 0)
         return type;
       else
-        return NULL;
+        return nullptr;
     } else {
       for(simgrid::mc::Member& member : type->members) {
 
@@ -998,20 +974,19 @@ static simgrid::mc::Type* get_offset_type(void *real_base_address, simgrid::mc::
           if (member.offset() == offset)
             return member.type;
         } else {
-          void *real_member =
-            mc_member_resolve(real_base_address, type, &member,
-              snapshot, process_index);
+          void *real_member = simgrid::dwarf::resolve_member(
+            real_base_address, type, &member, snapshot, process_index);
           if ((char*) real_member - (char *) real_base_address == offset)
             return member.type;
         }
 
       }
-      return NULL;
+      return nullptr;
     }
     break;
   default:
     /* FIXME : other cases ? */
-    return NULL;
+    return nullptr;
     break;
   }
 }
@@ -1022,13 +997,13 @@ static simgrid::mc::Type* get_offset_type(void *real_base_address, simgrid::mc::
  * @param area2          Process address for state 2
  * @param snapshot1      Snapshot of state 1
  * @param snapshot2      Snapshot of state 2
- * @param previous       Pairs of blocks already compared on the current path (or NULL)
+ * @param previous       Pairs of blocks already compared on the current path (or nullptr)
  * @param type_id        Type of variable
  * @param pointer_level
  * @return 0 (same), 1 (different), -1
  */
-int compare_heap_area(int process_index, const void *area1, const void *area2, mc_snapshot_t snapshot1,
-                      mc_snapshot_t snapshot2, xbt_dynar_t previous,
+int compare_heap_area(int process_index, const void *area1, const void *area2, simgrid::mc::Snapshot* snapshot1,
+                      simgrid::mc::Snapshot* snapshot2, xbt_dynar_t previous,
                       simgrid::mc::Type* type, int pointer_level)
 {
   simgrid::mc::Process* process = &mc_model_checker->process();
@@ -1044,7 +1019,7 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
   int type_size = -1;
   int offset1 = 0, offset2 = 0;
   int new_size1 = -1, new_size2 = -1;
-  simgrid::mc::Type *new_type1 = NULL, *new_type2 = NULL;
+  simgrid::mc::Type *new_type1 = nullptr, *new_type2 = nullptr;
 
   int match_pairs = 0;
 
@@ -1058,7 +1033,7 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
 
   malloc_info heapinfo_temp1, heapinfo_temp2;
 
-  if (previous == NULL) {
+  if (previous == nullptr) {
     previous =
         xbt_dynar_new(sizeof(heap_area_pair_t), heap_area_pair_free_voidp);
     match_pairs = 1;
@@ -1085,9 +1060,8 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
       || (block1 > (ssize_t) state->heapsize1) || (block1 < 1)
       || ((char *) area2 < (char *) state->std_heap_copy.heapbase)
       || (block2 > (ssize_t) state->heapsize2) || (block2 < 1)) {
-    if (match_pairs) {
+    if (match_pairs)
       xbt_dynar_free(&previous);
-    }
     return 1;
   }
 
@@ -1103,7 +1077,7 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
       type = type->full_type;
 
     // This assume that for "boring" types (volatile ...) byte_size is absent:
-    while (type->byte_size == 0 && type->subtype != NULL)
+    while (type->byte_size == 0 && type->subtype != nullptr)
       type = type->subtype;
 
     // Find type_size:
@@ -1168,17 +1142,15 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
 
     if (heapinfo1->busy_block.size !=
         heapinfo2->busy_block.size) {
-      if (match_pairs) {
+      if (match_pairs)
         xbt_dynar_free(&previous);
-      }
       return 1;
     }
 
     if (heapinfo1->busy_block.busy_size !=
         heapinfo2->busy_block.busy_size) {
-      if (match_pairs) {
+      if (match_pairs)
         xbt_dynar_free(&previous);
-      }
       return 1;
     }
 
@@ -1194,12 +1166,10 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
 
     // Remember (basic) type inference.
     // The current data structure only allows us to do this for the whole block.
-    if (type != NULL && area1 == real_addr_block1) {
+    if (type != nullptr && area1 == real_addr_block1)
       state->types1_(block1, 0) = type;
-    }
-    if (type != NULL && area2 == real_addr_block2) {
+    if (type != nullptr && area2 == real_addr_block2)
       state->types2_(block2, 0) = type;
-    }
 
     if (size <= 0) {
       if (match_pairs) {
@@ -1275,9 +1245,8 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
         }
         return -1;
       } else {
-        if (match_pairs) {
+        if (match_pairs)
           xbt_dynar_free(&previous);
-        }
         return 1;
       }
     }
@@ -1287,40 +1256,39 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
 
     // Remember (basic) type inference.
     // The current data structure only allows us to do this for the whole fragment.
-    if (type != NULL && area1 == real_addr_frag1) {
+    if (type != nullptr && area1 == real_addr_frag1)
       state->types1_(block1, frag1) = type;
-    }
-    if (type != NULL && area2 == real_addr_frag2) {
+    if (type != nullptr && area2 == real_addr_frag2)
       state->types2_(block2, frag2) = type;
-    }
+
     // The type of the variable is already known:
     if (type) {
       new_type1 = type;
       new_type2 = type;
     }
     // Type inference from the block type.
-    else if (state->types1_(block1, frag1) != NULL
-             || state->types2_(block2, frag2) != NULL) {
+    else if (state->types1_(block1, frag1) != nullptr
+             || state->types2_(block2, frag2) != nullptr) {
 
       offset1 = (char *) area1 - (char *) real_addr_frag1;
       offset2 = (char *) area2 - (char *) real_addr_frag2;
 
-      if (state->types1_(block1, frag1) != NULL
-          && state->types2_(block2, frag2) != NULL) {
+      if (state->types1_(block1, frag1) != nullptr
+          && state->types2_(block2, frag2) != nullptr) {
         new_type1 =
             get_offset_type(real_addr_frag1, state->types1_(block1, frag1),
                             offset1, size, snapshot1, process_index);
         new_type2 =
             get_offset_type(real_addr_frag2, state->types2_(block2, frag2),
                             offset1, size, snapshot2, process_index);
-      } else if (state->types1_(block1, frag1) != NULL) {
+      } else if (state->types1_(block1, frag1) != nullptr) {
         new_type1 =
             get_offset_type(real_addr_frag1, state->types1_(block1, frag1),
                             offset1, size, snapshot1, process_index);
         new_type2 =
             get_offset_type(real_addr_frag2, state->types1_(block1, frag1),
                             offset2, size, snapshot2, process_index);
-      } else if (state->types2_(block2, frag2) != NULL) {
+      } else if (state->types2_(block2, frag2) != nullptr) {
         new_type1 =
             get_offset_type(real_addr_frag1, state->types2_(block2, frag2),
                             offset1, size, snapshot1, process_index);
@@ -1335,15 +1303,15 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
         return -1;
       }
 
-      if (new_type1 != NULL && new_type2 != NULL && new_type1 != new_type2) {
+      if (new_type1 != nullptr && new_type2 != nullptr && new_type1 != new_type2) {
 
         type = new_type1;
-        while (type->byte_size == 0 && type->subtype != NULL)
+        while (type->byte_size == 0 && type->subtype != nullptr)
           type = type->subtype;
         new_size1 = type->byte_size;
 
         type = new_type2;
-        while (type->byte_size == 0 && type->subtype != NULL)
+        while (type->byte_size == 0 && type->subtype != nullptr)
           type = type->subtype;
         new_size2 = type->byte_size;
 
@@ -1361,15 +1329,14 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
       size = new_size1;
     }
 
-    if (offset1 == 0 && offset2 == 0) {
-      if (!add_heap_area_pair(previous, block1, frag1, block2, frag2)) {
+    if (offset1 == 0 && offset2 == 0
+      && !add_heap_area_pair(previous, block1, frag1, block2, frag2)) {
         if (match_pairs) {
           match_equals(state, previous);
           xbt_dynar_free(&previous);
         }
         return 0;
       }
-    }
 
     if (size <= 0) {
       if (match_pairs) {
@@ -1386,25 +1353,24 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
 
   } else {
 
-    if (match_pairs) {
+    if (match_pairs)
       xbt_dynar_free(&previous);
-    }
     return 1;
 
   }
 
 
   /* Start comparison */
-  if (type) {
+  if (type)
     res_compare =
         compare_heap_area_with_type(state, process_index, area1, area2, snapshot1, snapshot2,
                                     previous, type, size, check_ignore,
                                     pointer_level);
-  } else {
+  else
     res_compare =
         compare_heap_area_without_type(state, process_index, area1, area2, snapshot1, snapshot2,
                                        previous, size, check_ignore);
-  }
+
   if (res_compare == 1) {
     if (match_pairs)
       xbt_dynar_free(&previous);
@@ -1419,200 +1385,5 @@ int compare_heap_area(int process_index, const void *area1, const void *area2, m
   return 0;
 }
 
-/*********************************************** Miscellaneous ***************************************************/
-/****************************************************************************************************************/
-
-// Not used and broken code:
-# if 0
-
-// Not used:
-static int get_pointed_area_size(void *area, int heap)
-{
-
-  struct s_mc_diff *state = mc_diff_info;
-
-  int block, frag;
-  malloc_info *heapinfo;
-
-  if (heap == 1)
-    heapinfo = state->heapinfo1;
-  else
-    heapinfo = state->heapinfo2;
-
-  block =
-      ((char *) area -
-       (char *) state->std_heap_copy.heapbase) / BLOCKSIZE + 1;
-
-  if (((char *) area < (char *) state->std_heap_copy.heapbase)
-      || (block > state->heapsize1) || (block < 1))
-    return -1;
-
-  if (heapinfo[block].type == MMALLOC_TYPE_FREE || heapinfo[block].type == MMALLOC_TYPE_HEAPINFO) {     /* Free block */
-    return -1;
-  } else if (heapinfo[block].type == MMALLOC_TYPE_UNFRAGMENTED) {       /* Complete block */
-    return (int) heapinfo[block].busy_block.busy_size;
-  } else {
-    frag =
-        ((uintptr_t) (ADDR2UINT(area) % (BLOCKSIZE))) >> heapinfo[block].type;
-    return (int) heapinfo[block].busy_frag.frag_size[frag];
-  }
 }
-
-#ifndef max
-#define max( a, b ) ( ((a) > (b)) ? (a) : (b) )
-#endif
-
-// Not used:
-int mmalloc_linear_compare_heap(xbt_mheap_t heap1, xbt_mheap_t heap2)
-{
-
-  struct s_mc_diff *state = mc_diff_info;
-
-  if (heap1 == NULL && heap1 == NULL) {
-    XBT_DEBUG("Malloc descriptors null");
-    return 0;
-  }
-
-  if (heap1->heaplimit != heap2->heaplimit) {
-    XBT_DEBUG("Different limit of valid info table indices");
-    return 1;
-  }
-
-  /* Heap information */
-  state->heaplimit = ((struct mdesc *) heap1)->heaplimit;
-
-  state->std_heap_copy = *mc_model_checker->process().get_heap();
-
-  state->heapbase1 = (char *) heap1 + BLOCKSIZE;
-  state->heapbase2 = (char *) heap2 + BLOCKSIZE;
-
-  state->heapinfo1 =
-      (malloc_info *) ((char *) heap1 +
-                       ((uintptr_t)
-                        ((char *) heap1->heapinfo - (char *) state->s_heap)));
-  state->heapinfo2 =
-      (malloc_info *) ((char *) heap2 +
-                       ((uintptr_t)
-                        ((char *) heap2->heapinfo - (char *) state->s_heap)));
-
-  state->heapsize1 = heap1->heapsize;
-  state->heapsize2 = heap2->heapsize;
-
-  /* Start comparison */
-  size_t i, j, k;
-  void *addr_block1, *addr_block2, *addr_frag1, *addr_frag2;
-
-  int distance = 0;
-
-  /* Check busy blocks */
-
-  i = 1;
-
-  while (i <= state->heaplimit) {
-
-    addr_block1 =
-        ((void *) (((ADDR2UINT(i)) - 1) * BLOCKSIZE +
-                   (char *) state->heapbase1));
-    addr_block2 =
-        ((void *) (((ADDR2UINT(i)) - 1) * BLOCKSIZE +
-                   (char *) state->heapbase2));
-
-    if (state->heapinfo1[i].type != state->heapinfo2[i].type) {
-
-      distance += BLOCKSIZE;
-      XBT_DEBUG("Different type of blocks (%zu) : %d - %d -> distance = %d", i,
-                state->heapinfo1[i].type, state->heapinfo2[i].type, distance);
-      i++;
-
-    } else {
-
-      if (state->heapinfo1[i].type == MMALLOC_TYPE_FREE
-        || state->heapinfo1[i].type == MMALLOC_TYPE_HAPINFO) {     /* Free block */
-        i++;
-        continue;
-      }
-
-      if (state->heapinfo1[i].type == MMALLOC_TYPE_UNFRAGMENTED) {      /* Large block */
-
-        if (state->heapinfo1[i].busy_block.size !=
-            state->heapinfo2[i].busy_block.size) {
-          distance +=
-              BLOCKSIZE * max(state->heapinfo1[i].busy_block.size,
-                              state->heapinfo2[i].busy_block.size);
-          i += max(state->heapinfo1[i].busy_block.size,
-                   state->heapinfo2[i].busy_block.size);
-          XBT_DEBUG
-              ("Different larger of cluster at block %zu : %zu - %zu -> distance = %d",
-               i, state->heapinfo1[i].busy_block.size,
-               state->heapinfo2[i].busy_block.size, distance);
-          continue;
-        }
-
-        /*if(heapinfo1[i].busy_block.busy_size != heapinfo2[i].busy_block.busy_size){
-           distance += max(heapinfo1[i].busy_block.busy_size, heapinfo2[i].busy_block.busy_size);
-           i += max(heapinfo1[i].busy_block.size, heapinfo2[i].busy_block.size);
-           XBT_DEBUG("Different size used oin large cluster at block %zu : %zu - %zu -> distance = %d", i, heapinfo1[i].busy_block.busy_size, heapinfo2[i].busy_block.busy_size, distance);
-           continue;
-           } */
-
-        k = 0;
-
-        //while(k < (heapinfo1[i].busy_block.busy_size)){
-        while (k < state->heapinfo1[i].busy_block.size * BLOCKSIZE) {
-          if (memcmp((char *) addr_block1 + k, (char *) addr_block2 + k, 1) !=
-              0) {
-            distance++;
-          }
-          k++;
-        }
-
-        i++;
-
-      } else {                  /* Fragmented block */
-
-        for (j = 0; j < (size_t) (BLOCKSIZE >> state->heapinfo1[i].type); j++) {
-
-          addr_frag1 =
-              (void *) ((char *) addr_block1 + (j << state->heapinfo1[i].type));
-          addr_frag2 =
-              (void *) ((char *) addr_block2 + (j << state->heapinfo2[i].type));
-
-          if (state->heapinfo1[i].busy_frag.frag_size[j] == 0
-              && state->heapinfo2[i].busy_frag.frag_size[j] == 0) {
-            continue;
-          }
-
-
-          /*if(heapinfo1[i].busy_frag.frag_size[j] != heapinfo2[i].busy_frag.frag_size[j]){
-             distance += max(heapinfo1[i].busy_frag.frag_size[j], heapinfo2[i].busy_frag.frag_size[j]);
-             XBT_DEBUG("Different size used in fragment %zu in block %zu : %d - %d -> distance = %d", j, i, heapinfo1[i].busy_frag.frag_size[j], heapinfo2[i].busy_frag.frag_size[j], distance); 
-             continue;
-             } */
-
-          k = 0;
-
-          //while(k < max(heapinfo1[i].busy_frag.frag_size[j], heapinfo2[i].busy_frag.frag_size[j])){
-          while (k < (BLOCKSIZE / (BLOCKSIZE >> state->heapinfo1[i].type))) {
-            if (memcmp((char *) addr_frag1 + k, (char *) addr_frag2 + k, 1) !=
-                0) {
-              distance++;
-            }
-            k++;
-          }
-
-        }
-
-        i++;
-
-      }
-
-    }
-
-  }
-
-  return distance;
-
-}
-#endif
-
 }
