@@ -16,6 +16,7 @@ namespace simgrid {
 namespace mc {
 
 class PageStore;
+class ChunkedData;
 class ModelChecker;
 class AddressSpace;
 class Process;
@@ -25,6 +26,10 @@ class Member;
 class Type;
 class Variable;
 class Frame;
+class SimixProcessInformation;
+
+class Session;
+class Checker;
 
 }
 }
