@@ -8,29 +8,25 @@
 #include <fcntl.h>
 
 #include "xbt/log.h"
-#include "xbt/dynar.h"
-#include "xbt/virtu.h"
 
 #include "mc/mc.h"
-#include "mc_object_info.h"
-#include "mc_private.h"
-
-extern "C" {
+#include "src/mc/mc_private.h"
+#include "src/xbt/mmalloc/mmprivate.h"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_memory, mc,
                                 "Logging specific to MC (memory)");
 
+extern "C" {
+
 /* Initialize the model-checker memory subsystem */
 /* It creates the two heap regions: std_heap and mc_heap */
 void MC_memory_init()
 {
-  if (!malloc_use_mmalloc()) {
+  if (!malloc_use_mmalloc())
     xbt_die("Model-checking support is not enabled: run with simgrid-mc.");
-  }
 }
 
 /* Finalize the memory subsystem */
-#include "xbt_modinter.h"
 void MC_memory_exit(void)
 {
 }
