@@ -4,32 +4,143 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include <assert.h>
+#include <cassert>
 
-#include "mc_request.h"
-#include "mc_safety.h"
-#include "mc_private.h"
-#include "mc_smx.h"
-#include "mc_xbt.hpp"
+#include <xbt/log.h>
+#include <xbt/str.h>
+#include <xbt/sysdep.h>
+#include <xbt/dynar.h>
+#include <xbt/swag.h>
+
+#include "src/mc/mc_request.h"
+#include "src/mc/mc_safety.h"
+#include "src/mc/mc_private.h"
+#include "src/mc/mc_smx.h"
+#include "src/mc/mc_xbt.hpp"
 
 using simgrid::mc::remote;
 
-extern "C" {
-
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_request, mc,
                                 "Logging specific to MC (request)");
 
 static char *pointer_to_string(void *pointer);
 static char *buff_size_to_string(size_t size);
 
-// Those are MC_state_get_internal_request(state)
-int MC_request_depend(smx_simcall_t r1, smx_simcall_t r2)
+static inline
+smx_synchro_t MC_get_comm(smx_simcall_t r)
 {
-  if (mc_reduce_kind == e_mc_reduce_none)
-    return TRUE;
+  switch (r->call ) {
+  case SIMCALL_COMM_WAIT:
+    return simcall_comm_wait__get__comm(r);
+  case SIMCALL_COMM_TEST:
+    return simcall_comm_test__get__comm(r);
+  default:
+    return nullptr;
+  }
+}
 
+static inline
+smx_mailbox_t MC_get_mbox(smx_simcall_t r)
+{
+  switch(r->call) {
+  case SIMCALL_COMM_ISEND:
+    return simcall_comm_isend__get__mbox(r);
+  case SIMCALL_COMM_IRECV:
+    return simcall_comm_irecv__get__mbox(r);
+  default:
+    return nullptr;
+  }
+}
+
+namespace simgrid {
+namespace mc {
+
+// Does half the job
+static inline
+bool request_depend_asymmetric(smx_simcall_t r1, smx_simcall_t r2)
+{
+  if (r1->call == SIMCALL_COMM_ISEND && r2->call == SIMCALL_COMM_IRECV)
+    return false;
+
+  if (r1->call == SIMCALL_COMM_IRECV && r2->call == SIMCALL_COMM_ISEND)
+    return false;
+
+  // Those are internal requests, we do not need indirection
+  // because those objects are copies:
+  smx_synchro_t synchro1 = MC_get_comm(r1);
+  smx_synchro_t synchro2 = MC_get_comm(r2);
+
+  if ((r1->call == SIMCALL_COMM_ISEND || r1->call == SIMCALL_COMM_IRECV)
+      && r2->call == SIMCALL_COMM_WAIT) {
+
+    smx_mailbox_t mbox = MC_get_mbox(r1);
+
+    if (mbox != synchro2->comm.mbox_cpy
+        && simcall_comm_wait__get__timeout(r2) <= 0)
+      return false;
+
+    if ((r1->issuer != synchro2->comm.src_proc)
+        && (r1->issuer != synchro2->comm.dst_proc)
+        && simcall_comm_wait__get__timeout(r2) <= 0)
+      return false;
+
+    if ((r1->call == SIMCALL_COMM_ISEND)
+        && (synchro2->comm.type == SIMIX_COMM_SEND)
+        && (synchro2->comm.src_buff !=
+            simcall_comm_isend__get__src_buff(r1))
+        && simcall_comm_wait__get__timeout(r2) <= 0)
+      return false;
+
+    if ((r1->call == SIMCALL_COMM_IRECV)
+        && (synchro2->comm.type == SIMIX_COMM_RECEIVE)
+        && (synchro2->comm.dst_buff != simcall_comm_irecv__get__dst_buff(r1))
+        && simcall_comm_wait__get__timeout(r2) <= 0)
+      return false;
+  }
+
+  /* FIXME: the following rule assumes that the result of the
+   * isend/irecv call is not stored in a buffer used in the
+   * test call. */
+#if 0
+  if((r1->call == SIMCALL_COMM_ISEND || r1->call == SIMCALL_COMM_IRECV)
+     &&  r2->call == SIMCALL_COMM_TEST)
+     return FALSE;
+#endif
+
+  if (r1->call == SIMCALL_COMM_WAIT
+      && (r2->call == SIMCALL_COMM_WAIT || r2->call == SIMCALL_COMM_TEST)
+      && (synchro1->comm.src_proc == nullptr || synchro1->comm.dst_proc == nullptr))
+    return false;
+
+  if (r1->call == SIMCALL_COMM_TEST &&
+      (simcall_comm_test__get__comm(r1) == nullptr
+       || synchro1->comm.src_buff == nullptr
+       || synchro1->comm.dst_buff == nullptr))
+    return false;
+
+  if (r1->call == SIMCALL_COMM_TEST && r2->call == SIMCALL_COMM_WAIT
+      && synchro1->comm.src_buff == synchro2->comm.src_buff
+      && synchro1->comm.dst_buff == synchro2->comm.dst_buff)
+    return false;
+
+  if (r1->call == SIMCALL_COMM_WAIT && r2->call == SIMCALL_COMM_TEST
+      && synchro1->comm.src_buff != nullptr
+      && synchro1->comm.dst_buff != nullptr
+      && synchro2->comm.src_buff != nullptr
+      && synchro2->comm.dst_buff != nullptr
+      && synchro1->comm.dst_buff != synchro2->comm.src_buff
+      && synchro1->comm.dst_buff != synchro2->comm.dst_buff
+      && synchro2->comm.dst_buff != synchro1->comm.src_buff)
+    return false;
+
+  return true;
+}
+
+// Those are internal_req
+bool request_depend(smx_simcall_t r1, smx_simcall_t r2)
+{
   if (r1->issuer == r2->issuer)
-    return FALSE;
+    return false;
 
   /* Wait with timeout transitions are not considered by the independance theorem, thus we consider them as dependant with all other transitions */
   if ((r1->call == SIMCALL_COMM_WAIT && simcall_comm_wait__get__timeout(r1) > 0)
@@ -37,181 +148,40 @@ int MC_request_depend(smx_simcall_t r1, smx_simcall_t r2)
           && simcall_comm_wait__get__timeout(r2) > 0))
     return TRUE;
 
-  if (r1->call == SIMCALL_COMM_ISEND && r2->call == SIMCALL_COMM_IRECV)
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_IRECV && r2->call == SIMCALL_COMM_ISEND)
-    return FALSE;
+  if (r1->call != r2->call)
+    return request_depend_asymmetric(r1, r2)
+      && request_depend_asymmetric(r2, r1);
 
   // Those are internal requests, we do not need indirection
   // because those objects are copies:
-  smx_synchro_t synchro1 = NULL, synchro2 = NULL;
-  if (r1->call == SIMCALL_COMM_WAIT) {
-    synchro1 = simcall_comm_wait__get__comm(r1);
-  }
-  if (r2->call == SIMCALL_COMM_WAIT) {
-    synchro2 = simcall_comm_wait__get__comm(r2);
-  }
-  if (r1->call == SIMCALL_COMM_TEST) {
-    synchro1 = simcall_comm_test__get__comm(r1);
-  }
-  if (r2->call == SIMCALL_COMM_TEST) {
-    synchro2 = simcall_comm_test__get__comm(r2);
+  smx_synchro_t synchro1 = MC_get_comm(r1);
+  smx_synchro_t synchro2 = MC_get_comm(r2);
+
+  switch(r1->call) {
+  case SIMCALL_COMM_ISEND:
+    return simcall_comm_isend__get__mbox(r1) == simcall_comm_isend__get__mbox(r2);
+  case SIMCALL_COMM_IRECV:
+    return simcall_comm_irecv__get__mbox(r1) == simcall_comm_irecv__get__mbox(r2);
+  case SIMCALL_COMM_WAIT:
+    if (synchro1->comm.src_buff == synchro2->comm.src_buff
+        && synchro1->comm.dst_buff == synchro2->comm.dst_buff)
+      return false;
+    else if (synchro1->comm.src_buff != nullptr
+        && synchro1->comm.dst_buff != nullptr
+        && synchro2->comm.src_buff != nullptr
+        && synchro2->comm.dst_buff != nullptr
+        && synchro1->comm.dst_buff != synchro2->comm.src_buff
+        && synchro1->comm.dst_buff != synchro2->comm.dst_buff
+        && synchro2->comm.dst_buff != synchro1->comm.src_buff)
+      return false;
+    else
+      return true;
+  default:
+    return true;
   }
+}
 
-  if ((r1->call == SIMCALL_COMM_ISEND || r1->call == SIMCALL_COMM_IRECV)
-      && r2->call == SIMCALL_COMM_WAIT) {
-
-    smx_rdv_t rdv =
-        r1->call ==
-        SIMCALL_COMM_ISEND ? simcall_comm_isend__get__rdv(r1) :
-        simcall_comm_irecv__get__rdv(r1);
-
-    if (rdv != synchro2->comm.rdv_cpy
-        && simcall_comm_wait__get__timeout(r2) <= 0)
-      return FALSE;
-
-    if ((r1->issuer != synchro2->comm.src_proc)
-        && (r1->issuer != synchro2->comm.dst_proc)
-        && simcall_comm_wait__get__timeout(r2) <= 0)
-      return FALSE;
-
-    if ((r1->call == SIMCALL_COMM_ISEND)
-        && (synchro2->comm.type == SIMIX_COMM_SEND)
-        && (synchro2->comm.src_buff !=
-            simcall_comm_isend__get__src_buff(r1))
-        && simcall_comm_wait__get__timeout(r2) <= 0)
-      return FALSE;
-
-    if ((r1->call == SIMCALL_COMM_IRECV)
-        && (synchro2->comm.type == SIMIX_COMM_RECEIVE)
-        && (synchro2->comm.dst_buff != simcall_comm_irecv__get__dst_buff(r1))
-        && simcall_comm_wait__get__timeout(r2) <= 0)
-      return FALSE;
-  }
-
-  if ((r2->call == SIMCALL_COMM_ISEND || r2->call == SIMCALL_COMM_IRECV)
-      && r1->call == SIMCALL_COMM_WAIT) {
-
-    smx_rdv_t rdv =
-        r2->call ==
-        SIMCALL_COMM_ISEND ? simcall_comm_isend__get__rdv(r2) :
-        simcall_comm_irecv__get__rdv(r2);
-
-    if (rdv != synchro1->comm.rdv_cpy
-        && simcall_comm_wait__get__timeout(r1) <= 0)
-      return FALSE;
-
-    if ((r2->issuer != synchro1->comm.src_proc)
-        && (r2->issuer != synchro1->comm.dst_proc)
-        && simcall_comm_wait__get__timeout(r1) <= 0)
-      return FALSE;
-
-    if ((r2->call == SIMCALL_COMM_ISEND)
-        && (synchro1->comm.type == SIMIX_COMM_SEND)
-        && (synchro1->comm.src_buff !=
-            simcall_comm_isend__get__src_buff(r2))
-        && simcall_comm_wait__get__timeout(r1) <= 0)
-      return FALSE;
-
-    if ((r2->call == SIMCALL_COMM_IRECV)
-        && (synchro1->comm.type == SIMIX_COMM_RECEIVE)
-        && (synchro1->comm.dst_buff !=
-            simcall_comm_irecv__get__dst_buff(r2))
-        && simcall_comm_wait__get__timeout(r1) <= 0)
-      return FALSE;
-  }
-
-  /* FIXME: the following rule assumes that the result of the
-   * isend/irecv call is not stored in a buffer used in the
-   * test call. */
-  /*if(   (r1->call == SIMCALL_COMM_ISEND || r1->call == SIMCALL_COMM_IRECV)
-     &&  r2->call == SIMCALL_COMM_TEST)
-     return FALSE; */
-
-  /* FIXME: the following rule assumes that the result of the
-   * isend/irecv call is not stored in a buffer used in the
-   * test call.*/
-  /*if(   (r2->call == SIMCALL_COMM_ISEND || r2->call == SIMCALL_COMM_IRECV)
-     && r1->call == SIMCALL_COMM_TEST)
-     return FALSE; */
-
-  if (r1->call == SIMCALL_COMM_ISEND && r2->call == SIMCALL_COMM_ISEND
-      && simcall_comm_isend__get__rdv(r1) != simcall_comm_isend__get__rdv(r2))
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_IRECV && r2->call == SIMCALL_COMM_IRECV
-      && simcall_comm_irecv__get__rdv(r1) != simcall_comm_irecv__get__rdv(r2))
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_WAIT
-      && (r2->call == SIMCALL_COMM_WAIT || r2->call == SIMCALL_COMM_TEST)
-      && (synchro1->comm.src_proc == NULL || synchro1->comm.dst_proc == NULL))
-    return FALSE;
-
-  if (r2->call == SIMCALL_COMM_WAIT
-      && (r1->call == SIMCALL_COMM_WAIT || r1->call == SIMCALL_COMM_TEST)
-      && (synchro2->comm.src_proc == NULL || synchro2->comm.dst_proc == NULL))
-      return FALSE;
-
-  if (r1->call == SIMCALL_COMM_WAIT && r2->call == SIMCALL_COMM_WAIT
-      && synchro1->comm.src_buff == synchro2->comm.src_buff
-      && synchro2->comm.dst_buff == synchro2->comm.dst_buff)
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_WAIT && r2->call == SIMCALL_COMM_WAIT
-      && synchro1->comm.src_buff != NULL
-      && synchro1->comm.dst_buff != NULL
-      && synchro2->comm.src_buff != NULL
-      && synchro2->comm.dst_buff != NULL
-      && synchro1->comm.dst_buff != synchro2->comm.src_buff
-      && synchro1->comm.dst_buff != synchro2->comm.dst_buff
-      && synchro2->comm.dst_buff != synchro1->comm.src_buff)
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_TEST &&
-      (simcall_comm_test__get__comm(r1) == NULL
-       || synchro1->comm.src_buff == NULL
-       || synchro1->comm.dst_buff == NULL))
-    return FALSE;
-
-  if (r2->call == SIMCALL_COMM_TEST &&
-      (simcall_comm_test__get__comm(r2) == NULL
-       || synchro2->comm.src_buff == NULL
-       || synchro2->comm.dst_buff == NULL))
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_TEST && r2->call == SIMCALL_COMM_WAIT
-      && synchro1->comm.src_buff == synchro2->comm.src_buff
-      && synchro1->comm.dst_buff == synchro2->comm.dst_buff)
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_WAIT && r2->call == SIMCALL_COMM_TEST
-      && synchro1->comm.src_buff == synchro2->comm.src_buff
-      && synchro1->comm.dst_buff == synchro2->comm.dst_buff)
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_WAIT && r2->call == SIMCALL_COMM_TEST
-      && synchro1->comm.src_buff != NULL
-      && synchro1->comm.dst_buff != NULL
-      && synchro2->comm.src_buff != NULL
-      && synchro2->comm.dst_buff != NULL
-      && synchro1->comm.dst_buff != synchro2->comm.src_buff
-      && synchro1->comm.dst_buff != synchro2->comm.dst_buff
-      && synchro2->comm.dst_buff != synchro1->comm.src_buff)
-    return FALSE;
-
-  if (r1->call == SIMCALL_COMM_TEST && r2->call == SIMCALL_COMM_WAIT
-      && synchro1->comm.src_buff != NULL
-      && synchro1->comm.dst_buff != NULL
-      && synchro2->comm.src_buff != NULL
-      && synchro2->comm.dst_buff != NULL
-      && synchro1->comm.dst_buff != synchro2->comm.src_buff
-      && synchro1->comm.dst_buff != synchro2->comm.dst_buff
-      && synchro2->comm.dst_buff != synchro1->comm.src_buff)
-    return FALSE;
-
-  return TRUE;
+}
 }
 
 static char *pointer_to_string(void *pointer)
@@ -233,21 +203,23 @@ static char *buff_size_to_string(size_t buff_size)
 }
 
 
-char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t request_type)
+std::string simgrid::mc::request_to_string(smx_simcall_t req, int value, simgrid::mc::RequestType request_type)
 {
+  xbt_assert(mc_mode == MC_MODE_SERVER);
+
   bool use_remote_comm = true;
   switch(request_type) {
-  case MC_REQUEST_SIMIX:
+  case simgrid::mc::RequestType::simix:
     use_remote_comm = true;
     break;
-  case MC_REQUEST_EXECUTED:
-  case MC_REQUEST_INTERNAL:
+  case simgrid::mc::RequestType::executed:
+  case simgrid::mc::RequestType::internal:
     use_remote_comm = false;
     break;
   }
 
-  const char* type = NULL;
-  char *args = NULL;
+  const char* type = nullptr;
+  char *args = nullptr;
 
   smx_process_t issuer = MC_smx_simcall_get_issuer(req);
 
@@ -320,8 +292,10 @@ char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t req
       } else
         act = remote_act;
 
-      smx_process_t src_proc = MC_smx_resolve_process(act->comm.src_proc);
-      smx_process_t dst_proc = MC_smx_resolve_process(act->comm.dst_proc);
+      smx_process_t src_proc = mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(act->comm.src_proc));
+      smx_process_t dst_proc = mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(act->comm.dst_proc));
       args = bprintf("comm=%s [(%lu)%s (%s)-> (%lu)%s (%s)]", p,
                      src_proc ? src_proc->pid : 0,
                      src_proc ? MC_smx_process_get_host_name(src_proc) : "",
@@ -346,7 +320,7 @@ char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t req
         act = remote_act;
 
     char* p;
-    if (act->comm.src_proc == NULL || act->comm.dst_proc == NULL) {
+    if (act->comm.src_proc == nullptr || act->comm.dst_proc == nullptr) {
       type = "Test FALSE";
       p = pointer_to_string(remote_act);
       args = bprintf("comm=%s", p);
@@ -354,8 +328,10 @@ char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t req
       type = "Test TRUE";
       p = pointer_to_string(remote_act);
 
-      smx_process_t src_proc = MC_smx_resolve_process(act->comm.src_proc);
-      smx_process_t dst_proc = MC_smx_resolve_process(act->comm.dst_proc);
+      smx_process_t src_proc = mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(act->comm.src_proc));
+      smx_process_t dst_proc = mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(act->comm.dst_proc));
       args = bprintf("comm=%s [(%lu)%s (%s) -> (%lu)%s (%s)]", p,
                      src_proc->pid,
                      MC_smx_process_get_name(src_proc),
@@ -382,9 +358,8 @@ char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t req
       args = bprintf("comm=%s (%d of %lu)",
         p, value + 1, xbt_dynar_length(&comms));
       xbt_free(p);
-    } else {
+    } else
       args = bprintf("comm at idx %d", value);
-    }
     break;
   }
 
@@ -421,21 +396,12 @@ char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t req
 
     args = bprintf("locked = %d, owner = %d, sleeping = %d",
       mutex.locked,
-      mutex.owner != NULL ? (int) MC_smx_resolve_process(mutex.owner)->pid : -1,
+      mutex.owner != nullptr ? (int) mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(mutex.owner))->pid : -1,
       mutex_sleeping.count);
     break;
   }
 
-  case SIMCALL_MC_SNAPSHOT:
-    type = "MC_SNAPSHOT";
-    args = NULL;
-    break;
-
-  case SIMCALL_MC_COMPARE_SNAPSHOTS:
-    type = "MC_COMPARE_SNAPSHOTS";
-    args = NULL;
-    break;
-
   case SIMCALL_MC_RANDOM:
     type = "MC_RANDOM";
     args = bprintf("%d", value);
@@ -445,64 +411,27 @@ char *MC_request_to_string(smx_simcall_t req, int value, e_mc_request_type_t req
     THROW_UNIMPLEMENTED;
   }
 
-  char* str;
-  if (args != NULL) {
-    str =
-        bprintf("[(%lu)%s (%s)] %s(%s)", issuer->pid,
+  std::string str;
+  if (args != nullptr)
+    str = simgrid::xbt::string_printf("[(%lu)%s (%s)] %s(%s)", issuer->pid,
                 MC_smx_process_get_host_name(issuer),
                 MC_smx_process_get_name(issuer),
                 type, args);
-  } else {
-    str =
-        bprintf("[(%lu)%s (%s)] %s ", issuer->pid,
+  else
+    str = simgrid::xbt::string_printf("[(%lu)%s (%s)] %s ", issuer->pid,
                 MC_smx_process_get_host_name(issuer),
                 MC_smx_process_get_name(issuer),
                 type);
-  }
   xbt_free(args);
   return str;
 }
 
-unsigned int MC_request_testany_fail(smx_simcall_t req)
+namespace simgrid {
+namespace mc {
+
+bool request_is_enabled_by_idx(smx_simcall_t req, unsigned int idx)
 {
-  // Remote xbt_dynar_foreach on simcall_comm_testany__get__comms(req).
-
-  // Read the dynar:
-  s_xbt_dynar_t comms;
-  mc_model_checker->process().read_bytes(
-    &comms, sizeof(comms), remote(simcall_comm_testany__get__comms(req)));
-
-  // Read ther dynar buffer:
-  size_t buffer_size = comms.elmsize * comms.used;
-  char buffer[buffer_size];
-  mc_model_checker->process().read_bytes(
-    buffer, buffer_size, remote(comms.data));
-
-  // Iterate over the elements:
-  assert(comms.elmsize == sizeof(smx_synchro_t));
-  unsigned cursor;
-  for (cursor=0; cursor != comms.used; ++cursor) {
-
-    // Get the element:
-    smx_synchro_t remote_action = NULL;
-    memcpy(&remote_action, buffer + comms.elmsize * cursor, sizeof(remote_action));
-
-    // Dereference the pointer:
-    s_smx_synchro_t action;
-    mc_model_checker->process().read_bytes(
-      &action, sizeof(action), remote(remote_action));
-
-    // Finally so something useful about it:
-    if (action.comm.src_proc && action.comm.dst_proc)
-      return FALSE;
-  }
-
-  return TRUE;
-}
-
-int MC_request_is_enabled_by_idx(smx_simcall_t req, unsigned int idx)
-{
-  smx_synchro_t remote_act = NULL;
+  smx_synchro_t remote_act = nullptr;
   switch (req->call) {
 
   case SIMCALL_COMM_WAIT:
@@ -527,7 +456,7 @@ int MC_request_is_enabled_by_idx(smx_simcall_t req, unsigned int idx)
     break;
 
   default:
-    return TRUE;
+    return true;
   }
 
   s_smx_synchro_t synchro;
@@ -536,22 +465,42 @@ int MC_request_is_enabled_by_idx(smx_simcall_t req, unsigned int idx)
   return synchro.comm.src_proc && synchro.comm.dst_proc;
 }
 
-int MC_process_is_enabled(smx_process_t process)
+bool process_is_enabled(smx_process_t process)
 {
-  return MC_request_is_enabled(&process->simcall);
+  return simgrid::mc::request_is_enabled(&process->simcall);
 }
 
-char *MC_request_get_dot_output(smx_simcall_t req, int value)
+static const char* colors[] = {
+  "blue",
+  "red",
+  "green3",
+  "goldenrod",
+  "brown",
+  "purple",
+  "magenta",
+  "turquoise4",
+  "gray25",
+  "forestgreen",
+  "hotpink",
+  "lightblue",
+  "tan",
+};
+
+static inline const char* get_color(int id)
 {
-  char *label = NULL;
+  return colors[id % (sizeof(colors) / sizeof(colors[0])) ];
+}
+
+std::string request_get_dot_output(smx_simcall_t req, int value)
+{
+  std::string label;
 
   const smx_process_t issuer = MC_smx_simcall_get_issuer(req);
 
   switch (req->call) {
   case SIMCALL_COMM_ISEND:
     if (issuer->host)
-      label =
-          bprintf("[(%lu)%s] iSend", issuer->pid,
+      label = simgrid::xbt::string_printf("[(%lu)%s] iSend", issuer->pid,
                   MC_smx_process_get_host_name(issuer));
     else
       label = bprintf("[(%lu)] iSend", issuer->pid);
@@ -559,38 +508,38 @@ char *MC_request_get_dot_output(smx_simcall_t req, int value)
 
   case SIMCALL_COMM_IRECV:
     if (issuer->host)
-      label =
-          bprintf("[(%lu)%s] iRecv", issuer->pid,
+      label = simgrid::xbt::string_printf("[(%lu)%s] iRecv", issuer->pid,
                   MC_smx_process_get_host_name(issuer));
     else
-      label = bprintf("[(%lu)] iRecv", issuer->pid);
+      label = simgrid::xbt::string_printf("[(%lu)] iRecv", issuer->pid);
     break;
 
   case SIMCALL_COMM_WAIT: {
     if (value == -1) {
       if (issuer->host)
-        label =
-            bprintf("[(%lu)%s] WaitTimeout", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)%s] WaitTimeout", issuer->pid,
                     MC_smx_process_get_host_name(issuer));
       else
-        label = bprintf("[(%lu)] WaitTimeout", issuer->pid);
+        label = simgrid::xbt::string_printf("[(%lu)] WaitTimeout", issuer->pid);
     } else {
       smx_synchro_t remote_act = simcall_comm_wait__get__comm(req);
       s_smx_synchro_t synchro;
       mc_model_checker->process().read_bytes(&synchro,
         sizeof(synchro), remote(remote_act));
 
-      smx_process_t src_proc = MC_smx_resolve_process(synchro.comm.src_proc);
-      smx_process_t dst_proc = MC_smx_resolve_process(synchro.comm.dst_proc);
+      smx_process_t src_proc = mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(synchro.comm.src_proc));
+      smx_process_t dst_proc = mc_model_checker->process().resolveProcess(
+        simgrid::mc::remote(synchro.comm.dst_proc));
       if (issuer->host)
-        label =
-            bprintf("[(%lu)%s] Wait [(%lu)->(%lu)]", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)%s] Wait [(%lu)->(%lu)]",
+                    issuer->pid,
                     MC_smx_process_get_host_name(issuer),
                     src_proc ? src_proc->pid : 0,
                     dst_proc ? dst_proc->pid : 0);
       else
-        label =
-            bprintf("[(%lu)] Wait [(%lu)->(%lu)]", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)] Wait [(%lu)->(%lu)]",
+                    issuer->pid,
                     src_proc ? src_proc->pid : 0,
                     dst_proc ? dst_proc->pid : 0);
     }
@@ -602,20 +551,19 @@ char *MC_request_get_dot_output(smx_simcall_t req, int value)
     s_smx_synchro_t synchro;
     mc_model_checker->process().read_bytes(&synchro,
       sizeof(synchro), remote(remote_act));
-    if (synchro.comm.src_proc == NULL || synchro.comm.dst_proc == NULL) {
+    if (synchro.comm.src_proc == nullptr || synchro.comm.dst_proc == nullptr) {
       if (issuer->host)
-        label =
-            bprintf("[(%lu)%s] Test FALSE", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)%s] Test FALSE",
+                    issuer->pid,
                     MC_smx_process_get_host_name(issuer));
       else
         label = bprintf("[(%lu)] Test FALSE", issuer->pid);
     } else {
       if (issuer->host)
-        label =
-            bprintf("[(%lu)%s] Test TRUE", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)%s] Test TRUE", issuer->pid,
                     MC_smx_process_get_host_name(issuer));
       else
-        label = bprintf("[(%lu)] Test TRUE", issuer->pid);
+        label = simgrid::xbt::string_printf("[(%lu)] Test TRUE", issuer->pid);
     }
     break;
   }
@@ -624,84 +572,62 @@ char *MC_request_get_dot_output(smx_simcall_t req, int value)
     unsigned long comms_size = read_length(
       mc_model_checker->process(), remote(simcall_comm_waitany__get__comms(req)));
     if (issuer->host)
-      label =
-          bprintf("[(%lu)%s] WaitAny [%d of %lu]", issuer->pid,
+      label = simgrid::xbt::string_printf("[(%lu)%s] WaitAny [%d of %lu]",
+                  issuer->pid,
                   MC_smx_process_get_host_name(issuer), value + 1,
                   comms_size);
     else
-      label =
-          bprintf("[(%lu)] WaitAny [%d of %lu]", issuer->pid, value + 1,
-                  comms_size);
+      label = simgrid::xbt::string_printf("[(%lu)] WaitAny [%d of %lu]",
+                  issuer->pid, value + 1, comms_size);
     break;
   }
 
   case SIMCALL_COMM_TESTANY:
     if (value == -1) {
       if (issuer->host)
-        label =
-            bprintf("[(%lu)%s] TestAny FALSE", issuer->pid,
-                    MC_smx_process_get_host_name(issuer));
+        label = simgrid::xbt::string_printf("[(%lu)%s] TestAny FALSE",
+                    issuer->pid, MC_smx_process_get_host_name(issuer));
       else
-        label = bprintf("[(%lu)] TestAny FALSE", issuer->pid);
+        label = simgrid::xbt::string_printf("[(%lu)] TestAny FALSE", issuer->pid);
     } else {
       if (issuer->host)
-        label =
-            bprintf("[(%lu)%s] TestAny TRUE [%d of %lu]", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)%s] TestAny TRUE [%d of %lu]",
+                    issuer->pid,
                     MC_smx_process_get_host_name(issuer), value + 1,
                     xbt_dynar_length(simcall_comm_testany__get__comms(req)));
       else
-        label =
-            bprintf("[(%lu)] TestAny TRUE [%d of %lu]", issuer->pid,
+        label = simgrid::xbt::string_printf("[(%lu)] TestAny TRUE [%d of %lu]",
+                    issuer->pid,
                     value + 1,
                     xbt_dynar_length(simcall_comm_testany__get__comms(req)));
     }
     break;
 
   case SIMCALL_MUTEX_TRYLOCK:
-    label = bprintf("[(%lu)] Mutex TRYLOCK", issuer->pid);
+    label = simgrid::xbt::string_printf("[(%lu)] Mutex TRYLOCK", issuer->pid);
     break;
 
   case SIMCALL_MUTEX_LOCK:
-    label = bprintf("[(%lu)] Mutex LOCK", issuer->pid);
+    label = simgrid::xbt::string_printf("[(%lu)] Mutex LOCK", issuer->pid);
     break;
 
   case SIMCALL_MC_RANDOM:
     if (issuer->host)
-      label =
-          bprintf("[(%lu)%s] MC_RANDOM (%d)", issuer->pid,
-                  MC_smx_process_get_host_name(issuer), value);
+      label = simgrid::xbt::string_printf("[(%lu)%s] MC_RANDOM (%d)",
+                  issuer->pid, MC_smx_process_get_host_name(issuer), value);
     else
-      label = bprintf("[(%lu)] MC_RANDOM (%d)", issuer->pid, value);
-    break;
-
-  case SIMCALL_MC_SNAPSHOT:
-    if (issuer->host)
-      label =
-          bprintf("[(%lu)%s] MC_SNAPSHOT", issuer->pid,
-                  MC_smx_process_get_host_name(issuer));
-    else
-      label = bprintf("[(%lu)] MC_SNAPSHOT", issuer->pid);
-    break;
-
-  case SIMCALL_MC_COMPARE_SNAPSHOTS:
-    if (issuer->host)
-      label =
-          bprintf("[(%lu)%s] MC_COMPARE_SNAPSHOTS", issuer->pid,
-                  MC_smx_process_get_host_name(issuer));
-    else
-      label = bprintf("[(%lu)] MC_COMPARE_SNAPSHOTS", issuer->pid);
+      label = simgrid::xbt::string_printf("[(%lu)] MC_RANDOM (%d)", issuer->pid, value);
     break;
 
   default:
     THROW_UNIMPLEMENTED;
   }
 
-  char* str =
-      bprintf("label = \"%s\", color = %s, fontcolor = %s", label,
-              colors[issuer->pid - 1], colors[issuer->pid - 1]);
-  xbt_free(label);
-  return str;
-
+  const char* color = get_color(issuer->pid - 1);
+  return  simgrid::xbt::string_printf(
+        "label = \"%s\", color = %s, fontcolor = %s", label.c_str(),
+        color, color);
 }
 
 }
+}
