@@ -22,7 +22,7 @@ typedef struct s_smx_host_priv {
 } s_smx_host_priv_t;
 
 XBT_PRIVATE void _SIMIX_host_free_process_arg(void *);
-XBT_PRIVATE void SIMIX_host_create(const char *name);
+XBT_PRIVATE void SIMIX_host_create(sg_host_t host);
 XBT_PRIVATE void SIMIX_host_destroy(void *host);
 
 XBT_PRIVATE void SIMIX_host_add_auto_restart_process(sg_host_t host,
@@ -37,37 +37,22 @@ XBT_PRIVATE void SIMIX_host_add_auto_restart_process(sg_host_t host,
 
 XBT_PRIVATE void SIMIX_host_restart_processes(sg_host_t host);
 XBT_PRIVATE void SIMIX_host_autorestart(sg_host_t host);
-XBT_PRIVATE xbt_dict_t SIMIX_host_get_properties(sg_host_t host);
-XBT_PRIVATE int SIMIX_host_get_core(sg_host_t host);
-XBT_PRIVATE xbt_swag_t SIMIX_host_get_process_list(sg_host_t host);
-XBT_PRIVATE double SIMIX_host_get_speed(sg_host_t host);
-XBT_PRIVATE double SIMIX_host_get_available_speed(sg_host_t host);
-XBT_PRIVATE int SIMIX_host_get_state(sg_host_t host);
-XBT_PRIVATE double SIMIX_host_get_current_power_peak(sg_host_t host);
-XBT_PRIVATE double SIMIX_host_get_power_peak_at(sg_host_t host, int pstate_index);
-XBT_PRIVATE int SIMIX_host_get_nb_pstates(sg_host_t host);
-XBT_PRIVATE double SIMIX_host_get_consumed_energy(sg_host_t host);
-XBT_PRIVATE double SIMIX_host_get_wattmin_at(sg_host_t host,int pstate);
-XBT_PRIVATE double SIMIX_host_get_wattmax_at(sg_host_t host,int pstate);
-XBT_PRIVATE void SIMIX_host_set_pstate(sg_host_t host, int pstate_index);
-XBT_PRIVATE int SIMIX_host_get_pstate(sg_host_t host);
-XBT_PRIVATE smx_synchro_t SIMIX_process_execute(smx_process_t issuer, const char *name,
+XBT_PRIVATE smx_synchro_t SIMIX_execution_start(smx_process_t issuer, const char *name,
     double flops_amount, double priority, double bound, unsigned long affinity_mask);
-XBT_PRIVATE smx_synchro_t SIMIX_process_parallel_execute(const char *name,
+XBT_PRIVATE smx_synchro_t SIMIX_execution_parallel_start(const char *name,
     int host_nb, sg_host_t *host_list,
     double *flops_amount, double *bytes_amount,
     double amount, double rate);
-XBT_PRIVATE void SIMIX_process_execution_destroy(smx_synchro_t synchro);
-XBT_PRIVATE void SIMIX_process_execution_cancel(smx_synchro_t synchro);
-XBT_PRIVATE double SIMIX_process_execution_get_remains(smx_synchro_t synchro);
-XBT_PRIVATE e_smx_state_t SIMIX_process_execution_get_state(smx_synchro_t synchro);
-XBT_PRIVATE void SIMIX_process_execution_set_priority(smx_synchro_t synchro, double priority);
-XBT_PRIVATE void SIMIX_process_execution_set_bound(smx_synchro_t synchro, double bound);
-XBT_PRIVATE void SIMIX_process_execution_set_affinity(smx_synchro_t synchro, sg_host_t host, unsigned long mask);
-XBT_PRIVATE xbt_dynar_t SIMIX_host_get_attached_storage_list(sg_host_t host);
+XBT_PRIVATE void SIMIX_execution_destroy(smx_synchro_t synchro);
+XBT_PRIVATE void SIMIX_execution_cancel(smx_synchro_t synchro);
+XBT_PRIVATE double SIMIX_execution_get_remains(smx_synchro_t synchro);
+XBT_PRIVATE e_smx_state_t SIMIX_execution_get_state(smx_synchro_t synchro);
+XBT_PRIVATE void SIMIX_execution_set_priority(smx_synchro_t synchro, double priority);
+XBT_PRIVATE void SIMIX_execution_set_bound(smx_synchro_t synchro, double bound);
+XBT_PRIVATE void SIMIX_execution_set_affinity(smx_synchro_t synchro, sg_host_t host, unsigned long mask);
 
-XBT_PRIVATE void SIMIX_host_execution_suspend(smx_synchro_t synchro);
-XBT_PRIVATE void SIMIX_host_execution_resume(smx_synchro_t synchro);
+XBT_PRIVATE void SIMIX_execution_suspend(smx_synchro_t synchro);
+XBT_PRIVATE void SIMIX_execution_resume(smx_synchro_t synchro);
 
 XBT_PRIVATE void SIMIX_post_host_execute(smx_synchro_t synchro);
 XBT_PRIVATE void SIMIX_set_category(smx_synchro_t synchro, const char *category);
@@ -90,7 +75,7 @@ XBT_PRIVATE void SIMIX_vm_start(sg_host_t ind_vm);
 XBT_PRIVATE void SIMIX_vm_shutdown(sg_host_t ind_vm, smx_process_t issuer);
 // --
 
-XBT_PRIVATE int SIMIX_vm_get_state(sg_host_t ind_vm);
+XBT_PRIVATE e_surf_vm_state_t SIMIX_vm_get_state(sg_host_t ind_vm);
 // --
 XBT_PRIVATE void SIMIX_vm_migrate(sg_host_t ind_vm, sg_host_t ind_dst_pm);
 
@@ -102,10 +87,6 @@ XBT_PRIVATE void SIMIX_vm_set_affinity(sg_host_t ind_vm, sg_host_t ind_pm, unsig
 
 XBT_PRIVATE void SIMIX_vm_migratefrom_resumeto(sg_host_t vm, sg_host_t src_pm, sg_host_t dst_pm);
 
-XBT_PRIVATE void SIMIX_host_get_params(sg_host_t ind_vm, vm_params_t params);
-
-XBT_PRIVATE void SIMIX_host_set_params(sg_host_t ind_vm, vm_params_t params);
-
 SG_END_DECL()
 
 #endif
