@@ -61,6 +61,7 @@ typedef struct s_smx_process {
   int argc;
   char **argv;
   smx_timer_t kill_timer;
+  int segment_index;    /*Reference to an SMPI process' data segment. Default value is -1 if not in SMPI context*/
 } s_smx_process_t;
 
 
@@ -74,11 +75,11 @@ XBT_PRIVATE smx_process_t SIMIX_process_create(
                           xbt_dict_t properties,
                           int auto_restart,
                           smx_process_t parent_process);
+
 XBT_PRIVATE void SIMIX_process_runall(void);
 XBT_PRIVATE void SIMIX_process_kill(smx_process_t process, smx_process_t issuer);
 XBT_PRIVATE void SIMIX_process_killall(smx_process_t issuer, int reset_pid);
 XBT_PRIVATE smx_process_t SIMIX_process_create_from_wrapper(smx_process_arg_t args);
-XBT_PRIVATE void SIMIX_create_maestro_process(void);
 XBT_PRIVATE void SIMIX_process_stop(smx_process_t arg);
 XBT_PRIVATE void SIMIX_process_cleanup(smx_process_t arg);
 XBT_PRIVATE void SIMIX_process_empty_trash(void);
@@ -108,6 +109,9 @@ XBT_PRIVATE void SIMIX_process_sleep_destroy(smx_synchro_t synchro);
 XBT_PRIVATE void SIMIX_process_auto_restart_set(smx_process_t process, int auto_restart);
 XBT_PRIVATE smx_process_t SIMIX_process_restart(smx_process_t process, smx_process_t issuer);
 
+void SIMIX_segment_index_set(smx_process_t, int);
+extern void (*SMPI_switch_data_segment)(int);
+
 SG_END_DECL()
 
 #endif
