@@ -89,7 +89,7 @@ int smpi_coll_tuned_allgatherv_ompi_bruck(void *sbuf, int scount,
    int *new_scounts = NULL, *new_sdispls = NULL;
    ptrdiff_t slb, rlb, sext, rext;
    char *tmpsend = NULL, *tmprecv = NULL;
-   MPI_Datatype new_rdtype, new_sdtype;
+   MPI_Datatype new_rdtype = MPI_DATATYPE_NULL, new_sdtype = MPI_DATATYPE_NULL;
 
    size = smpi_comm_size(comm);
    rank = smpi_comm_rank(comm);
@@ -162,8 +162,8 @@ int smpi_coll_tuned_allgatherv_ompi_bruck(void *sbuf, int scount,
                                      rbuf, 1, new_rdtype, recvfrom,
                                      COLL_TAG_ALLGATHERV,
                                      comm, MPI_STATUS_IGNORE);
-      smpi_datatype_free(&new_sdtype);
-      smpi_datatype_free(&new_rdtype);
+      smpi_datatype_unuse(new_sdtype);
+      smpi_datatype_unuse(new_rdtype);
 
    }
 
