@@ -4,52 +4,32 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include <xbt/dynar.h>
 #include "cpu_interface.hpp"
+#include "plugins/energy.hpp"
+#include "src/instr/instr_private.h" // TRACE_is_enabled(). FIXME: remove by subscribing tracing to the surf signals
 
 XBT_LOG_EXTERNAL_CATEGORY(surf_kernel);
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_cpu, surf,
-                                "Logging specific to the SURF cpu module");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_cpu, surf, "Logging specific to the SURF cpu module");
 
-int autoload_surf_cpu_model = 1;
 void_f_void_t surf_cpu_model_init_preparse = NULL;
 
-CpuModel *surf_cpu_model_pm;
-CpuModel *surf_cpu_model_vm;
+simgrid::surf::CpuModel *surf_cpu_model_pm;
+simgrid::surf::CpuModel *surf_cpu_model_vm;
+
+namespace simgrid {
+namespace surf {
+
 /*************
  * Callbacks *
  *************/
 
-Cpu *getActionCpu(CpuAction *action) {
-  return static_cast<Cpu*>(lmm_constraint_id(lmm_get_cnst_from_var
-		                	 (action->getModel()->getMaxminSystem(),
-		                	 action->getVariable(), 0)));
-}
-
-surf_callback(void, Cpu*) cpuCreatedCallbacks;
-surf_callback(void, Cpu*) cpuDestructedCallbacks;
-surf_callback(void, Cpu*, e_surf_resource_state_t, e_surf_resource_state_t) cpuStateChangedCallbacks;
-surf_callback(void, CpuAction*, e_surf_action_state_t, e_surf_action_state_t) cpuActionStateChangedCallbacks;
-
-void cpu_parse_init(sg_platf_host_cbarg_t host){
-  surf_cpu_model_pm->createCpu(
-        host->id,
-        host->power_peak,
-        host->pstate,
-        host->power_scale,
-        host->power_trace,
-        host->core_amount,
-        host->initial_state,
-        host->state_trace,
-        host->properties);
-}
-
-void cpu_add_traces(){
-  surf_cpu_model_pm->addTraces();
-}
+simgrid::xbt::signal<void(CpuAction*, Action::State, Action::State)> cpuActionStateChangedCallbacks;
 
 /*********
  * Model *
  *********/
+
 void CpuModel::updateActionsStateLazy(double now, double /*delta*/)
 {
   CpuAction *action;
@@ -70,7 +50,7 @@ void CpuModel::updateActionsStateLazy(double now, double /*delta*/)
 
     /* set the remains to 0 due to precision problems when updating the remaining amount */
     action->setRemains(0);
-    action->setState(SURF_ACTION_DONE);
+    action->setState(Action::State::done);
     action->heapRemove(getActionHeap()); //FIXME: strange call since action was already popped
   }
   if (TRACE_is_enabled()) {
@@ -103,12 +83,12 @@ void CpuModel::updateActionsStateFull(double now, double delta)
 
   for(ActionList::iterator it(running_actions->begin()), itNext=it, itend(running_actions->end())
      ; it != itend ; it=itNext) {
-	++itNext;
+    ++itNext;
     action = static_cast<CpuAction*>(&*it);
     if (TRACE_is_enabled()) {
-      Cpu *x = static_cast<Cpu*> (lmm_constraint_id(lmm_get_cnst_from_var(getMaxminSystem(), action->getVariable(), 0)) );
+      Cpu *cpu = static_cast<Cpu*> (lmm_constraint_id(lmm_get_cnst_from_var(getMaxminSystem(), action->getVariable(), 0)) );
 
-      TRACE_surf_host_set_utilization(x->getName(),
+      TRACE_surf_host_set_utilization(cpu->getName(),
                                       action->getCategory(),
                                       lmm_variable_getvalue(action->getVariable()),
                                       now - delta,
@@ -126,133 +106,164 @@ void CpuModel::updateActionsStateFull(double now, double delta)
     if ((action->getRemainsNoUpdate() <= 0) &&
         (lmm_get_variable_weight(action->getVariable()) > 0)) {
       action->finish();
-      action->setState(SURF_ACTION_DONE);
+      action->setState(Action::State::done);
     } else if ((action->getMaxDuration() != NO_MAX_DURATION) &&
                (action->getMaxDuration() <= 0)) {
       action->finish();
-      action->setState(SURF_ACTION_DONE);
+      action->setState(Action::State::done);
     }
   }
-
-  return;
 }
 
 /************
  * Resource *
  ************/
-
-Cpu::Cpu(){
-  surf_callback_emit(cpuCreatedCallbacks, this);
+Cpu::Cpu(Model *model, simgrid::s4u::Host *host, xbt_dynar_t speedPerPstate, int core)
+ : Cpu(model, host, NULL/*constraint*/, speedPerPstate, core)
+{
 }
 
-Cpu::Cpu(Model *model, const char *name, xbt_dict_t props,
-		 int core, double powerPeak, double powerScale)
- : Resource(model, name, props)
- , m_core(core)
- , m_powerPeak(powerPeak)
- , m_powerScale(powerScale)
- , p_constraintCore(NULL)
- , p_constraintCoreId(NULL)
+Cpu::Cpu(Model *model, simgrid::s4u::Host *host, lmm_constraint_t constraint,
+    xbt_dynar_t speedPerPstate, int core)
+ : Resource(model, host->name().c_str(), constraint)
+ , coresAmount_(core)
+ , host_(host)
 {
-  surf_callback_emit(cpuCreatedCallbacks, this);
-}
+  xbt_assert(core > 0, "Host %s must have at least one core, not 0.", host->name().c_str());
 
-Cpu::Cpu(Model *model, const char *name, xbt_dict_t props,
-		 lmm_constraint_t constraint, int core, double powerPeak, double powerScale)
- : Resource(model, name, props, constraint)
- , m_core(core)
- , m_powerPeak(powerPeak)
- , m_powerScale(powerScale)
-{
-  surf_callback_emit(cpuCreatedCallbacks, this);
-  /* At now, we assume that a VM does not have a multicore CPU. */
-  if (core > 1)
-    xbt_assert(model == surf_cpu_model_pm);
+  speed_.peak = xbt_dynar_get_as(speedPerPstate, 0/*pstate*/, double);
+  speed_.scale = 1;
+  host->pimpl_cpu = this;
+  xbt_assert(speed_.scale > 0, "Speed of host %s must be >0", host->name().c_str());
+
+  // Copy the power peak array:
+  speedPerPstate_ = xbt_dynar_new(sizeof(double), nullptr);
+  unsigned long n = xbt_dynar_length(speedPerPstate);
+  for (unsigned long i = 0; i != n; ++i) {
+    double value = xbt_dynar_get_as(speedPerPstate, i, double);
+    xbt_dynar_push(speedPerPstate_, &value);
+  }
+
+  xbt_assert(model == surf_cpu_model_pm || core==1, "Currently, VM cannot be multicore");
 
-  p_constraintCore = NULL;
-  p_constraintCoreId = NULL;
   if (model->getUpdateMechanism() != UM_UNDEFINED) {
-	p_constraintCore = xbt_new(lmm_constraint_t, core);
-	p_constraintCoreId = xbt_new(void*, core);
+    p_constraintCore = xbt_new(lmm_constraint_t, core);
+    p_constraintCoreId = xbt_new(void*, core);
 
-    int i;
-    for (i = 0; i < core; i++) {
+    for (int i = 0; i < core; i++) {
       /* just for a unique id, never used as a string. */
-      p_constraintCoreId[i] = bprintf("%s:%i", name, i);
-      p_constraintCore[i] = lmm_constraint_new(model->getMaxminSystem(), p_constraintCoreId[i], m_powerScale * m_powerPeak);
+      p_constraintCoreId[i] = bprintf("%s:%i", host->name().c_str(), i);
+      p_constraintCore[i] = lmm_constraint_new(model->getMaxminSystem(), p_constraintCoreId[i], speed_.scale * speed_.peak);
     }
   }
 }
 
-Cpu::~Cpu(){
-  surf_callback_emit(cpuDestructedCallbacks, this);
+Cpu::~Cpu()
+{
   if (p_constraintCoreId){
-    for (int i = 0; i < m_core; i++) {
-	  xbt_free(p_constraintCoreId[i]);
-    }
+    for (int i = 0; i < coresAmount_; i++)
+      xbt_free(p_constraintCoreId[i]);
     xbt_free(p_constraintCore);
   }
-  if (p_constraintCoreId)
-    xbt_free(p_constraintCoreId);
+  xbt_free(p_constraintCoreId);
+  xbt_dynar_free(&speedPerPstate_);
 }
 
 double Cpu::getCurrentPowerPeak()
 {
-  return m_powerPeak;
+  return speed_.peak;
+}
+
+int Cpu::getNbPStates()
+{
+  return xbt_dynar_length(speedPerPstate_);
+}
+
+void Cpu::setPState(int pstate_index)
+{
+  xbt_dynar_t plist = speedPerPstate_;
+  xbt_assert(pstate_index <= (int)xbt_dynar_length(plist),
+      "Invalid parameters for CPU %s (pstate %d > length of pstates %d)", getName(), pstate_index, (int)xbt_dynar_length(plist));
+
+  double new_peak_speed = xbt_dynar_get_as(plist, pstate_index, double);
+  pstate_ = pstate_index;
+  speed_.peak = new_peak_speed;
+
+  onSpeedChange();
+}
+
+int Cpu::getPState()
+{
+  return pstate_;
+}
+
+double Cpu::getPowerPeakAt(int pstate_index)
+{
+  xbt_dynar_t plist = speedPerPstate_;
+  xbt_assert((pstate_index <= (int)xbt_dynar_length(plist)), "Invalid parameters (pstate index out of bounds)");
+
+  return xbt_dynar_get_as(plist, pstate_index, double);
 }
 
 double Cpu::getSpeed(double load)
 {
-  return load * m_powerPeak;
+  return load * speed_.peak;
 }
 
 double Cpu::getAvailableSpeed()
 {
 /* number between 0 and 1 */
-  return m_powerScale;
+  return speed_.scale;
 }
 
+void Cpu::onSpeedChange() {
+  TRACE_surf_host_set_speed(surf_get_clock(), getName(), coresAmount_ * speed_.scale * speed_.peak);
+}
+
+
 int Cpu::getCore()
 {
-  return m_core;
+  return coresAmount_;
 }
 
-void Cpu::setState(e_surf_resource_state_t state)
+void Cpu::setStateTrace(tmgr_trace_t trace)
 {
-  e_surf_resource_state_t old = Resource::getState();
-  Resource::setState(state);
-  surf_callback_emit(cpuStateChangedCallbacks, this, old, state);
+  xbt_assert(stateEvent_==NULL,"Cannot set a second state trace to Host %s", host_->name().c_str());
+
+  stateEvent_ = future_evt_set->add_trace(trace, 0.0, this);
 }
+void Cpu::setSpeedTrace(tmgr_trace_t trace)
+{
+  xbt_assert(speed_.event==NULL,"Cannot set a second speed trace to Host %s", host_->name().c_str());
+
+  speed_.event = future_evt_set->add_trace(trace, 0.0, this);
+}
+
+
 /**********
  * Action *
  **********/
 
 void CpuAction::updateRemainingLazy(double now)
 {
-  double delta = 0.0;
+  xbt_assert(getStateSet() == getModel()->getRunningActionSet(), "You're updating an action that is not running.");
+  xbt_assert(getPriority() > 0, "You're updating an action that seems suspended.");
 
-  xbt_assert(getStateSet() == getModel()->getRunningActionSet(),
-      "You're updating an action that is not running.");
+  double delta = now - lastUpdate_;
 
-  /* bogus priority, skip it */
-  xbt_assert(getPriority() > 0,
-      "You're updating an action that seems suspended.");
-
-  delta = now - m_lastUpdate;
-
-  if (m_remains > 0) {
-    XBT_CDEBUG(surf_kernel, "Updating action(%p): remains was %f, last_update was: %f", this, m_remains, m_lastUpdate);
-    double_update(&(m_remains), m_lastValue * delta, sg_maxmin_precision*sg_surf_precision);
+  if (remains_ > 0) {
+    XBT_CDEBUG(surf_kernel, "Updating action(%p): remains was %f, last_update was: %f", this, remains_, lastUpdate_);
+    double_update(&(remains_), lastValue_ * delta, sg_maxmin_precision*sg_surf_precision);
 
     if (TRACE_is_enabled()) {
       Cpu *cpu = static_cast<Cpu*>(lmm_constraint_id(lmm_get_cnst_from_var(getModel()->getMaxminSystem(), getVariable(), 0)));
-      TRACE_surf_host_set_utilization(cpu->getName(), getCategory(), m_lastValue, m_lastUpdate, now - m_lastUpdate);
+      TRACE_surf_host_set_utilization(cpu->getName(), getCategory(), lastValue_, lastUpdate_, now - lastUpdate_);
     }
-    XBT_CDEBUG(surf_kernel, "Updating action(%p): remains is now %f", this, m_remains);
+    XBT_CDEBUG(surf_kernel, "Updating action(%p): remains is now %f", this, remains_);
   }
 
-  m_lastUpdate = now;
-  m_lastValue = lmm_variable_getvalue(getVariable());
+  lastUpdate_ = now;
+  lastValue_ = lmm_variable_getvalue(getVariable());
 }
 
 /*
@@ -284,20 +295,16 @@ void CpuAction::setAffinity(Cpu *cpu, unsigned long mask)
     unsigned long nbits = 0;
 
     /* FIXME: There is much faster algorithms doing this. */
-    for (int i = 0; i < cpu->m_core; i++) {
+    for (int i = 0; i < cpu->coresAmount_; i++) {
       unsigned long has_affinity = (1UL << i) & mask;
       if (has_affinity)
         nbits += 1;
     }
 
-    if (nbits > 1) {
-      XBT_CRITICAL("Do not specify multiple cores for an affinity mask.");
-      XBT_CRITICAL("See the comment in cpu_action_set_affinity().");
-      DIE_IMPOSSIBLE;
-    }
+    xbt_assert(nbits <= 1, "Affinity mask cannot span over multiple cores.");
   }
 
-  for (int i = 0; i < cpu->m_core; i++) {
+  for (int i = 0; i < cpu->coresAmount_; i++) {
     XBT_DEBUG("clear affinity %p to cpu-%d@%s", this, i,  cpu->getName());
     lmm_shrink(cpu->getModel()->getMaxminSystem(), cpu->p_constraintCore[i], var_obj);
 
@@ -323,8 +330,23 @@ void CpuAction::setAffinity(Cpu *cpu, unsigned long mask)
   XBT_OUT();
 }
 
-void CpuAction::setState(e_surf_action_state_t state){
-  e_surf_action_state_t old = getState();
+simgrid::xbt::signal<void(simgrid::surf::CpuAction*, Action::State)> CpuAction::onStateChange;
+
+void CpuAction::setState(Action::State state){
+  Action::State previous = getState();
   Action::setState(state);
-  surf_callback_emit(cpuActionStateChangedCallbacks, this, old, state);
+  onStateChange(this, previous);
+}
+std::list<Cpu*> CpuAction::cpus() {
+  std::list<Cpu*> retlist;
+  lmm_system_t sys = getModel()->getMaxminSystem();
+  int llen = lmm_get_number_of_cnst_from_var(sys, getVariable());
+
+  for(int i = 0; i<llen; i++)
+    retlist.push_back( (Cpu*)(lmm_constraint_id( lmm_get_cnst_from_var(sys, getVariable(), i) )) );
+
+  return retlist;
+}
+
+}
 }
