@@ -18,33 +18,33 @@ int ROUTING_STORAGE_HOST_LEVEL;
 int SURF_STORAGE_LEVEL;
 xbt_lib_t storage_type_lib;
 int ROUTING_STORAGE_TYPE_LEVEL; //Routing for storage_type level
-xbt_dynar_t mount_list = NULL;
-StorageModel *surf_storage_model = NULL;
+simgrid::surf::StorageModel *surf_storage_model = NULL;
+
+namespace simgrid {
+namespace surf {
 
 /*************
  * Callbacks *
  *************/
 
-surf_callback(void, Storage*) storageCreatedCallbacks;
-surf_callback(void, Storage*) storageDestructedCallbacks;
-surf_callback(void, Storage*, e_surf_resource_state_t, e_surf_resource_state_t) storageStateChangedCallbacks;
-surf_callback(void, StorageAction*, e_surf_action_state_t, e_surf_action_state_t) storageActionStateChangedCallbacks;
+simgrid::xbt::signal<void(Storage*)> storageCreatedCallbacks;
+simgrid::xbt::signal<void(Storage*)> storageDestructedCallbacks;
+simgrid::xbt::signal<void(Storage*, int, int)> storageStateChangedCallbacks; // signature: wasOn, isOn
+simgrid::xbt::signal<void(StorageAction*, Action::State, Action::State)> storageActionStateChangedCallbacks;
 
 /*********
  * Model *
  *********/
 
 StorageModel::StorageModel()
-	: Model()
+  : Model()
 {
   p_storageList = NULL;
 }
 
 StorageModel::~StorageModel(){
-  lmm_system_free(p_maxminSystem);
-
+  lmm_system_free(maxminSystem_);
   surf_storage_model = NULL;
-
   xbt_dynar_free(&p_storageList);
 }
 
@@ -53,39 +53,40 @@ StorageModel::~StorageModel(){
  ************/
 
 Storage::Storage(Model *model, const char *name, xbt_dict_t props,
-                 const char* type_id, char *content_name, char *content_type,
+                 const char* type_id, const char *content_name, const char *content_type,
                  sg_size_t size)
- : Resource(model, name, props)
- , p_contentType(content_type)
+ : Resource(model, name)
+ , PropertyHolder(props)
+ , p_contentType(xbt_strdup(content_type))
  , m_size(size), m_usedSize(0)
  , p_typeId(xbt_strdup(type_id))
  , p_writeActions(xbt_dynar_new(sizeof(Action*),NULL))
 {
-  surf_callback_emit(storageCreatedCallbacks, this);
   p_content = parseContent(content_name);
-  setState(SURF_RESOURCE_ON);
+  turnOn();
 }
 
 Storage::Storage(Model *model, const char *name, xbt_dict_t props,
                  lmm_system_t maxminSystem, double bread, double bwrite,
-                 double bconnection, const char* type_id, char *content_name,
-                 char *content_type, sg_size_t size, char *attach)
- :  Resource(model, name, props, lmm_constraint_new(maxminSystem, this, bconnection))
- , p_contentType(content_type)
+                 double bconnection, const char* type_id, const char *content_name,
+                 const char *content_type, sg_size_t size, const char *attach)
+ : Resource(model, name, lmm_constraint_new(maxminSystem, this, bconnection))
+ , PropertyHolder(props)
+ , p_contentType(xbt_strdup(content_type))
  , m_size(size), m_usedSize(0)
  , p_typeId(xbt_strdup(type_id))
- , p_writeActions(xbt_dynar_new(sizeof(Action*),NULL)) {
-  surf_callback_emit(storageCreatedCallbacks, this);
+ , p_writeActions(xbt_dynar_new(sizeof(Action*),NULL))
+{
   p_content = parseContent(content_name);
   p_attach = xbt_strdup(attach);
-  setState(SURF_RESOURCE_ON);
+  turnOn();
   XBT_DEBUG("Create resource with Bconnection '%f' Bread '%f' Bwrite '%f' and Size '%llu'", bconnection, bread, bwrite, size);
   p_constraintRead  = lmm_constraint_new(maxminSystem, this, bread);
   p_constraintWrite = lmm_constraint_new(maxminSystem, this, bwrite);
 }
 
 Storage::~Storage(){
-  surf_callback_emit(storageDestructedCallbacks, this);
+  storageDestructedCallbacks(this);
   xbt_dict_free(&p_content);
   xbt_dynar_free(&p_writeActions);
   free(p_typeId);
@@ -93,19 +94,16 @@ Storage::~Storage(){
   free(p_attach);
 }
 
-xbt_dict_t Storage::parseContent(char *filename)
+xbt_dict_t Storage::parseContent(const char *filename)
 {
   m_usedSize = 0;
   if ((!filename) || (strcmp(filename, "") == 0))
     return NULL;
 
   xbt_dict_t parse_content = xbt_dict_new_homogeneous(xbt_free_f);
-  FILE *file = NULL;
 
-  file = surf_fopen(filename, "r");
-  if (file == NULL)
-    xbt_die("Cannot open file '%s' (path=%s)", filename,
-            xbt_str_join(surf_path, ":"));
+  FILE *file =  surf_fopen(filename, "r");
+  xbt_assert(file, "Cannot open file '%s' (path=%s)", filename, xbt_str_join(surf_path, ":"));
 
   char *line = NULL;
   size_t len = 0;
@@ -115,14 +113,12 @@ xbt_dict_t Storage::parseContent(char *filename)
 
   while ((read = xbt_getline(&line, &len, file)) != -1) {
     if (read){
-      if(sscanf(line,"%s %llu", path, &size) == 2) {
-        m_usedSize += size;
-        sg_size_t *psize = xbt_new(sg_size_t, 1);
-        *psize = size;
-        xbt_dict_set(parse_content,path,psize,NULL);
-      } else {
-        xbt_die("Be sure of passing a good format for content file.\n");
-      }
+      xbt_assert(sscanf(line,"%s %llu", path, &size) == 2, "Parse error in %s: %s",filename,line);
+
+      m_usedSize += size;
+      sg_size_t *psize = xbt_new(sg_size_t, 1);
+      *psize = size;
+      xbt_dict_set(parse_content,path,psize,NULL);
     }
   }
   free(line);
@@ -136,16 +132,22 @@ bool Storage::isUsed()
   return false;
 }
 
-void Storage::updateState(tmgr_trace_event_t /*event_type*/, double /*value*/, double /*date*/)
+void Storage::apply_event(tmgr_trace_iterator_t /*event*/, double /*value*/)
 {
   THROW_UNIMPLEMENTED;
 }
 
-void Storage::setState(e_surf_resource_state_t state)
-{
-  e_surf_resource_state_t old = Resource::getState();
-  Resource::setState(state);
-  surf_callback_emit(storageStateChangedCallbacks, this, old, state);
+void Storage::turnOn() {
+  if (isOff()) {
+    Resource::turnOn();
+    storageStateChangedCallbacks(this, 0, 1);
+  }
+}
+void Storage::turnOff() {
+  if (isOn()) {
+    Resource::turnOff();
+    storageStateChangedCallbacks(this, 1, 0);
+  }
 }
 
 xbt_dict_t Storage::getContent()
@@ -192,8 +194,11 @@ StorageAction::StorageAction(Model *model, double cost, bool failed, lmm_variabl
   progress = 0;
 }
 
-void StorageAction::setState(e_surf_action_state_t state){
-  e_surf_action_state_t old = getState();
+void StorageAction::setState(Action::State state){
+  Action::State old = getState();
   Action::setState(state);
-  surf_callback_emit(storageActionStateChangedCallbacks, this, old, state);
+  storageActionStateChangedCallbacks(this, old, state);
+}
+
+}
 }
