@@ -5,13 +5,16 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include <xbt/base.h>
+#include <xbt/signal.hpp>
 
 #include "surf_interface.hpp"
+#include "src/surf/PropertyHolder.hpp"
 
 #ifndef STORAGE_INTERFACE_HPP_
 #define STORAGE_INTERFACE_HPP_
 
-extern xbt_dynar_t mount_list;
+namespace simgrid {
+namespace surf {
 
 /***********
  * Classes *
@@ -29,25 +32,25 @@ class StorageAction;
  * @brief Callbacks handler which emit the callbacks after Storage creation *
  * @details Callback functions have the following signature: `void(Storage*)`
  */
-XBT_PUBLIC_DATA(surf_callback(void, Storage*)) storageCreatedCallbacks;
+XBT_PUBLIC_DATA(simgrid::xbt::signal<void(simgrid::surf::Storage*)>) storageCreatedCallbacks;
 
 /** @ingroup SURF_callbacks
  * @brief Callbacks handler which emit the callbacks after Storage destruction *
  * @details Callback functions have the following signature: `void(StoragePtr)`
  */
-XBT_PUBLIC_DATA(surf_callback(void, Storage*)) storageDestructedCallbacks;
+XBT_PUBLIC_DATA(simgrid::xbt::signal<void(simgrid::surf::Storage*)>) storageDestructedCallbacks;
 
 /** @ingroup SURF_callbacks
  * @brief Callbacks handler which emit the callbacks after Storage State changed *
- * @details Callback functions have the following signature: `void(StorageAction *action, e_surf_resource_state_t old, e_surf_resource_state_t current)`
+ * @details Callback functions have the following signature: `void(StorageAction *action, int previouslyOn, int currentlyOn)`
  */
-XBT_PUBLIC_DATA(surf_callback(void, Storage*, e_surf_resource_state_t, e_surf_resource_state_t)) storageStateChangedCallbacks;
+XBT_PUBLIC_DATA(simgrid::xbt::signal<void(simgrid::surf::Storage*, int, int)>) storageStateChangedCallbacks;
 
 /** @ingroup SURF_callbacks
  * @brief Callbacks handler which emit the callbacks after StorageAction State changed *
- * @details Callback functions have the following signature: `void(StorageAction *action, e_surf_action_state_t old, e_surf_action_state_t current)`
+ * @details Callback functions have the following signature: `void(StorageAction *action, simgrid::surf::Action::State old, simgrid::surf::Action::State current)`
  */
-XBT_PUBLIC_DATA(surf_callback(void, StorageAction*, e_surf_action_state_t, e_surf_action_state_t)) storageActionStateChangedCallbacks;
+XBT_PUBLIC_DATA(simgrid::xbt::signal<void(simgrid::surf::StorageAction*, simgrid::surf::Action::State, simgrid::surf::Action::State)>) storageActionStateChangedCallbacks;
 
 /*********
  * Model *
@@ -58,18 +61,10 @@ XBT_PUBLIC_DATA(surf_callback(void, StorageAction*, e_surf_action_state_t, e_sur
  */
 class StorageModel : public Model {
 public:
-  /**
-   * @brief The storage model constructor
-   */
   StorageModel();
-
-  /**
-   * @brief The Storange model destructor
-   */
   ~StorageModel();
 
-  /**
-   * @brief Create a Storage
+  /** @brief Create a Storage
    *
    * @param id [description]
    * @param type_id [description]
@@ -86,7 +81,7 @@ public:
                                     xbt_dict_t properties,
                                     const char *attach) = 0;
 
-  bool shareResourcesIsIdempotent() {return true;}
+  bool next_occuring_event_isIdempotent() {return true;}
 
   xbt_dynar_t p_storageList;
 };
@@ -98,7 +93,8 @@ public:
  * @brief SURF storage interface class
  * @details A Storage represent a storage unit (e.g.: hard drive, usb key)
  */
-class Storage : public Resource {
+class Storage : public simgrid::surf::Resource,
+        public simgrid::surf::PropertyHolder {
 public:
   /**
    * @brief Storage constructor
@@ -112,7 +108,7 @@ public:
    * @param size [description]
    */
   Storage(Model *model, const char *name, xbt_dict_t props,
-          const char* type_id, char *content_name, char *content_type,
+          const char* type_id, const char *content_name, const char *content_type,
           sg_size_t size);
 
   /**
@@ -134,38 +130,25 @@ public:
   Storage(Model *model, const char *name, xbt_dict_t props,
           lmm_system_t maxminSystem, double bread, double bwrite,
           double bconnection,
-          const char* type_id, char *content_name, char *content_type,
-          sg_size_t size, char *attach);
+          const char* type_id, const char *content_name, const char *content_type,
+          sg_size_t size, const char *attach);
 
-  /**
-   * @brief Storage destructor
-   */
   ~Storage();
 
-  /**
-   * @brief Check if the Storage is used
-   *
-   * @return true if the current Storage is used, false otherwise
-   */
-  bool isUsed();
+  /** @brief Check if the Storage is used (if an action currently uses its resources) */
+  bool isUsed() override;
 
-  /**
-   * @brief Update the state of the current Storage
-   *
-   * @param event_type [description]
-   * @param value [description]
-   * @param date [description]
-   */
-  void updateState(tmgr_trace_event_t event_type, double value, double date);
+  void apply_event(tmgr_trace_iterator_t event, double value) override;
 
-  void setState(e_surf_resource_state_t state);
+  void turnOn() override;
+  void turnOff() override;
 
   xbt_dict_t p_content;
   char* p_contentType;
   sg_size_t m_size;
   sg_size_t m_usedSize;
   char * p_typeId;
-  char* p_attach;
+  char* p_attach; //FIXME: this is the name of the host. Use the host directly
 
   /**
    * @brief Open a file
@@ -232,7 +215,7 @@ public:
   virtual sg_size_t getUsedSize();
 
 
-  xbt_dict_t parseContent(char *filename);
+  xbt_dict_t parseContent(const char *filename);
 
   xbt_dynar_t p_writeActions;
 
@@ -285,7 +268,7 @@ public:
   StorageAction(Model *model, double cost, bool failed, lmm_variable_t var,
       Storage *storage, e_surf_action_storage_type_t type);
 
-  void setState(e_surf_action_state_t state);
+  void setState(simgrid::surf::Action::State state) override;
 
   e_surf_action_storage_type_t m_type;
   Storage *p_storage;
@@ -293,6 +276,9 @@ public:
   double progress;
 };
 
+}
+}
+
 typedef struct s_storage_type {
   char *model;
   char *content;
