@@ -11,6 +11,9 @@
 #ifndef STORAGE_N11_HPP_
 #define STORAGE_N11_HPP_
 
+namespace simgrid {
+namespace surf {
+
 /***********
  * Classes *
  ***********/
@@ -28,10 +31,9 @@ public:
   StorageN11Model();
   ~StorageN11Model();
   Storage *createStorage(const char* id, const char* type_id,
-		   const char* content_name, const char* content_type, xbt_dict_t properties, const char* attach);
-  void addTraces(){DIE_IMPOSSIBLE;}
-  double shareResources(double now);
-  void updateActionsState(double now, double delta);
+       const char* content_name, const char* content_type, xbt_dict_t properties, const char* attach) override;
+  double next_occuring_event(double now) override;
+  void updateActionsState(double now, double delta) override;
 };
 
 /************
@@ -41,8 +43,8 @@ public:
 class StorageN11 : public Storage {
 public:
   StorageN11(StorageModel *model, const char* name, xbt_dict_t properties,
-		     lmm_system_t maxminSystem, double bread, double bwrite, double bconnection,
-		     const char* type_id, char *content_name, char *content_type, sg_size_t size, char *attach);
+         lmm_system_t maxminSystem, double bread, double bwrite, double bconnection,
+         const char* type_id, char *content_name, const char *content_type, sg_size_t size, char *attach);
 
   StorageAction *open(const char* mount, const char* path);
   StorageAction *close(surf_file_t fd);
@@ -72,4 +74,7 @@ public:
 
 };
 
+}
+}
+
 #endif /* STORAGE_N11_HPP_ */
