@@ -4,187 +4,107 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include "src/internal_config.h"
 #include "surf_private.h"
 #include "surf_interface.hpp"
 #include "network_interface.hpp"
 #include "cpu_interface.hpp"
-#include "host_interface.hpp"
-#include "simix/smx_host_private.h"
+#include "src/surf/HostImpl.hpp"
+#include "src/simix/smx_host_private.h"
 #include "surf_routing.hpp"
 #include "simgrid/sg_config.h"
 #include "mc/mc.h"
-#include "vm_interface.hpp"
+#include "virtual_machine.hpp"
+#include "src/instr/instr_private.h" // TRACE_is_enabled(). FIXME: remove by subscribing tracing to the surf signals
+#include "simgrid/s4u/engine.hpp"
 
 XBT_LOG_NEW_CATEGORY(surf, "All SURF categories");
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_kernel, surf,
-                                "Logging specific to SURF (kernel)");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_kernel, surf, "Logging specific to SURF (kernel)");
 
 /*********
  * Utils *
  *********/
 
-/* This function is a pimple that we ought to fix. But it won't be easy.
- *
- * The surf_solve() function does properly return the set of actions that
- * changed. Instead, each model change a global data, and then the caller of
- * surf_solve must pick into these sets of action_failed and action_done.
- *
- * This was not clean but ok as long as we didn't had to restart the processes
- * when the resource comes back up.
- * We worked by putting sentinel actions on every resources we are interested
- * in, so that surf informs us if/when the corresponding resource fails.
- *
- * But this does not work to get Simix informed of when a resource comes back
- * up, and this is where this pimple comes. We have a set of resources that are
- * currently down and for which simix needs to know when it comes back up.
- * And the current function is called *at every simulation step* to sweep over
- * that set, searching for a resource that was turned back up in the meanwhile.
- * This is UGLY and slow.
- *
- * The proper solution would be to not rely on globals for the action_failed and
- * action_done swags. They must be passed as parameter by the caller (the
- * handling of these actions in simix may let you think that these two sets can
- * be merged, but their handling in SimDag induce the contrary unless this
- * simdag code can check by itself whether the action is done of failed -- seems
- * very doable, but yet more cleanup to do).
- *
- * Once surf_solve() is passed the set of actions that changed, you want to add
- * a new set of resources back up as parameter to this function. You also want
- * to add a boolean field "restart_watched" to each resource, and make sure that
- * whenever a resource with this field enabled comes back up, it's added to that
- * set so that Simix sees it and react accordingly. This would kill that need
- * for surf to call simix.
- *
- */
-
-/*static void remove_watched_host(void *key)
-{
-  xbt_dict_remove(watched_hosts_lib, *(char**)key);
-}*/
-
-/*void surf_watched_hosts(void)
-{
-  char *key;
-  void *host;
-  xbt_dict_cursor_t cursor;
-  xbt_dynar_t hosts = xbt_dynar_new(sizeof(char*), NULL);
-
-  XBT_DEBUG("Check for host SURF_RESOURCE_ON on watched_hosts_lib");
-  xbt_dict_foreach(watched_hosts_lib, cursor, key, host)
-  {
-    if(SIMIX_host_get_state((smx_host_t)host) == SURF_RESOURCE_ON){
-      XBT_INFO("Restart processes on host: %s", SIMIX_host_get_name((smx_host_t)host));
-      SIMIX_host_autorestart((smx_host_t)host);
-      xbt_dynar_push_as(hosts, char*, key);
-    }
-    else
-      XBT_DEBUG("See SURF_RESOURCE_OFF on host: %s",key);
-  }
-  xbt_dynar_map(hosts, remove_watched_host);
-  xbt_dynar_free(&hosts);
-}*/
-
 /* model_list_invoke contains only surf_host and surf_vm.
- * The callback functions of cpu_model and network_model will be called from
- * those of these host models. */
-xbt_dynar_t model_list = NULL; /* for destroying all models correctly */
-xbt_dynar_t model_list_invoke = NULL;  /* for invoking callbacks */
+ * The callback functions of cpu_model and network_model will be called from those of these host models. */
+xbt_dynar_t all_existing_models = NULL; /* to destroy models correctly */
+xbt_dynar_t model_list_invoke = NULL;  /* to invoke callbacks */
 
-tmgr_history_t history = NULL;
-lmm_system_t maxmin_system = NULL;
+simgrid::trace_mgr::future_evt_set *future_evt_set = nullptr;
 xbt_dynar_t surf_path = NULL;
-xbt_dynar_t host_that_restart = NULL;
+xbt_dynar_t host_that_restart = xbt_dynar_new(sizeof(char*), NULL);
 xbt_dict_t watched_hosts_lib;
 
-surf_callback(void, void) surfExitCallbacks;
+namespace simgrid {
+namespace surf {
+
+simgrid::xbt::signal<void(void)> surfExitCallbacks;
+
+}
+}
+
+#include <simgrid/plugins/energy.h> // FIXME: this plugin should not be linked to the core
 
 s_surf_model_description_t surf_plugin_description[] = {
     {"Energy", "Cpu energy consumption.", sg_energy_plugin_init},
      {NULL, NULL,  NULL}      /* this array must be NULL terminated */
 };
 
-/* Don't forget to update the option description in smx_config when you change
-   this */
+/* Don't forget to update the option description in smx_config when you change this */
 s_surf_model_description_t surf_network_model_description[] = {
-  {"LV08",
-   "Realistic network analytic model (slow-start modeled by multiplying latency by 10.4, bandwidth by .92; bottleneck sharing uses a payload of S=8775 for evaluating RTT). ",
+  {"LV08", "Realistic network analytic model (slow-start modeled by multiplying latency by 10.4, bandwidth by .92; bottleneck sharing uses a payload of S=8775 for evaluating RTT). ",
    surf_network_model_init_LegrandVelho},
   {"Constant",
    "Simplistic network model where all communication take a constant time (one second). This model provides the lowest realism, but is (marginally) faster.",
    surf_network_model_init_Constant},
-  {"SMPI",
-   "Realistic network model specifically tailored for HPC settings (accurate modeling of slow start with correction factors on three intervals: < 1KiB, < 64 KiB, >= 64 KiB)",
+  {"SMPI", "Realistic network model specifically tailored for HPC settings (accurate modeling of slow start with correction factors on three intervals: < 1KiB, < 64 KiB, >= 64 KiB)",
    surf_network_model_init_SMPI},
-  {"IB",
-   "Realistic network model specifically tailored for HPC settings, with Infiniband contention model",
+  {"IB", "Realistic network model specifically tailored for HPC settings, with Infiniband contention model",
    surf_network_model_init_IB},
-  {"CM02",
-   "Legacy network analytic model (Very similar to LV08, but without corrective factors. The timings of small messages are thus poorly modeled).",
+  {"CM02", "Legacy network analytic model (Very similar to LV08, but without corrective factors. The timings of small messages are thus poorly modeled).",
    surf_network_model_init_CM02},
-#ifdef HAVE_NS3
-  {"NS3",
-   "Network pseudo-model using the NS3 tcp model instead of an analytic model",
-  surf_network_model_init_NS3},
+#if HAVE_NS3
+  {"NS3", "Network pseudo-model using the NS3 tcp model instead of an analytic model", surf_network_model_init_NS3},
 #endif
-  {"Reno",
-   "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
+  {"Reno",  "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
    surf_network_model_init_Reno},
-  {"Reno2",
-   "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
+  {"Reno2", "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
    surf_network_model_init_Reno2},
-  {"Vegas",
-   "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
+  {"Vegas", "Model from Steven H. Low using lagrange_solve instead of lmm_solve (experts only; check the code for more info).",
    surf_network_model_init_Vegas},
   {NULL, NULL, NULL}      /* this array must be NULL terminated */
 };
 
 s_surf_model_description_t surf_cpu_model_description[] = {
-  {"Cas01",
-   "Simplistic CPU model (time=size/power).",
-   surf_cpu_model_init_Cas01},
+  {"Cas01", "Simplistic CPU model (time=size/power).", surf_cpu_model_init_Cas01},
   {NULL, NULL,  NULL}      /* this array must be NULL terminated */
 };
 
 s_surf_model_description_t surf_host_model_description[] = {
-  {"default",
-   "Default host model. Currently, CPU:Cas01 and network:LV08 (with cross traffic enabled)",
-   surf_host_model_init_current_default},
-  {"compound",
-   "Host model that is automatically chosen if you change the network and CPU models",
-   surf_host_model_init_compound},
-  {"ptask_L07", "Host model somehow similar to Cas01+CM02 but allowing parallel tasks",
-   surf_host_model_init_ptask_L07},
+  {"default",   "Default host model. Currently, CPU:Cas01 and network:LV08 (with cross traffic enabled)", surf_host_model_init_current_default},
+  {"compound",  "Host model that is automatically chosen if you change the network and CPU models", surf_host_model_init_compound},
+  {"ptask_L07", "Host model somehow similar to Cas01+CM02 but allowing parallel tasks", surf_host_model_init_ptask_L07},
   {NULL, NULL, NULL}      /* this array must be NULL terminated */
 };
 
 s_surf_model_description_t surf_vm_model_description[] = {
-  {"default",
-   "Default vm model.",
-   surf_vm_model_init_HL13},
+  {"default", "Default vm model.", surf_vm_model_init_HL13},
   {NULL, NULL, NULL}      /* this array must be NULL terminated */
 };
 
 s_surf_model_description_t surf_optimization_mode_description[] = {
-  {"Lazy",
-   "Lazy action management (partial invalidation in lmm + heap in action remaining).",
-   NULL},
-  {"TI",
-   "Trace integration. Highly optimized mode when using availability traces (only available for the Cas01 CPU model for now).",
-    NULL},
-  {"Full",
-   "Full update of remaining and variables. Slow but may be useful when debugging.",
-   NULL},
+  {"Lazy", "Lazy action management (partial invalidation in lmm + heap in action remaining).", NULL},
+  {"TI",   "Trace integration. Highly optimized mode when using availability traces (only available for the Cas01 CPU model for now).", NULL},
+  {"Full", "Full update of remaining and variables. Slow but may be useful when debugging.", NULL},
   {NULL, NULL, NULL}      /* this array must be NULL terminated */
 };
 
 s_surf_model_description_t surf_storage_model_description[] = {
-  {"default",
-   "Simplistic storage model.",
-   surf_storage_model_init_default},
+  {"default", "Simplistic storage model.", surf_storage_model_init_default},
   {NULL, NULL,  NULL}      /* this array must be NULL terminated */
 };
 
-#ifdef CONTEXT_THREADS
+#if HAVE_THREAD_CONTEXTS
 static xbt_parmap_t surf_parmap = NULL; /* parallel map on models */
 #endif
 
@@ -195,7 +115,7 @@ double surf_get_clock(void)
   return NOW;
 }
 
-#ifdef _XBT_WIN32
+#ifdef _WIN32
 # define FILE_DELIM "\\"
 #else
 # define FILE_DELIM "/"         /* FIXME: move to better location */
@@ -225,7 +145,7 @@ FILE *surf_fopen(const char *name, const char *mode)
   return NULL;
 }
 
-#ifdef _XBT_WIN32
+#ifdef _WIN32
 #include <windows.h>
 #define MAX_DRIVE 26
 static const char *disk_drives_letter_table[MAX_DRIVE] = {
@@ -244,7 +164,7 @@ static const char *disk_drives_letter_table[MAX_DRIVE] = {
 const char *__surf_get_initial_path(void)
 {
 
-#ifdef _XBT_WIN32
+#ifdef _WIN32
   unsigned i;
   char current_directory[MAX_PATH + 1] = { 0 };
   unsigned int len = GetCurrentDirectory(MAX_PATH + 1, current_directory);
@@ -272,7 +192,7 @@ const char *__surf_get_initial_path(void)
  */
 int __surf_is_absolute_file_path(const char *file_path)
 {
-#ifdef _XBT_WIN32
+#ifdef _WIN32
   WIN32_FIND_DATA wfd = { 0 };
   HANDLE hFile = FindFirstFile(file_path, &wfd);
 
@@ -289,10 +209,8 @@ int __surf_is_absolute_file_path(const char *file_path)
 /** Displays the long description of all registered models, and quit */
 void model_help(const char *category, s_surf_model_description_t * table)
 {
-  int i;
-  printf("Long description of the %s models accepted by this simulator:\n",
-         category);
-  for (i = 0; table[i].name; i++)
+  printf("Long description of the %s models accepted by this simulator:\n", category);
+  for (int i = 0; table[i].name; i++)
     printf("  %s: %s\n", table[i].name, table[i].description);
 }
 
@@ -318,37 +236,26 @@ int find_model_description(s_surf_model_description_t * table,
   return -1;
 }
 
-static XBT_INLINE void routing_asr_prop_free(void *p)
+static inline void surf_storage_free(void *r)
 {
-  //xbt_dict_t elm = (xbt_dict_t) p;
-  //xbt_dict_free(&elm); FIXME: leaking in some case? That's a sometimes double-free with AsCluster::~AsCluster
-}
-
-static XBT_INLINE void surf_host_free(void *r)
-{
-  delete static_cast<Host*>(r);
-}
-
-static XBT_INLINE void surf_storage_free(void *r)
-{
-  delete static_cast<Storage*>(r);
+  delete static_cast<simgrid::surf::Storage*>(r);
 }
 
 void sg_version_check(int lib_version_major,int lib_version_minor,int lib_version_patch) {
     if ((lib_version_major != SIMGRID_VERSION_MAJOR) || (lib_version_minor != SIMGRID_VERSION_MINOR)) {
       fprintf(stderr,
-    		  "FATAL ERROR: Your program was compiled with SimGrid version %d.%d.%d, "
-    		  "and then linked against SimGrid %d.%d.%d. Please fix this.\n",
+          "FATAL ERROR: Your program was compiled with SimGrid version %d.%d.%d, "
+          "and then linked against SimGrid %d.%d.%d. Please fix this.\n",
               SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH,
-			  lib_version_major,lib_version_minor,lib_version_patch);
+        lib_version_major,lib_version_minor,lib_version_patch);
       abort();
     }
     if (lib_version_patch != SIMGRID_VERSION_PATCH) {
         fprintf(stderr,
-      		  "Warning: Your program was compiled with SimGrid version %d.%d.%d, "
-      		  "and then linked against SimGrid %d.%d.%d. Proceeding anyway.\n",
+            "Warning: Your program was compiled with SimGrid version %d.%d.%d, "
+            "and then linked against SimGrid %d.%d.%d. Proceeding anyway.\n",
                 SIMGRID_VERSION_MAJOR,SIMGRID_VERSION_MINOR,SIMGRID_VERSION_PATCH,
-  			  lib_version_major,lib_version_minor,lib_version_patch);
+          lib_version_major,lib_version_minor,lib_version_patch);
     }
 }
 
@@ -360,30 +267,38 @@ void sg_version(int *ver_major,int *ver_minor,int *ver_patch) {
 
 void surf_init(int *argc, char **argv)
 {
+  if (host_list != nullptr) // Already initialized
+    return;
+
   XBT_DEBUG("Create all Libs");
-  host_lib = xbt_lib_new();
+  host_list = xbt_dict_new_homogeneous([](void*p) {
+    simgrid::s4u::Host* host = static_cast<simgrid::s4u::Host*>(p);
+    simgrid::s4u::Host::onDestruction(*host);
+    delete host;
+  });
+  USER_HOST_LEVEL = simgrid::s4u::Host::extension_create(NULL);
+
   as_router_lib = xbt_lib_new();
   storage_lib = xbt_lib_new();
   storage_type_lib = xbt_lib_new();
   file_lib = xbt_lib_new();
   watched_hosts_lib = xbt_dict_new_homogeneous(NULL);
 
-  sg_host_init();
 
   XBT_DEBUG("Add routing levels");
-  ROUTING_PROP_ASR_LEVEL = xbt_lib_add_level(as_router_lib,routing_asr_prop_free);
+  ROUTING_PROP_ASR_LEVEL = xbt_lib_add_level(as_router_lib, NULL);
 
   XBT_DEBUG("Add SURF levels");
-  SURF_HOST_LEVEL = xbt_lib_add_level(host_lib,surf_host_free);
+  simgrid::surf::HostImpl::classInit();
   SURF_STORAGE_LEVEL = xbt_lib_add_level(storage_lib,surf_storage_free);
 
   xbt_init(argc, argv);
-  if (!model_list)
-    model_list = xbt_dynar_new(sizeof(Model*), NULL);
+  if (!all_existing_models)
+    all_existing_models = xbt_dynar_new(sizeof(simgrid::surf::Model*), NULL);
   if (!model_list_invoke)
-    model_list_invoke = xbt_dynar_new(sizeof(Model*), NULL);
-  if (!history)
-    history = tmgr_history_new();
+    model_list_invoke = xbt_dynar_new(sizeof(simgrid::surf::Model*), NULL);
+  if (!future_evt_set)
+    future_evt_set = new simgrid::trace_mgr::future_evt_set();
 
   TRACE_add_start_function(TRACE_surf_alloc);
   TRACE_add_end_function(TRACE_surf_release);
@@ -397,7 +312,7 @@ void surf_init(int *argc, char **argv)
 void surf_exit(void)
 {
   unsigned int iter;
-  Model *model = NULL;
+  simgrid::surf::Model *model = NULL;
 
   TRACE_end();                  /* Just in case it was not called by the upper
                                  * layer (or there is no upper layer) */
@@ -407,7 +322,7 @@ void surf_exit(void)
   xbt_dynar_free(&host_that_restart);
   xbt_dynar_free(&surf_path);
 
-  xbt_lib_free(&host_lib);
+  xbt_dict_free(&host_list);
   xbt_lib_free(&as_router_lib);
   xbt_lib_free(&storage_lib);
   sg_link_exit();
@@ -415,30 +330,26 @@ void surf_exit(void)
   xbt_lib_free(&file_lib);
   xbt_dict_free(&watched_hosts_lib);
 
-  xbt_dynar_foreach(model_list, iter, model)
+  xbt_dynar_foreach(all_existing_models, iter, model)
     delete model;
-  xbt_dynar_free(&model_list);
+  xbt_dynar_free(&all_existing_models);
   xbt_dynar_free(&model_list_invoke);
   routing_exit();
 
-  surf_callback_emit(surfExitCallbacks);
+  simgrid::surf::surfExitCallbacks();
 
-  if (maxmin_system) {
-    lmm_system_free(maxmin_system);
-    maxmin_system = NULL;
-  }
-  if (history) {
-    tmgr_history_free(history);
-    history = NULL;
+  if (future_evt_set) {
+    delete future_evt_set;
+    future_evt_set = nullptr;
   }
 
-#ifdef CONTEXT_THREADS
+#if HAVE_THREAD_CONTEXTS
   xbt_parmap_destroy(surf_parmap);
 #endif
 
   tmgr_finalize();
-  surf_parse_lex_destroy();
-  surf_parse_free_callbacks();
+  sg_platf_exit();
+  simgrid::s4u::Engine::shutdown();
 
   NOW = 0;                      /* Just in case the user plans to restart the simulation afterward */
 }
@@ -447,39 +358,42 @@ void surf_exit(void)
  * Model *
  *********/
 
-Model::Model()
-  : p_maxminSystem(NULL)
-{
-  p_readyActionSet = new ActionList();
-  p_runningActionSet = new ActionList();
-  p_failedActionSet = new ActionList();
-  p_doneActionSet = new ActionList();
+namespace simgrid {
+namespace surf {
 
-  p_modifiedSet = NULL;
-  p_actionHeap = NULL;
-  p_updateMechanism = UM_UNDEFINED;
-  m_selectiveUpdate = 0;
+Model::Model()
+  : maxminSystem_(NULL)
+{
+  readyActionSet_ = new ActionList();
+  runningActionSet_ = new ActionList();
+  failedActionSet_ = new ActionList();
+  doneActionSet_ = new ActionList();
+
+  modifiedSet_ = NULL;
+  actionHeap_ = NULL;
+  updateMechanism_ = UM_UNDEFINED;
+  selectiveUpdate_ = 0;
 }
 
 Model::~Model(){
-  delete p_readyActionSet;
-  delete p_runningActionSet;
-  delete p_failedActionSet;
-  delete p_doneActionSet;
+  delete readyActionSet_;
+  delete runningActionSet_;
+  delete failedActionSet_;
+  delete doneActionSet_;
 }
 
-double Model::shareResources(double now)
+double Model::next_occuring_event(double now)
 {
   //FIXME: set the good function once and for all
-  if (p_updateMechanism == UM_LAZY)
-    return shareResourcesLazy(now);
-  else if (p_updateMechanism == UM_FULL)
-    return shareResourcesFull(now);
+  if (updateMechanism_ == UM_LAZY)
+    return next_occuring_event_lazy(now);
+  else if (updateMechanism_ == UM_FULL)
+    return next_occuring_event_full(now);
   else
     xbt_die("Invalid cpu update mechanism!");
 }
 
-double Model::shareResourcesLazy(double now)
+double Model::next_occuring_event_lazy(double now)
 {
   Action *action = NULL;
   double min = -1;
@@ -487,20 +401,20 @@ double Model::shareResourcesLazy(double now)
 
   XBT_DEBUG
       ("Before share resources, the size of modified actions set is %zd",
-       p_modifiedSet->size());
+       modifiedSet_->size());
 
-  lmm_solve(p_maxminSystem);
+  lmm_solve(maxminSystem_);
 
   XBT_DEBUG
       ("After share resources, The size of modified actions set is %zd",
-       p_modifiedSet->size());
+       modifiedSet_->size());
 
-  while(!p_modifiedSet->empty()) {
-    action = &(p_modifiedSet->front());
-    p_modifiedSet->pop_front();
+  while(!modifiedSet_->empty()) {
+    action = &(modifiedSet_->front());
+    modifiedSet_->pop_front();
     int max_dur_flag = 0;
 
-    if (action->getStateSet() != p_runningActionSet)
+    if (action->getStateSet() != runningActionSet_)
       continue;
 
     /* bogus priority, skip it */
@@ -539,15 +453,15 @@ double Model::shareResourcesLazy(double now)
         action->getMaxDuration());
 
     if (min != -1) {
-      action->heapUpdate(p_actionHeap, min, max_dur_flag ? MAX_DURATION : NORMAL);
+      action->heapUpdate(actionHeap_, min, max_dur_flag ? MAX_DURATION : NORMAL);
       XBT_DEBUG("Insert at heap action(%p) min %f now %f", action, min,
                 now);
     } else DIE_IMPOSSIBLE;
   }
 
   //hereafter must have already the min value for this resource model
-  if (xbt_heap_size(p_actionHeap) > 0)
-    min = xbt_heap_maxkey(p_actionHeap) - now;
+  if (xbt_heap_size(actionHeap_) > 0)
+    min = xbt_heap_maxkey(actionHeap_) - now;
   else
     min = -1;
 
@@ -556,7 +470,7 @@ double Model::shareResourcesLazy(double now)
   return min;
 }
 
-double Model::shareResourcesFull(double /*now*/) {
+double Model::next_occuring_event_full(double /*now*/) {
   THROW_UNIMPLEMENTED;
 }
 
@@ -593,7 +507,7 @@ double Model::shareResourcesMaxMin(ActionList *running_actions,
 
 
   for (++it; it != itend; ++it) {
-	action = &*it;
+  action = &*it;
     value = lmm_variable_getvalue(action->getVariable());
     if (value > 0) {
       if (action->getRemains() > 0)
@@ -617,12 +531,12 @@ double Model::shareResourcesMaxMin(ActionList *running_actions,
 
 void Model::updateActionsState(double now, double delta)
 {
-  if (p_updateMechanism == UM_FULL)
-	updateActionsStateFull(now, delta);
-  else if (p_updateMechanism == UM_LAZY)
-	updateActionsStateLazy(now, delta);
+  if (updateMechanism_ == UM_FULL)
+  updateActionsStateFull(now, delta);
+  else if (updateMechanism_ == UM_LAZY)
+  updateActionsStateLazy(now, delta);
   else
-	xbt_die("Invalid cpu update mechanism!");
+  xbt_die("Invalid cpu update mechanism!");
 }
 
 void Model::updateActionsStateLazy(double /*now*/, double /*delta*/)
@@ -635,79 +549,65 @@ void Model::updateActionsStateFull(double /*now*/, double /*delta*/)
   THROW_UNIMPLEMENTED;
 }
 
+}
+}
+
 /************
  * Resource *
  ************/
 
-Resource::Resource()
-: p_name(NULL), p_properties(NULL), p_model(NULL)
+namespace simgrid {
+namespace surf {
+
+Resource::Resource(Model *model, const char *name)
+  : name_(xbt_strdup(name))
+  , model_(model)
 {}
 
-Resource::Resource(Model *model, const char *name, xbt_dict_t props)
-  : p_name(xbt_strdup(name)), p_properties(props), p_model(model)
-  , m_running(true), m_stateCurrent(SURF_RESOURCE_ON)
-{}
-
-Resource::Resource(Model *model, const char *name, xbt_dict_t props, lmm_constraint_t constraint)
-  : p_name(xbt_strdup(name)), p_properties(props), p_model(model)
-  , m_running(true), m_stateCurrent(SURF_RESOURCE_ON), p_constraint(constraint)
-{}
-
-Resource::Resource(Model *model, const char *name, xbt_dict_t props, e_surf_resource_state_t stateInit)
-  : p_name(xbt_strdup(name)), p_properties(props), p_model(model)
-  , m_running(true), m_stateCurrent(stateInit)
+Resource::Resource(Model *model, const char *name, lmm_constraint_t constraint)
+  : name_(xbt_strdup(name))
+  , model_(model)
+  , constraint_(constraint)
 {}
 
 Resource::~Resource() {
-  xbt_free((void*)p_name);
-  xbt_dict_free(&p_properties);
+  xbt_free((void*)name_);
 }
 
-e_surf_resource_state_t Resource::getState()
-{
-  return m_stateCurrent;
+bool Resource::isOn() const {
+  return isOn_;
 }
-
-void Resource::setState(e_surf_resource_state_t state)
-{
-  m_stateCurrent = state;
-}
-
-bool Resource::isOn()
-{
-  return m_running;
+bool Resource::isOff() const {
+  return ! isOn_;
 }
 
 void Resource::turnOn()
 {
-  if (!m_running) {
-    m_running = true;
-  }
+  isOn_ = true;
 }
 
 void Resource::turnOff()
 {
-  if (m_running) {
-    m_running = false;
-  }
+  isOn_ = false;
 }
 
-Model *Resource::getModel() {
-  return p_model;
+Model *Resource::getModel() const {
+  return model_;
 }
 
-const char *Resource::getName() {
-  return p_name;
+const char *Resource::getName() const {
+  return name_;
 }
 
-xbt_dict_t Resource::getProperties() {
-  if (p_properties==NULL)
-    p_properties = xbt_dict_new();
-  return p_properties;
+bool Resource::operator==(const Resource &other) const {
+  return strcmp(name_, other.name_);
 }
 
-lmm_constraint_t Resource::getConstraint() {
-  return p_constraint;
+lmm_constraint_t Resource::getConstraint() const {
+  return constraint_;
+}
+
+}
 }
 
 /**********
@@ -723,96 +623,95 @@ const char *surf_action_state_names[6] = {
   "SURF_ACTION_NOT_IN_THE_SYSTEM"
 };
 
-void Action::initialize(Model *model, double cost, bool failed,
-                        lmm_variable_t var)
-{
-  m_priority = 1.0;
-  m_refcount = 1;
-  m_remains = cost;
-  m_maxDuration = NO_MAX_DURATION;
-  m_finish = -1.0;
-  m_start = surf_get_clock();
-  m_cost = cost;
-  p_model = model;
-  p_data = NULL;
-  p_variable = var;
-  m_lastValue = 0;
-  m_lastUpdate = 0;
-  m_suspended = false;
-  m_hat = NOTSET;
-  p_category = NULL;
-  p_stateHookup.prev = 0;
-  p_stateHookup.next = 0;
-  if (failed)
-    p_stateSet = getModel()->getFailedActionSet();
-  else
-    p_stateSet = getModel()->getRunningActionSet();
-
-  p_stateSet->push_back(*this);
+/* added to manage the communication action's heap */
+void surf_action_lmm_update_index_heap(void *action, int i) {
+  static_cast<simgrid::surf::Action*>(action)->updateIndexHeap(i);
 }
 
-Action::Action(Model *model, double cost, bool failed)
+namespace simgrid {
+namespace surf {
+
+void Action::initialize(simgrid::surf::Model *model, double cost, bool failed,
+                        lmm_variable_t var)
+{
+  remains_ = cost;
+  start_ = surf_get_clock();
+  cost_ = cost;
+  model_ = model;
+  variable_ = var;
+  if (failed)
+    stateSet_ = getModel()->getFailedActionSet();
+  else
+    stateSet_ = getModel()->getRunningActionSet();
+
+  stateSet_->push_back(*this);
+}
+
+Action::Action(simgrid::surf::Model *model, double cost, bool failed)
 {
   initialize(model, cost, failed);
 }
 
-Action::Action(Model *model, double cost, bool failed, lmm_variable_t var)
+Action::Action(simgrid::surf::Model *model, double cost, bool failed, lmm_variable_t var)
 {
   initialize(model, cost, failed, var);
 }
 
 Action::~Action() {
-  xbt_free(p_category);
+  xbt_free(category_);
 }
 
 void Action::finish() {
-    m_finish = surf_get_clock();
+    finishTime_ = surf_get_clock();
 }
 
-e_surf_action_state_t Action::getState()
+Action::State Action::getState()
 {
-  if (p_stateSet ==  getModel()->getReadyActionSet())
-    return SURF_ACTION_READY;
-  if (p_stateSet ==  getModel()->getRunningActionSet())
-    return SURF_ACTION_RUNNING;
-  if (p_stateSet ==  getModel()->getFailedActionSet())
-    return SURF_ACTION_FAILED;
-  if (p_stateSet ==  getModel()->getDoneActionSet())
-    return SURF_ACTION_DONE;
-  return SURF_ACTION_NOT_IN_THE_SYSTEM;
+  if (stateSet_ ==  getModel()->getReadyActionSet())
+    return Action::State::ready;
+  if (stateSet_ ==  getModel()->getRunningActionSet())
+    return Action::State::running;
+  if (stateSet_ ==  getModel()->getFailedActionSet())
+    return Action::State::failed;
+  if (stateSet_ ==  getModel()->getDoneActionSet())
+    return Action::State::done;
+  return Action::State::not_in_the_system;
 }
 
-void Action::setState(e_surf_action_state_t state)
+void Action::setState(Action::State state)
 {
-  //surf_action_state_t action_state = &(action->model_type->states);
-  XBT_IN("(%p,%s)", this, surf_action_state_names[state]);
-  p_stateSet->erase(p_stateSet->iterator_to(*this));
-  if (state == SURF_ACTION_READY)
-    p_stateSet = getModel()->getReadyActionSet();
-  else if (state == SURF_ACTION_RUNNING)
-    p_stateSet = getModel()->getRunningActionSet();
-  else if (state == SURF_ACTION_FAILED)
-    p_stateSet = getModel()->getFailedActionSet();
-  else if (state == SURF_ACTION_DONE)
-    p_stateSet = getModel()->getDoneActionSet();
-  else
-    p_stateSet = NULL;
-
-  if (p_stateSet)
-    p_stateSet->push_back(*this);
-  XBT_OUT();
+  stateSet_->erase(stateSet_->iterator_to(*this));
+  switch (state) {
+  case Action::State::ready:
+    stateSet_ = getModel()->getReadyActionSet();
+    break;
+  case Action::State::running:
+    stateSet_ = getModel()->getRunningActionSet();
+    break;
+  case Action::State::failed:
+    stateSet_ = getModel()->getFailedActionSet();
+    break;
+  case Action::State::done:
+    stateSet_ = getModel()->getDoneActionSet();
+    break;
+  default:
+    stateSet_ = NULL;
+    break;
+  }
+  if (stateSet_)
+    stateSet_->push_back(*this);
 }
 
 double Action::getBound()
 {
-  return (p_variable) ? lmm_variable_getbound(p_variable) : 0;
+  return (variable_) ? lmm_variable_getbound(variable_) : 0;
 }
 
 void Action::setBound(double bound)
 {
   XBT_IN("(%p,%g)", this, bound);
-  if (p_variable)
-    lmm_update_variable_bound(getModel()->getMaxminSystem(), p_variable, bound);
+  if (variable_)
+    lmm_update_variable_bound(getModel()->getMaxminSystem(), variable_, bound);
 
   if (getModel()->getUpdateMechanism() == UM_LAZY && getLastUpdate()!=surf_get_clock())
     heapRemove(getModel()->getActionHeap());
@@ -821,35 +720,35 @@ void Action::setBound(double bound)
 
 double Action::getStartTime()
 {
-  return m_start;
+  return start_;
 }
 
 double Action::getFinishTime()
 {
   /* keep the function behavior, some models (cpu_ti) change the finish time before the action end */
-  return m_remains == 0 ? m_finish : -1;
+  return remains_ == 0 ? finishTime_ : -1;
 }
 
 void Action::setData(void* data)
 {
-  p_data = data;
+  data_ = data;
 }
 
 void Action::setCategory(const char *category)
 {
   XBT_IN("(%p,%s)", this, category);
-  p_category = xbt_strdup(category);
+  category_ = xbt_strdup(category);
   XBT_OUT();
 }
 
 void Action::ref(){
-  m_refcount++;
+  refcount_++;
 }
 
 void Action::setMaxDuration(double duration)
 {
   XBT_IN("(%p,%g)", this, duration);
-  m_maxDuration = duration;
+  maxDuration_ = duration;
   if (getModel()->getUpdateMechanism() == UM_LAZY)      // remove action from the heap
     heapRemove(getModel()->getActionHeap());
   XBT_OUT();
@@ -860,16 +759,16 @@ void Action::gapRemove() {}
 void Action::setPriority(double priority)
 {
   XBT_IN("(%p,%g)", this, priority);
-  m_priority = priority;
+  priority_ = priority;
   lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), priority);
 
   if (getModel()->getUpdateMechanism() == UM_LAZY)
-	heapRemove(getModel()->getActionHeap());
+    heapRemove(getModel()->getActionHeap());
   XBT_OUT();
 }
 
 void Action::cancel(){
-  setState(SURF_ACTION_FAILED);
+  setState(Action::State::failed);
   if (getModel()->getUpdateMechanism() == UM_LAZY) {
     if (action_lmm_hook.is_linked())
       getModel()->getModifiedSet()->erase(getModel()->getModifiedSet()->iterator_to(*this));
@@ -878,10 +777,10 @@ void Action::cancel(){
 }
 
 int Action::unref(){
-  m_refcount--;
-  if (!m_refcount) {
+  refcount_--;
+  if (!refcount_) {
     if (action_hook.is_linked())
-      p_stateSet->erase(p_stateSet->iterator_to(*this));
+      stateSet_->erase(stateSet_->iterator_to(*this));
     if (getVariable())
       lmm_variable_free(getModel()->getMaxminSystem(), getVariable());
     if (getModel()->getUpdateMechanism() == UM_LAZY) {
@@ -899,9 +798,9 @@ int Action::unref(){
 void Action::suspend()
 {
   XBT_IN("(%p)", this);
-  if (m_suspended != 2) {
+  if (suspended_ != 2) {
     lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), 0.0);
-    m_suspended = 1;
+    suspended_ = 1;
     if (getModel()->getUpdateMechanism() == UM_LAZY)
       heapRemove(getModel()->getActionHeap());
   }
@@ -911,9 +810,9 @@ void Action::suspend()
 void Action::resume()
 {
   XBT_IN("(%p)", this);
-  if (m_suspended != 2) {
-    lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), m_priority);
-    m_suspended = 0;
+  if (suspended_ != 2) {
+    lmm_update_variable_weight(getModel()->getMaxminSystem(), getVariable(), priority_);
+    suspended_ = 0;
     if (getModel()->getUpdateMechanism() == UM_LAZY)
       heapRemove(getModel()->getActionHeap());
   }
@@ -922,7 +821,7 @@ void Action::resume()
 
 bool Action::isSuspended()
 {
-  return m_suspended == 1;
+  return suspended_ == 1;
 }
 /* insert action on heap using a given key and a hat (heap_action_type)
  * a hat can be of three types for communications:
@@ -933,35 +832,30 @@ bool Action::isSuspended()
  */
 void Action::heapInsert(xbt_heap_t heap, double key, enum heap_action_type hat)
 {
-  m_hat = hat;
+  hat_ = hat;
   xbt_heap_push(heap, this, key);
 }
 
 void Action::heapRemove(xbt_heap_t heap)
 {
-  m_hat = NOTSET;
-  if (m_indexHeap >= 0) {
-    xbt_heap_remove(heap, m_indexHeap);
+  hat_ = NOTSET;
+  if (indexHeap_ >= 0) {
+    xbt_heap_remove(heap, indexHeap_);
   }
 }
 
 void Action::heapUpdate(xbt_heap_t heap, double key, enum heap_action_type hat)
 {
-  m_hat = hat;
-  if (m_indexHeap >= 0) {
-    xbt_heap_update(heap, m_indexHeap, key);
+  hat_ = hat;
+  if (indexHeap_ >= 0) {
+    xbt_heap_update(heap, indexHeap_, key);
   }else{
     xbt_heap_push(heap, this, key);
   }
 }
 
-/* added to manage the communication action's heap */
-void surf_action_lmm_update_index_heap(void *action, int i) {
-  static_cast<Action*>(action)->updateIndexHeap(i);
-}
-
 void Action::updateIndexHeap(int i) {
-  m_indexHeap = i;
+  indexHeap_ = i;
 }
 
 double Action::getRemains()
@@ -971,12 +865,12 @@ double Action::getRemains()
   if (getModel()->getUpdateMechanism() == UM_LAZY)      /* update remains before return it */
     updateRemainingLazy(surf_get_clock());
   XBT_OUT();
-  return m_remains;
+  return remains_;
 }
 
 double Action::getRemainsNoUpdate()
 {
-  return m_remains;
+  return remains_;
 }
 
 //FIXME split code in the right places
@@ -986,51 +880,51 @@ void Action::updateRemainingLazy(double now)
 
   if(getModel() == surf_network_model)
   {
-    if (m_suspended != 0)
+    if (suspended_ != 0)
       return;
   }
   else
   {
-    xbt_assert(p_stateSet == getModel()->getRunningActionSet(),
-        "You're updating an action that is not running.");
-
-      /* bogus priority, skip it */
-    xbt_assert(m_priority > 0,
-        "You're updating an action that seems suspended.");
+    xbt_assert(stateSet_ == getModel()->getRunningActionSet(), "You're updating an action that is not running.");
+    xbt_assert(priority_ > 0, "You're updating an action that seems suspended.");
   }
 
-  delta = now - m_lastUpdate;
+  delta = now - lastUpdate_;
 
-  if (m_remains > 0) {
-    XBT_DEBUG("Updating action(%p): remains was %f, last_update was: %f", this, m_remains, m_lastUpdate);
-    double_update(&m_remains, m_lastValue * delta, sg_surf_precision*sg_maxmin_precision);
+  if (remains_ > 0) {
+    XBT_DEBUG("Updating action(%p): remains was %f, last_update was: %f", this, remains_, lastUpdate_);
+    double_update(&remains_, lastValue_ * delta, sg_surf_precision*sg_maxmin_precision);
 
     if (getModel() == surf_cpu_model_pm && TRACE_is_enabled()) {
-      Resource *cpu = static_cast<Resource*>(lmm_constraint_id(lmm_get_cnst_from_var(getModel()->getMaxminSystem(), getVariable(), 0)));
-      TRACE_surf_host_set_utilization(cpu->getName(), getCategory(), m_lastValue, m_lastUpdate, now - m_lastUpdate);
+      simgrid::surf::Resource *cpu = static_cast<simgrid::surf::Resource*>(
+        lmm_constraint_id(lmm_get_cnst_from_var(getModel()->getMaxminSystem(), getVariable(), 0)));
+      TRACE_surf_host_set_utilization(cpu->getName(), getCategory(), lastValue_, lastUpdate_, now - lastUpdate_);
     }
-    XBT_DEBUG("Updating action(%p): remains is now %f", this, m_remains);
+    XBT_DEBUG("Updating action(%p): remains is now %f", this, remains_);
   }
 
   if(getModel() == surf_network_model)
   {
-    if (m_maxDuration != NO_MAX_DURATION)
-      double_update(&m_maxDuration, delta, sg_surf_precision);
+    if (maxDuration_ != NO_MAX_DURATION)
+      double_update(&maxDuration_, delta, sg_surf_precision);
 
     //FIXME: duplicated code
-    if ((m_remains <= 0) &&
+    if ((remains_ <= 0) &&
         (lmm_get_variable_weight(getVariable()) > 0)) {
       finish();
-      setState(SURF_ACTION_DONE);
+      setState(Action::State::done);
       heapRemove(getModel()->getActionHeap());
-    } else if (((m_maxDuration != NO_MAX_DURATION)
-        && (m_maxDuration <= 0))) {
+    } else if (((maxDuration_ != NO_MAX_DURATION)
+        && (maxDuration_ <= 0))) {
       finish();
-      setState(SURF_ACTION_DONE);
+      setState(Action::State::done);
       heapRemove(getModel()->getActionHeap());
     }
   }
 
-  m_lastUpdate = now;
-  m_lastValue = lmm_variable_getvalue(getVariable());
+  lastUpdate_ = now;
+  lastValue_ = lmm_variable_getvalue(getVariable());
+}
+
+}
 }
