@@ -11,11 +11,10 @@
 #ifndef _XBT_EX_INTERFACE_H_
 #define _XBT_EX_INTERFACE_H_
 
+#include "xbt/base.h"
 #include "xbt/ex.h"
-/* The display made by an uncatched exception */
-void xbt_ex_display(xbt_ex_t * e);
 
 /* Change raw libc symbols to file names and line numbers */
-void xbt_ex_setup_backtrace(xbt_ex_t * e);
+XBT_PRIVATE void xbt_ex_setup_backtrace(xbt_ex_t * e);
 
 #endif                          /* _XBT_EX_INTERFACE_H_ */
