@@ -11,12 +11,12 @@
 
 #include <dlfcn.h>
 
-#include "../../mc/mc_base.h"
+#include "src/mc/mc_base.h"
 #include "mmprivate.h"
-#include "xbt_modinter.h"
-#include "internal_config.h"
+#include "src/xbt_modinter.h"
+#include "src/internal_config.h"
 #include <math.h>
-#include "../mc/mc_protocol.h"
+#include "src/mc/mc_protocol.h"
 
 /* ***** Whether to use `mmalloc` of the undrlying malloc ***** */
 
@@ -50,7 +50,8 @@ xbt_mheap_t mmalloc_set_current_heap(xbt_mheap_t new_heap)
   return heap;
 }
 
-#ifdef MMALLOC_WANT_OVERRIDE_LEGACY
+/* Override the malloc-like functions if MC is activated at compile time */
+#if HAVE_MC
 
 /* ***** Temporary allocator
  *
@@ -255,4 +256,4 @@ void free(void *p)
   mfree(mdp, p);
   UNLOCK(mdp);
 }
-#endif /* WANT_MALLOC_OVERRIDE */
+#endif /* HAVE_MC */
