@@ -6,11 +6,9 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include "src/internal_config.h"
 #include "xbt/sysdep.h"
-#include "xbt/log_private.h"
-#ifdef HAVE_SMPI
-#include "smpi/private.h" // to access bench_begin/end. Not ultraclean, I confess
-#endif
+#include "src/xbt/log_private.h"
 #include <stdio.h>
 
 static void append_file(xbt_log_appender_t this_, char *str) {
@@ -26,13 +24,6 @@ static void free_(xbt_log_appender_t this_) {
     fclose(this_->data);
 }
 
-#ifdef HAVE_SMPI
-void __smpi_bench_dont (void); // Stupid prototype
-void __smpi_bench_dont (void) { /* I'm only a place-holder in case we link without SMPI */; }
-void smpi_bench_begin(void) __attribute__ ((weak, alias ("__smpi_bench_dont")));
-void smpi_bench_end(void)   __attribute__ ((weak, alias ("__smpi_bench_dont")));
-#endif
-
 XBT_LOG_EXTERNAL_CATEGORY(smpi); // To detect if SMPI is inited
 
 xbt_log_appender_t xbt_log_appender_file_new(char *arg) {
@@ -62,8 +53,7 @@ typedef struct xbt_log_append2_file_s* xbt_log_append2_file_t;
 #define APPEND2_END_TOKEN_CLEAR "\n                   "
 
 static void open_append2_file(xbt_log_append2_file_t data){
-  if(data->count<0)
-  {
+  if(data->count<0) {
     //Roll
     if(!data->file)
       data->file= fopen(data->filename, "w");
@@ -71,8 +61,7 @@ static void open_append2_file(xbt_log_append2_file_t data){
       fputs(APPEND2_END_TOKEN_CLEAR,data->file);
       fseek(data->file,0,SEEK_SET);
     }
-  }
-  else{
+  } else{
     //printf("Splitting\n");
     //Split
     if(data->file)
@@ -88,24 +77,19 @@ static void open_append2_file(xbt_log_append2_file_t data){
     data->count++;
     data->file= fopen(newname, "w");
     xbt_assert(data->file);
-
   }
 }
-  
-
-
 
 static void append2_file(xbt_log_appender_t this_, char *str) {
    xbt_log_append2_file_t d=(xbt_log_append2_file_t) this_->data;
    xbt_assert(d->file);
-   if(ftell(d->file)>=d->limit)
-   {
+   if(ftell(d->file)>=d->limit) {
      open_append2_file(d);
    }
    fputs(str, d->file);
    if(d->count<0){
-          fputs(APPEND2_END_TOKEN,d->file);
-          fseek(d->file,-((signed long)strlen(APPEND2_END_TOKEN)),SEEK_CUR);
+     fputs(APPEND2_END_TOKEN,d->file);
+     fseek(d->file,-((signed long)strlen(APPEND2_END_TOKEN)),SEEK_CUR);
    }
 }
 
@@ -138,7 +122,10 @@ xbt_log_appender_t xbt_log_appender2_file_new(char *arg,int roll) {
   xbt_assert(sep>0);
   data->filename=xbt_strdup(sep+1);
   *sep='\0';
-  data->limit=atol(buf);
+  char *endptr;
+  data->limit=strtol(buf,&endptr,10);
+  xbt_assert(endptr[0]=='\0', "Invalid buffer size: %s", buf);
+  xbt_free(buf);
   if(roll)
     data->count=-1;
   else
@@ -147,4 +134,3 @@ xbt_log_appender_t xbt_log_appender2_file_new(char *arg,int roll) {
   res->data = data;
   return res;
 }
-
