@@ -18,23 +18,6 @@ static int xbt_fake_pid(void)
 
 int_f_void_t xbt_getpid = xbt_fake_pid;
 
-/*
- * Time elapsed since the beginning of the simulation.
- */
-double xbt_time()
-{
-  /* FIXME: check if we should use the request mechanism or not */
-  return SIMIX_get_clock();
-}
-
-/*
- * Freeze the process for the specified amount of time
- */
-void xbt_sleep(double sec)
-{
-  simcall_process_sleep(sec);
-}
-
 const char *xbt_procname(void)
 {
   return SIMIX_process_self_get_name();
