@@ -4,21 +4,39 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include <stdio.h>
-#include "simgrid/msg.h"            /* Yeah! If you want to use msg, you need to include simgrid/msg.h */
-#include "xbt/sysdep.h"         /* calloc, printf */
+#include "simgrid/msg.h"
 
-/* Create a log channel to have nice outputs. */
-#include "xbt/log.h"
-#include "xbt/asserts.h"
-XBT_LOG_NEW_DEFAULT_CATEGORY(msg_test,
-                             "Messages specific for this msg example");
+XBT_LOG_NEW_DEFAULT_CATEGORY(msg_test, "Messages specific for this msg example");
 
-int master(int argc, char *argv[]);
-int slave(int argc, char *argv[]);
+static int slave(int argc, char *argv[])
+{
+  msg_task_t task = NULL;
+  XBT_ATTRIB_UNUSED int res;
+  int id = -1;
+  char mailbox[80];
 
-/** Emitter function  */
-int master(int argc, char *argv[])
+  sprintf(mailbox, "jupi");
+
+  while (1) {
+    res = MSG_task_receive(&(task), mailbox);
+    xbt_assert(res == MSG_OK, "MSG_task_get failed");
+
+    if (!strcmp(MSG_task_get_name(task), "finalize")) {
+      MSG_task_destroy(task);
+      break;
+    }
+    MSG_task_execute(task);
+    XBT_INFO("Task \"%s\" done", MSG_task_get_name(task));
+
+    MSG_task_destroy(task);
+    task = NULL;
+    id--;
+  }
+  XBT_INFO("I'm done. See you!");
+  return 0;
+}
+
+static int master(int argc, char *argv[])
 {
   double task_comp_size = 5E7;
   double task_comm_size = 1E6;
@@ -69,68 +87,23 @@ int master(int argc, char *argv[])
 
   XBT_INFO("Goodbye now!");
   return 0;
-}                               /* end_of_master */
+}
 
-/** Receiver function  */
-int slave(int argc, char *argv[])
-{
-  msg_task_t task = NULL;
-  XBT_ATTRIB_UNUSED int res;
-  int id = -1;
-  char mailbox[80];
-
-  sprintf(mailbox, "jupi");
-
-  while (1) {
-    res = MSG_task_receive(&(task), mailbox);
-    xbt_assert(res == MSG_OK, "MSG_task_get failed");
-
-    if (!strcmp(MSG_task_get_name(task), "finalize")) {
-      MSG_task_destroy(task);
-      break;
-    }
-    MSG_task_execute(task);
-    XBT_INFO("Task \"%s\" done", MSG_task_get_name(task));
-
-    MSG_task_destroy(task);
-    task = NULL;
-    id--;
-  }
-  XBT_INFO("I'm done. See you!");
-  return 0;
-}                               /* end_of_slave */
-
-/** Main function */
 int main(int argc, char *argv[])
 {
   msg_error_t res;
-  const char *platform_file;
-  const char *application_file;
 
   MSG_init(&argc, argv);
-  if (argc != 3) {
-    printf("Usage: %s platform_file deployment_file\n", argv[0]);
-    printf("example: %s msg_platform.xml msg_deployment.xml\n", argv[0]);
-    exit(1);
-  }
-  platform_file = argv[1];
-  application_file = argv[2];
+  xbt_assert(argc == 2, "Usage: %s platform_file\n\tExample: %s msg_platform.xml\n", argv[0], argv[0]);
 
-  {                             /*  Simulation setting */
-    MSG_create_environment(platform_file);
-  }
-  {                             /*   Application deployment */
-    MSG_function_register("master", master);
-    MSG_function_register("slave", slave);
+  MSG_create_environment(argv[1]);
+
+  MSG_process_create("master", master, NULL, MSG_get_host_by_name("Tremblay"));
+  MSG_process_create("slave", slave, NULL, MSG_get_host_by_name("Jupiter"));
 
-    MSG_launch_application(application_file);
-  }
   res = MSG_main();
 
   XBT_INFO("Simulation time %g", MSG_get_clock());
 
-  if (res == MSG_OK)
-    return 0;
-  else
-    return 1;
-}                               /* end_of_main */
+  return res != MSG_OK;
+}
