@@ -4,8 +4,6 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include <stdio.h>
-#include <stdlib.h>
 #include "simgrid/simdag.h"
 #include "xbt/log.h"
 
@@ -23,13 +21,7 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(incomplete, sd, "SimDag incomplete test");
  */
 int main(int argc, char **argv)
 {
-
-  SD_task_t taskInit;
-  SD_task_t taskA, taskB, taskC, taskD;
-  xbt_dynar_t ret;
-
-  const SD_workstation_t *workstation;
-
+  /* scheduling parameters */
   double communication_amount1 = 1e9;
   double no_cost = 0.0;
 
@@ -40,32 +32,25 @@ int main(int argc, char **argv)
   SD_create_environment(argv[1]);
 
   /* creation of the tasks and their dependencies */
-  taskInit = SD_task_create("Init", NULL, 1.0);
-  taskA = SD_task_create("Task A", NULL, 1.0);
-  taskB = SD_task_create("Task B", NULL, 1.0);
-  taskC = SD_task_create("Task C", NULL, 1.0);
-  taskD = SD_task_create("Task D", NULL, 1.0);
-
-
-  /* scheduling parameters */
-
-  workstation = SD_workstation_get_list();
+  SD_task_t taskInit = SD_task_create("Init", NULL, 1.0);
+  SD_task_t taskA = SD_task_create("Task A", NULL, 1.0);
+  SD_task_t taskB = SD_task_create("Task B", NULL, 1.0);
+  SD_task_t taskC = SD_task_create("Task C", NULL, 1.0);
+  SD_task_t taskD = SD_task_create("Task D", NULL, 1.0);
 
   SD_task_dependency_add(NULL, NULL, taskInit, taskA);
   SD_task_dependency_add(NULL, NULL, taskInit, taskB);
   SD_task_dependency_add(NULL, NULL, taskC, taskD);
 
+  const sg_host_t *hosts = sg_host_list();
+
+  SD_task_schedule(taskInit, 1, sg_host_list(), &no_cost, &no_cost, -1.0);
+  SD_task_schedule(taskA, 1, &hosts[0], &no_cost, &communication_amount1, -1.0);
+  SD_task_schedule(taskD, 1, &hosts[0], &no_cost, &communication_amount1, -1.0);
+
   /* let's launch the simulation! */
-  SD_task_schedule(taskInit, 1, SD_workstation_get_list(), &no_cost,
-                   &no_cost, -1.0);
-  SD_task_schedule(taskA, 1, &workstation[0], &no_cost,
-                     &communication_amount1, -1.0);
-  SD_task_schedule(taskD, 1, &workstation[0], &no_cost,
-                     &communication_amount1, -1.0);
+  SD_simulate(-1.);
 
-
-  ret = SD_simulate(-1.);
-  xbt_dynar_free(&ret);
   SD_task_destroy(taskA);
   SD_task_destroy(taskB);
   SD_task_destroy(taskC);
