@@ -11,7 +11,7 @@
  */
 int main( int argc, char *argv[] )
 {
-    MPI_Init( 0, 0 );
+    MPI_Init( &argc, &argv );
     MPI_Finalize( );
     return 1;
 }
