@@ -8,8 +8,7 @@
 
 #include "xbt.h"
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(test, top,
-                                "Logging specific to this test");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(test, top, "Logging specific to this test");
 XBT_LOG_NEW_CATEGORY(top, "Useless test channel");
 
 static void dolog(const char *settings)
@@ -22,7 +21,6 @@ static void dolog(const char *settings)
   XBT_CRITICAL("false alarm%s%s%s%s%s%s", "", "", "", "", "", "!");
 }
 
-
 int main(int argc, char **argv)
 {
   xbt_init(&argc, argv);
